/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03239
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1999
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03239-0001-statasetup.do)
 |
 **************************************************************************/

set mem 200m  /* Allocating 200 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Household Survey on Drug Abuse, 1999, Dataset 0001"

#delimit ;
label define CIGEVER   1 "Yes" 2 "No" ;
label define CIGOFRSM  1 "Definitely Yes" 2 "Probably Yes" 3 "Probably Not"
                       4 "Definitely Not" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CIGWILYR  1 "Definitely Yes" 2 "Probably Yes" 3 "Probably Not"
                       4 "Definitely Not" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DON'T KNOW"
                       997 "REFUSED" ;
label define CIGYFU    9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn (CIGTRY<AGE-1)"
                       9991 "NEVER USED CIGARETTES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (CIGTRY<AGE-1)" ;
label define CIGMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED CIGARETTES" ;
label define CIG30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG30EST   1 "1 or 2 days" 2 "3 to 5 days" 3 "6 to 9 days"
                       4 "10 to 19 days" 5 "20 to 29 days" 6 "All 30 days"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIG30AV   1 "Less than one cigarette per day"
                       2 "1 cigarette per day" 3 "2 to 5 cigarettes per day"
                       4 "6 to 15 cigarettes per day (about 1/2 pack)"
                       5 "16 to 25 cigarettes per day (about 1 pack)"
                       6 "26 to 35 cigarettes per day (about 1 1/2 packs)"
                       7 "More than 35 cigs per day (abt 2 packs or more)"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIG30BR2  101 "Basic" 102 "Benson & Hedges" 103 "Cambridge"
                       104 "Camel" 105 "Capri" 106 "Carlton" 107 "Doral"
                       109 "GPC" 110 "Kent" 111 "Kool" 112 "Marlboro"
                       113 "Merit" 114 "Misty" 115 "Monarch" 116 "Montclair"
                       117 "More" 118 "Newport" 119 "Pall Mall"
                       120 "Parliament" 121 "Private Label" 122 "Salem"
                       123 "Vantage" 124 "Viceroy" 125 "Virginia Slims"
                       126 "Winston" 127 "Alpine" 128 "Barclay" 129 "Belair"
                       130 "Best Value" 132 "Bugler (roll-your-own)"
                       134 "Chesterfield" 137 "Eve" 138 "Harley Davidson"
                       140 "Lark" 142 "Lucky Strike" 144 "Maverick" 146 "Now"
                       147 "Old Gold" 148 "Players" 149 "Pyramid" 153 "Satin"
                       157 "Tareyton" 158 "Top (roll-your-own)" 160 "True"
                       161 "American Spirit" 162 "Austin"
                       166 "Bidis, brand unspecified" 171 "Checkers"
                       172 "Cimmarron" 173 "Clove, brand unspecified"
                       174 "Daves" 175 "Djarum" 176 "Drum rolling tobacco"
                       178 "Dunhill Cigarettes" 179 "Eagle"
                       185 "Generic cigarettes, brand unspecified"
                       188 "Gunsmoke" 191 "Jester (roll-your-own)"
                       193 "Kamel Red" 198 "Medallion" 199 "Meridian"
                       404 "Black & Mild" 423 "Swisher Sweets"
                       428 "Winchester" 501 "Prince Albert Tobacco"
                       1001 "Nat Sherman Cigarettes" 1005 "Private Stock"
                       1011 "Sampoerna's" 1017 "Sundance" 1018 "USA Gold"
                       1020 "Waves" 1024 "Prime" 1029 "Tourney"
                       1032 "American Spirit rolling tobacco"
                       1999 "Cigarette, brand otherwise unspecified"
                       3999 "Snuff, brand otherwise unspecified"
                       4999 "Cigar/Cigarillo, brand otherwise unspecified"
                       7999 "Not a tobacco product"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CIGARETTES"
                       9993 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define CIG30RO2  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGDLYMO  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (NEVER USED CIGS EVERYDAY)" ;
label define CIG100LF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CHEWEVER  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define CHEWTRY   985 "BAD DATA Logically assigned"
                       991 "NEVER USED CHEWING TOBACCO" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CHEWYFU   9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CHEWING TOBACCO" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (CHEWTRY<AGE-1)" ;
label define CHEWMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CHEWING TOBACCO" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CHEWREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED CHEWING TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CHW30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED CHEWING TOBACCO"
                       93 "DID NOT USE CHEWING TOBACCO PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CHW30BR2  201 "Beech-Nut" 202 "Chattanooga Chew"
                       203 "Day's Work" 204 "Granger" 205 "H.B. Scott"
                       206 "Levi Garrett" 207 "Red Fox" 208 "Red Man"
                       209 "Taylors Pride" 212 "Apple Jack" 220 "Lancaster"
                       221 "Mail Pouch" 225 "Trophy" 301 "Copenhagen"
                       304 "Hawken" 305 "Kodiak" 307 "Silver Creek"
                       308 "Skoal" 309 "Timber Wolf" 312 "Cougar"
                       317 "Rooster"
                       1999 "Cigarette, brand otherwise unspecified"
                       2999 "Chewing tobacco, brand otherwise unspecified"
                       3999 "Snuff, brand otherwise unspecified"
                       9000 "Did not confirm brand"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CHEWING TOBACCO"
                       9993 "DID NOT USE CHEWING TOBACCO PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SNFEVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define SNUFTRY   985 "BAD DATA Logically assigned"
                       991 "NEVER USED SNUFF" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define SNUFYFU   9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SNUFF" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (SNUFTRY<AGE-1)" ;
label define SNUFMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED SNUFF"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED SMOKELESS TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SNF30USE  85 "BAD DATA Logically assigned" 91 "NEVER USED SNUFF"
                       93 "DID NOT USE SNUFF IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SNF30BR2  301 "Copenhagen" 304 "Hawken" 305 "Kodiak"
                       306 "Redwood" 307 "Silver Creek" 308 "Skoal"
                       309 "Timber Wolf" 310 "Bruton" 312 "Cougar"
                       317 "Rooster" 321 "W. Garrett snuff"
                       2999 "Chewing tobacco, brand otherwise unspecified"
                       3999 "Snuff, brand otherwise unspecified"
                       7999 "Not a tobacco product"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SNUFF"
                       9993 "DID NOT USE SNUFF IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SLTTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED SMOKELESS TOBACCO" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SLTYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SMOKELESS TOBACCO" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (SLTTRY<AGE-1)" ;
label define SLTMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLTREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED SMOKELESS TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SLT30BR2  201 "Beech-Nut" 202 "Chattanooga Chew"
                       203 "Day's Work" 205 "H.B. Scott" 206 "Levi Garrett"
                       207 "Red Fox" 208 "Red Man" 209 "Taylors Pride"
                       212 "Apple Jack" 220 "Lancaster" 221 "Mail Pouch"
                       301 "Copenhagen" 304 "Hawken" 305 "Kodiak"
                       306 "Redwood" 307 "Silver Creek" 308 "Skoal"
                       309 "Timber Wolf" 310 "Bruton" 311 "Cooper"
                       312 "Cougar" 317 "Rooster" 321 "W. Garrett snuff"
                       1999 "Cigarette, brand otherwise unspecified"
                       2999 "Chewing tobacco, brand otherwise unspecified"
                       3999 "Snuff, brand otherwise unspecified"
                       7999 "Not a tobacco product"
                       9000 "Did not confirm brand"
                       9991 "NEVER USED SMOKELESS TOBACCO"
                       9993 "DID NOT USE SMOKELESS TOBACCO IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SLT30FAV  1 "Brand reported from CHW30BR2"
                       2 "Brand reported from SNF30BR2"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       93 "DID NOT USE SMOKELESS TOBACCO IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGAREVR  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define CIGARTRY  985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARS" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define CIGARYFU  9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CIGARS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (CIGARTRY<AGE-1)" ;
label define CIGARMFU  1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CIGARREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED CIGARS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CGR30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARS"
                       93 "DID NOT USE CIGARS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CI30EST   1 "1 or 2 days" 2 "3 to 5 days" 3 "6 to 9 days"
                       4 "10 to 19 days" 5 "20 to 29 days" 6 "All 30 days"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARS"
                       93 "DID NOT USE CIGARS PAST 30 DAYS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CGR30BR2  112 "Marlboro" 175 "Djarum" 401 "Antonio y Cleopatra"
                       402 "Backwoods" 403 "Bering" 404 "Black & Mild"
                       405 "Captain Black" 407 "Cuesta-Rey"
                       408 "Dutch Masters" 409 "El Producto"
                       411 "Garcia y Vega" 412 "Havatampa" 413 "King Edward"
                       414 "La Corona" 415 "Little Nippers" 416 "Macanudos"
                       417 "Muriel" 418 "Partagas" 419 "Phillies"
                       420 "Rigoletto" 421 "Robert Burns" 422 "Roi-Tan"
                       423 "Swisher Sweets" 424 "Tijuana Smalls"
                       426 "White Owl" 427 "William Penn" 428 "Winchester"
                       429 "Al Capone" 431 "Arturo Fuente" 432 "Ashton"
                       434 "Baccarat" 437 "Blackstone" 441 "Cherry Blend"
                       443 "Cohiba" 445 "Corona, brand unspecified"
                       447 "Cremosa Cubanos" 448 "Cuban, brand unspecified"
                       452 "Don Diego" 457 "Don Thomas" 458 "Dunhill Cigars"
                       464 "H. Upmann" 465 "Habana/Havana, brand unspecified"
                       469 "Hoya De Monterrey" 476 "La Gloria Cubana"
                       486 "Montecristo" 488 "Optimo" 492 "Primetime"
                       493 "Prince Albert Cigars" 494 "Punch"
                       496 "Romeo y Julieta"
                       1999 "Cigarette, brand otherwise unspecified"
                       4001 "Sweets, brand unspecified"
                       4002 "Tampa, brand unspecified" 4003 "Te Amo"
                       4005 "Thompson" 4006 "Tiparillo" 4009 "Bahia"
                       4999 "Cigar/Cigarillo, brand otherwise unspecified"
                       9000 "Did not confirm brand"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CIGARS"
                       9993 "DID NOT USE CIGARS IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define PIPEVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define PIPE30DY  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED PIPE TOBACCO" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define ALCEVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define ALCTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALCYFU    9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED ALCOHOL" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define ALCMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALTOTFG   1 "Trimmed to 365 days (no further editing)"
                       2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define ALFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define ALBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALDAYPYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALDAYPMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCDAYS   85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALDYSFG   1 "Edited for consistency with ALCYRTOT or DR5DAY"
                       98 "BLANK (NO ANSWER)" ;
label define NODR30A   975 "AT LEAST 5 Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define DR5DAY    80 "NO OCCAS OF 5+ DRINKS PST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJEVER    1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define MJAGE     985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJYFU     9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED MARIJUANA" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (MJAGE<AGE-1)" ;
label define MJMFU     1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MJREC     1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED MARIJUANA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJYRTOT   985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MRTOTFG   1 "Trimmed to 365 days (no further editing)"
                       2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define MJFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define MRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRDAYPYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MRDAYPMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MJDAY30A  85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCEVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define COCAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define COCYFU    9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn (COCAGE<AGE-1)"
                       9991 "NEVER USED COCAINE" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (COCAGE<AGE-1)" ;
label define COCMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED COCAINE" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       11 "Used in the past 30 days LOGICALLY ASSIGNED"
                       12 "Used >30 days ago but within pst 12 mos LOG ASSN"
                       91 "NEVER USED COCAINE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define COCYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE"
                       993 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CCTOTFG   1 "Trimmed to 365 days (no further editing)"
                       2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define CCFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define CCBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       21 "Prefer to ans in days per wk (CRBSTWAY=1,11)"
                       22 "Prefer to ans in days per mo (CRBSTWAY=2,12)"
                       23 "Prefer to ans in days per yr (CRBSTWAY=3,13)"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCDAYPYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED COCAINE"
                       993 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CCDAYPMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CCDAYPWK  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCUS30A  85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CRKEVER   1 "Yes" 2 "No" 91 "NEVER USED COCAINE (COCEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CRKAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define CRKYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CRACK" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (CRKAGE<AGE-1)" ;
label define CRKMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRAKREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED CRACK" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CRKYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CRTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define CRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define CRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CRDAYPYR  989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CRDAYPMO  85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRDAYPWK  85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRKUS30A  85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEREVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define HERAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HERYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HEROIN" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (HERAGE<AGE-1)" ;
label define HERMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN"
                       993 "DID NOT USE HEROIN IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HRTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define HRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define HRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRDAYPYR  991 "NEVER USED HEROIN"
                       993 "DID NOT USE HEROIN PAST 12 MOS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define HRDAYPMO  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HRDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HER30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 30 DAYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSD       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define PCP       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define PEYOTE    1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define MESC      1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define PSILCY    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define ECSTASY   1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define HALNOLST  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define HALNEWA   112 "Restoril, Temazepam"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       142 "Belladona" 174 "Ambien, Zolpidem"
                       187 "Belladona plant/flower/root, deadly nightshade"
                       209 "Xanax, Alprazolam" 267 "Marezine"
                       268 "Rohypnol, Roche, roofies" 283 "Paroxetine, Paxil"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       324 "Uppers; OTHER Stimulant, NOT OTHERWISE SPECIFIED"
                       326 "White cross" 345 "Black Molly" 348 "Crystal"
                       355 "Crystal meth" 386 "Herbal ecstacy"
                       417 "Morphine, Roxanol"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       501 "Gasoline or lighter fluids" 502 "Spray paints"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liquid, glue, or toluene"
                       505 "Lacquer thinner or other paint solvents"
                       506 "Amyl nitrite,'poppers,'locker room odorizer,'rush'"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 512 "Incense"
                       516 "Freon, refrigerant"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       520 "Old paint, paint" 524 "White-Out"
                       542 "Brasso, lens cleaner, spirits of ammonia"
                       566 "Smoked tea from Lipton tea bag"
                       601 "LSD ('acid')" 602 "Peyote" 603 "Mescaline"
                       604 "Psilocybin (mushrooms), shrooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       609 "Jimson weed"
                       614 "MDA, Methylenedioxy amphetamine"
                       615 "Homemade drugs"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds, morning glory tendrils"
                       618 "Acid paper, blotter (acid)"
                       622 "Microdot(s), green microdot, purple microdot"
                       624 "Orange sunshine, sunshine, yellow sunshine"
                       625 "Window, window pane, 4-way pane"
                       627 "Hawaiian wood rose, Hawaiian Woodrow seeds"
                       635 "Ginseng seeds, ginseng weed" 636 "DOM, STP"
                       639 "Nutmeg, Mace" 645 "Thai stick" 650 "Daytura"
                       658 "Special K, Ketamine" 659 "Boat"
                       660 "Toad, Toad licking" 678 "Banana peels"
                       679 "Hell bells" 695 "Angel's trumpet"
                       698 "Nexus, 2C-B" 703 "Opium" 706 "Smack"
                       802 "THC, cannabinol, marinol"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed"
                       809 "Pills" 828 "Tetracycline"
                       829 "Robitussin DM <OTC>"
                       840 "Cough medicine (contents not specified) <OTC>"
                       847 "GHB" 852 "sic" 876 "Glass"
                       883 "Dextromethorphan Hydrobromide <OTC>"
                       900 "Not a drug, Non-drug reason given for a drug"
                       1002 "Dramamine, seasick/motion sickness pill <OTC>"
                       3044 "Caffeine pills <OTC>"
                       3052 "Speed, otherwise unspecified" 4041 "Maxalt"
                       5009 "Robo" 5032 "Nitrogen"
                       6022 "Tequila worm, agave worm" 6029 "DXM"
                       6031 "Strychnine" 6037 "Fry" 6043 "Salviadivinorum"
                       6044 "Gel caps, gel tabs" 6054 "Spiney apples"
                       6055 "Liberty caps" 6056 "Wet" 6057 "Silk"
                       6059 "Satan flower" 6060 "Ololiuhqui"
                       6062 "Madderwort, Wormwood" 6064 "Marigold buttons"
                       6065 "3CPO" 6068 "Blue ice" 6070 "DTP" 6072 "JUNO"
                       6074 "LSA" 6075 "Trinity" 8002 "Zantac"
                       8008 "Antidepressant; type unspecified"
                       8011 "Herb, flower, plant; type unspecified"
                       8012 "Coriciden <OTC>"
                       8024 "Asthma inhaler,asthma medication,bronchial dilator"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWB   267 "Marezine" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       355 "Crystal meth" 407 "Demerol" 502 "Spray paints"
                       504 "Shoeshine liquid, glue, or toluene"
                       505 "Lacquer thinner or other paint solvents"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       511 "Markers, felt-tip pens, ink pens" 519 "Helium"
                       520 "Old paint, paint" 525 "Butane" 601 "LSD ('acid')"
                       603 "Mescaline" 604 "Psilocybin (mushrooms), shrooms"
                       607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       609 "Jimson weed"
                       614 "MDA, Methylenedioxy amphetamine"
                       617 "Morning glory seeds, morning glory tendrils"
                       622 "Microdot(s), green microdot, purple microdot"
                       625 "Window, window pane, 4-way pane" 636 "DOM, STP"
                       640 "Purple pyramid" 658 "Special K, Ketamine"
                       659 "Boat" 660 "Toad, Toad licking"
                       705 "Speed Ball (heroin + cocaine)"
                       802 "THC, cannabinol, marinol"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed"
                       815 "Coffee <OTC>" 829 "Robitussin DM <OTC>"
                       900 "Not a drug, Non-drug reason given for a drug"
                       1002 "Dramamine, seasick/motion sickness pill <OTC>"
                       3052 "Speed, otherwise unspecified" 4007 "Happy pills"
                       5001 "Bleach" 6038 "Triplets, trips"
                       6044 "Gel caps, gel tabs" 6056 "Wet"
                       6058 "Purple life" 6061 "5-MeO-DMT"
                       6062 "Madderwort, Wormwood" 6065 "3CPO"
                       6071 "Sinicuichi"
                       8024 "Asthma inhaler,asthma medication,bronchial dilator"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWC   508 "Nitrous oxide, 'whippets,' dentist gas"
                       509 "Correction fluids, degreasers, cleaning fluids"
                       519 "Helium" 526 "Nail polish"
                       604 "Psilocybin (mushrooms), shrooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       609 "Jimson weed" 616 "DET, Dimethyltryptamine, DMT"
                       625 "Window, window pane, 4-way pane"
                       658 "Special K, Ketamine" 660 "Toad, Toad licking"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed"
                       805 "Cocaine, coca, cocana, coke" 815 "Coffee <OTC>"
                       819 "Inderal" 3052 "Speed, otherwise unspecified"
                       6044 "Gel caps, gel tabs" 6063 "Foxglove"
                       8024 "Asthma inhaler,asthma medication,bronchial dilator"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWD   324 "Uppers; OTHER Stimulant, NOT OTHERWISE SPECIFIED"
                       519 "Helium" 601 "LSD ('acid')" 609 "Jimson weed"
                       3052 "Speed, otherwise unspecified"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWE   803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed"
                       3052 "Speed, otherwise unspecified"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALLAGE   985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (HALLAGE<AGE-1)" ;
label define HALMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HALLREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       11 "Used in the past 30 days LOGICALLY ASSIGNED"
                       12 "Used >30 days ago but within pst 12 mos LOG ASSN"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS"
                       993 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HLTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define HLFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define HLBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLDAYPYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED HALLUCINOGENS"
                       993 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLDAYPMO  89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLDAYPWK  91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HAL30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED LSD" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED PCP" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AMYLNIT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define CLEFLU    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define GAS       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GLUE      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ETHER     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVENT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LGAS      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NITOXID   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Yes" 2 "No" 91 "NEVER USED INHALANTS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHNOLST  1 "Yes" 2 "No" 91 "NEVER USED INHALANTS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHNEWA   377 "Albuterol, Proventil, Ventolin"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liquid, glue, or toluene"
                       505 "Lacquer thinner or other paint solvents"
                       506 "Amyl nitrite,'poppers,'locker room odorizer,'rush'"
                       507 "Halothane, ether, or other anesthetics; chloroform"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       509 "Correction fluids, degreasers, cleaning fluids"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens"
                       516 "Freon, refrigerant"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       520 "Old paint, paint"
                       522 "Liquid TV (MTV), TV tuner, TV11Y" 524 "White-Out"
                       525 "Butane" 526 "Nail polish" 528 "Whipped-cream can"
                       534 "Deodorant" 539 "ScotchGard" 540 "PAM"
                       542 "Brasso, lens cleaner, spirits of ammonia"
                       543 "Liquid oxygen, oxygen"
                       545 "Car tailpipe exhaust fumes, CO"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       566 "Smoked tea from Lipton tea bag"
                       577 "Rave runners" 588 "Antifreeze" 589 "Tire shine"
                       590 "Canned air" 591 "Air brush propellent"
                       592 "Computer air duster, computer cleaner, dust-off"
                       599 "Potpourri" 691 "Maximum impact"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       3051 "Betel nut, Beetlenut" 5001 "Bleach"
                       5019 "Melted plastic" 5021 "Octane booster"
                       5022 "Dry ice hits" 5023 "Double eagle"
                       5024 "Citronella candle" 5025 "Lime salt"
                       5026 "Silly putty" 5027 "Benzene"
                       5028 "Engine cleaner" 5030 "Polyurethane Spray"
                       5031 "Naphtha" 5033 "Sur-noxem" 5035 "Brake cleaner"
                       8011 "Herb, flower, plant; type unspecified"
                       8024 "Asthma inhaler,asthma medication,bronchial dilator"
                       8028 "Bactine <OTC>"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHNEWB   268 "Rohypnol, Roche, roofies"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liquid, glue, or toluene"
                       505 "Lacquer thinner or other paint solvents"
                       506 "Amyl nitrite,'poppers,'locker room odorizer,'rush'"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       509 "Correction fluids, degreasers, cleaning fluids"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens"
                       516 "Freon, refrigerant"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       520 "Old paint, paint" 524 "White-Out"
                       526 "Nail polish" 528 "Whipped-cream can" 540 "PAM"
                       545 "Car tailpipe exhaust fumes, CO"
                       592 "Computer air duster, computer cleaner, dust-off"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       826 "Alupent" 5001 "Bleach" 5029 "Floor wax"
                       5034 "Hippie crack"
                       8024 "Asthma inhaler,asthma medication,bronchial dilator"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHNEWC   503 "Other aerosol sprays"
                       504 "Shoeshine liquid, glue, or toluene"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       526 "Nail polish" 540 "PAM"
                       900 "Not a drug, Non-drug reason given for a drug"
                       5001 "Bleach" 9991 "NEVER USED INHALANTS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define INHNEWD   503 "Other aerosol sprays"
                       509 "Correction fluids, degreasers, cleaning fluids"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       526 "Nail polish" 540 "PAM"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHNEWE   504 "Shoeshine liquid, glue, or toluene" 519 "Helium"
                       524 "White-Out" 9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INHYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (INHAGE<AGE-1)" ;
label define INHMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define INHREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define INFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define INBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INDAYPYR  989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define INDAYPMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INHDY30A  85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DARVTYLC  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PERCTYLX  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define VICOLOR   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CODEINE   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEMEROL   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DILAUD    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FIORICET  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FIORINAL  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HYDROCOD  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHDON   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MORPHINE  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OXYCONTN  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHENCOD   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PROPOXY   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SK65A     1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STADOL    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TALACEN   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TALWIN    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TALWINNX  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRAMADOL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ULTRAM    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLNOLST  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       121 "USED SEDATIVE, DON'T KNOW NAME"
                       124 "Yellow jackets" 130 "Phenergan"
                       131 "Haldol, Haloperidol" 136 "Dimetapp <OTC>"
                       138 "Mandrakes" 157 "Barbiturates" 171 "NyQuil <OTC>"
                       174 "Ambien, Zolpidem" 184 "Red and blues"
                       186 "Butalbital" 201 "Valium, Diazepam"
                       202 "Librium, Chlordiazepoxide HCL" 205 "Serax"
                       207 "Ativan , Lorazapam" 209 "Xanax, Alprazolam"
                       211 "Buspar" 216 "Atarax , Hydroxyzine"
                       225 "Desyrel, Trazodone hydrochloride"
                       228 "Amitriptyline, Elavil"
                       234 "Cyclobenzaprine, Flexeril"
                       240 "Lithium carbonate, Lithonate" 241 "Prozac"
                       246 "Clonazepam, Klonopin"
                       268 "Rohypnol, Roche, roofies" 271 "Zoloft"
                       285 "Risperdal, resperidone" 288 "Baclofen"
                       290 "Skelaxin" 301 "Dexedrine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       339 "Amphetamines" 353 "No-Doz <OTC>"
                       364 "Pseudophedrine"
                       377 "Albuterol, Proventil, Ventolin"
                       382 "Footballs, purple footballs" 401 "Darvon"
                       403 "SK-65" 406 "Percodan" 407 "Demerol"
                       408 "Dilaudid"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       411 "Talwin" 414 "Propoxyphene" 415 "Codeine"
                       417 "Morphine, Roxanol" 418 "Dolophine, Methadone"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 424 "Fioricet" 425 "Advil <OTC>"
                       426 "Fiorinal" 427 "Darvocet"
                       430 "Aspirin, Ecotrin, Empirin <OTC>" 431 "Tylox"
                       434 "Anexsia, Co-Gesic, Lortab, Tussionex, Vicodin"
                       438 "Anaprox, Naprosyn, Naproxen" 442 "Ibuprofen"
                       445 "Norgesic Forte" 458 "Mepergan, Mepergan Fortis"
                       462 "Norflex" 476 "Isocom, Midrin"
                       480 "Robitussin AC with Codeine" 490 "Nubain"
                       496 "Ultram" 499 "Aleve <OTC>" 540 "PAM"
                       601 "LSD ('acid')" 802 "THC, cannabinol, marinol"
                       820 "Penicillin" 821 "Amoxicillin, Ampicillin"
                       840 "Cough medicine (contents not specified) <OTC>"
                       858 "Antibiotic" 895 "Tagamet, Cimetidine" 2001 "Soma"
                       2002 "Muscle Relaxers" 3023 "Adderall"
                       3052 "Speed, otherwise unspecified"
                       4001 "Actron, Ketoprofen, Orudis, Oruvail"
                       4005 "Etodolac, Lodine" 4027 "Rorer"
                       4031 "Cough medicine with codeine" 4032 "Flarex"
                       4033 "Vicoprofen" 4034 "Lilly red"
                       4035 "Nabumetone, Relafin" 4036 "Stagesic"
                       4039 "Daypro" 4040 "Ridaura" 4044 "Hydrocodone"
                       4045 "Phrenilin Forte" 4046 "Oxycodone" 4047 "Roxicet"
                       8002 "Zantac" 8008 "Antidepressant; type unspecified"
                       8009 "Allergy pills; type unspecified"
                       8010 "Zyrtec, cetirizine"
                       8019 "Azithromycin, Zithromax"
                       8024 "Asthma inhaler,asthma medication,bronchial dilator"
                       8025 "Claritin, Claritin D" 8032 "Prilosec"
                       8033 "Heart medication, type unspecified"
                       8040 "Trioxsalen"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWB  109 "Seconal" 110 "Tuinal"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       137 "7-14" 157 "Barbiturates" 171 "NyQuil <OTC>"
                       174 "Ambien, Zolpidem" 182 "Melzone" 183 "Mysoline"
                       201 "Valium, Diazepam" 209 "Xanax, Alprazolam"
                       221 "OTHER Tranquilizer, NOT OTHERWISE SPECIFIED"
                       225 "Desyrel, Trazodone hydrochloride" 241 "Prozac"
                       246 "Clonazepam, Klonopin"
                       268 "Rohypnol, Roche, roofies" 292 "Serzone"
                       301 "Dexedrine" 318 "Ritalin, Methylphenidate"
                       327 "Black beauties, Black Beauty" 352 "Lemons"
                       353 "No-Doz <OTC>" 354 "Vivarin <OTC>"
                       364 "Pseudophedrine" 406 "Percodan" 407 "Demerol"
                       408 "Dilaudid"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       410 "Phenaphen with Codeine, Phenaphen 3" 411 "Talwin"
                       415 "Codeine"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 427 "Darvocet"
                       434 "Anexsia, Co-Gesic, Lortab, Tussionex, Vicodin"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       438 "Anaprox, Naprosyn, Naproxen"
                       439 "222, Canadian 222" 442 "Ibuprofen" 496 "Ultram"
                       821 "Amoxicillin, Ampicillin" 2001 "Soma"
                       3023 "Adderall" 3052 "Speed, otherwise unspecified"
                       4005 "Etodolac, Lodine"
                       4011 "Carbamazepine, Epital, Tegretol" 4047 "Roxicet"
                       8021 "Cipro, Ciprofloxacin, Cliloxam"
                       8025 "Claritin, Claritin D" 8030 "Tums <OTC>"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWC  103 "Amytal" 105 "Placidyl" 110 "Tuinal"
                       116 "Methaqualone, Quaalude, Sopor"
                       174 "Ambien, Zolpidem" 201 "Valium, Diazepam"
                       209 "Xanax, Alprazolam" 318 "Ritalin, Methylphenidate"
                       327 "Black beauties, Black Beauty" 353 "No-Doz <OTC>"
                       369 "Artane" 401 "Darvon" 407 "Demerol"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       415 "Codeine" 417 "Morphine, Roxanol"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME"
                       434 "Anexsia, Co-Gesic, Lortab, Tussionex, Vicodin"
                       438 "Anaprox, Naprosyn, Naproxen"
                       821 "Amoxicillin, Ampicillin" 2001 "Soma"
                       3044 "Caffeine pills <OTC>"
                       8025 "Claritin, Claritin D" 8031 "Sugar pills"
                       8036 "Norvasc"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWD  110 "Tuinal" 116 "Methaqualone, Quaalude, Sopor"
                       209 "Xanax, Alprazolam" 407 "Demerol"
                       434 "Anexsia, Co-Gesic, Lortab, Tussionex, Vicodin"
                       3026 "Bupropion, Wellbutrin, Zyban"
                       3044 "Caffeine pills <OTC>"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWE  103 "Amytal"
                       329 "Bird's eggs, Robin's eggs, speckled eggs"
                       418 "Dolophine, Methadone"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALAGE   981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED PAIN RELIEVERS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ANALYFU   9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define ANALMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANALREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANLYRTOT  981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED PAIN RELIEVERS"
                       993 "DID NOT USE PAIN RELIEVERS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define PRTOTFG   98 "BLANK (NO ANSWER)" ;
label define PRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define PRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRDAYPYR  981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED PAIN RELIEVERS"
                       993 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define PRDAYPMO  81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PRDAYPWK  81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define KLONOPIN  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define XNAXATVN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define VALMDIAZ  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ATARAX    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BUSPAR    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EQUANIL   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FLEXERIL  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LIBRIUM   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LIMBTROL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MEPROB    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MILTOWN   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ROHYPNOL  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SERAX     1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SOMA      1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRANXENE  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VISTAR    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRNOLST   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       111 "Dalmane, Flurazepam" 113 "Halcion"
                       115 "Phenobarbital"
                       116 "Methaqualone, Quaalude, Sopor"
                       124 "Yellow jackets" 129 "Reds" 137 "7-14"
                       174 "Ambien, Zolpidem" 201 "Valium, Diazepam"
                       207 "Ativan , Lorazapam" 209 "Xanax, Alprazolam"
                       211 "Buspar" 215 "Vistaril"
                       221 "OTHER Tranquilizer, NOT OTHERWISE SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       223 "Carbacot, Marbaxin, Methocarbamol"
                       225 "Desyrel, Trazodone hydrochloride" 227 "Thorazine"
                       228 "Amitriptyline, Elavil" 229 "Librax"
                       233 "Trilafon, Perphenazine"
                       234 "Cyclobenzaprine, Flexeril"
                       240 "Lithium carbonate, Lithonate" 241 "Prozac"
                       246 "Clonazepam, Klonopin"
                       247 "Adapin, Doxepin, Sinequan"
                       268 "Rohypnol, Roche, roofies" 271 "Zoloft"
                       283 "Paroxetine, Paxil" 302 "Dexamyl"
                       318 "Ritalin, Methylphenidate" 406 "Percodan"
                       415 "Codeine" 417 "Morphine, Roxanol"
                       434 "Anexsia, Co-Gesic, Lortab, Tussionex, Vicodin"
                       438 "Anaprox, Naprosyn, Naproxen"
                       658 "Special K, Ketamine"
                       663 "Animal tranquilizer, horse tranquilizer"
                       2001 "Soma" 2002 "Muscle Relaxers" 3023 "Adderall"
                       4027 "Rorer" 8017 "Buscapina"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWB    110 "Tuinal"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       137 "7-14" 201 "Valium, Diazepam"
                       207 "Ativan , Lorazapam" 209 "Xanax, Alprazolam"
                       211 "Buspar" 222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       225 "Desyrel, Trazodone hydrochloride" 227 "Thorazine"
                       228 "Amitriptyline, Elavil"
                       240 "Lithium carbonate, Lithonate"
                       250 "Aventyl, Nortriptyline, Pamelor"
                       268 "Rohypnol, Roche, roofies"
                       318 "Ritalin, Methylphenidate" 363 "Bam(s)"
                       406 "Percodan"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       663 "Animal tranquilizer, horse tranquilizer"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWC    110 "Tuinal" 201 "Valium, Diazepam"
                       207 "Ativan , Lorazapam" 241 "Prozac" 363 "Bam(s)"
                       425 "Advil <OTC>"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWD    430 "Aspirin, Ecotrin, Empirin <OTC>"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWE    9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRANAGE   981 "NEVER USED TRANQUILIZERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TRANYFU   9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (TRANAGE<AGE-1)" ;
label define TRANMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRANREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRNYRTOT  981 "NEVER USED TRANQUILIZERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS"
                       993 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TRTOTFG   98 "BLANK (NO ANSWER)" ;
label define TRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define TRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRDAYPYR  981 "NEVER USED TRANQUILIZERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED TRANQUILIZERS"
                       993 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TRDAYPMO  81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRDAYPWK  81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHDES   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DIETPILS  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RITMPHEN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CYLERT    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEXED     1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DETAMP    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DIDREX    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ESKAT     1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IONAMIN   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MAZANOR   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OBLA      1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PLEGINE   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PRELUDIN  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SANOREX   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TENUATE   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STMNOLST  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  112 "Restoril, Temazepam" 209 "Xanax, Alprazolam"
                       240 "Lithium carbonate, Lithonate" 241 "Prozac"
                       268 "Rohypnol, Roche, roofies" 271 "Zoloft"
                       301 "Dexedrine" 302 "Dexamyl" 306 "Desoxyn"
                       312 "Ionamin" 313 "Adipex-P, Fastin, Phentermine"
                       317 "Mazanor" 318 "Ritalin, Methylphenidate"
                       320 "Dextroamphetamine"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       324 "Uppers; OTHER Stimulant, NOT OTHERWISE SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts"
                       329 "Bird's eggs, Robin's eggs, speckled eggs"
                       330 "Blue birds, blue jays, blue robins, speckled bird"
                       331 "Blancs, Whites" 332 "Ma huang, Ephedrine"
                       333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops" 339 "Amphetamines"
                       345 "Black Molly" 348 "Crystal" 353 "No-Doz <OTC>"
                       355 "Crystal meth" 363 "Bam(s)" 364 "Pseudophedrine"
                       366 "Duromine" 374 "Christmas tree(s)"
                       396 "Black Rjs, RJ8" 414 "Propoxyphene"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       3015 "Fen-Phen (fenfluramine and phentermine)"
                       3023 "Adderall" 3026 "Bupropion, Wellbutrin, Zyban"
                       3028 "Blackbirds"
                       3031 "Brethine, Bricanyl, Terbutaline" 3032 "Heads up"
                       3035 "Blacks" 3038 "Obenil" 3039 "Theophed"
                       3040 "Hyper pills" 3041 "Desbutal" 3050 "Mini Thins"
                       3052 "Speed, otherwise unspecified"
                       8039 "Kaopectate <OTC>"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWB  116 "Methaqualone, Quaalude, Sopor"
                       124 "Yellow jackets" 209 "Xanax, Alprazolam"
                       285 "Risperdal, resperidone" 301 "Dexedrine"
                       306 "Desoxyn" 325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       329 "Bird's eggs, Robin's eggs, speckled eggs"
                       336 "Diet pills" 374 "Christmas tree(s)"
                       408 "Dilaudid" 3023 "Adderall" 3029 "Soccerballs"
                       3037 "Effexor" 3042 "30-30" 3043 "Brown Bodies"
                       3050 "Mini Thins" 3052 "Speed, otherwise unspecified"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWC  201 "Valium, Diazepam" 241 "Prozac" 271 "Zoloft"
                       324 "Uppers; OTHER Stimulant, NOT OTHERWISE SPECIFIED"
                       331 "Blancs, Whites" 3023 "Adderall"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWD  201 "Valium, Diazepam"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWE  9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMAGE   981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STIMYFU   9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn (STIMAGE<AGE-1)"
                       9991 "NEVER USED STIMULANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (STIMAGE<AGE-1)" ;
label define STIMMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STIMREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       11 "Used in the past 30 days LOGICALLY ASSIGNED"
                       12 "Used >30 days ago but within pst 12 mos LOG ASSN"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STMYRTOT  981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS"
                       993 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STTOTFG   98 "BLANK (NO ANSWER)" ;
label define STFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define STBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STDAYPYR  981 "NEVER USED STIMULANTS Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED STIMULANTS"
                       993 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define STDAYPMO  81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STDAYPWK  81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHAGE   981 "NEVER USED METHAMPHETAMINES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED METHAMPHETAMINES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define METHYFU   9981 "NEVER USED METHAMPHETAMINES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED METHAMPHETAMINES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (METHAGE<AGE-1)" ;
label define METHMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED METHAMPHETAMINES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED METHAMPHETAMINES Logically assigned"
                       91 "NEVER USED METHAMPHETAMINES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NEMBBARB  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RESTTMAZ  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AMYTAL    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define BUTISOL   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CHHYD     1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DALMANE   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HALCION   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PHENOBAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PLACIDYL  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TUINAL    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDNOLST  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   105 "Placidyl" 110 "Tuinal" 115 "Phenobarbital"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       121 "USED SEDATIVE, DON'T KNOW NAME"
                       174 "Ambien, Zolpidem" 182 "Melzone"
                       201 "Valium, Diazepam" 209 "Xanax, Alprazolam"
                       220 "Meprobamate, Meprospan"
                       225 "Desyrel, Trazodone hydrochloride" 227 "Thorazine"
                       228 "Amitriptyline, Elavil"
                       234 "Cyclobenzaprine, Flexeril" 241 "Prozac"
                       246 "Clonazepam, Klonopin"
                       247 "Adapin, Doxepin, Sinequan"
                       268 "Rohypnol, Roche, roofies" 271 "Zoloft"
                       283 "Paroxetine, Paxil"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       417 "Morphine, Roxanol" 418 "Dolophine, Methadone"
                       2001 "Soma" 8002 "Zantac"
                       8011 "Herb, flower, plant; type unspecified"
                       8025 "Claritin, Claritin D"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWB   105 "Placidyl" 201 "Valium, Diazepam"
                       225 "Desyrel, Trazodone hydrochloride"
                       268 "Rohypnol, Roche, roofies"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWC   9981 "NEVER USED SEDATIVES Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWD   9981 "NEVER USED SEDATIVES Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWE   9981 "NEVER USED SEDATIVES Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDAGE    981 "NEVER USED SEDATIVES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED SEDATIVES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SEDYFU    9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP (SEDAGE<AGE-1)" ;
label define SEDMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDYRTOT  981 "NEVER USED SEDATIVES Logically assigned"
                       991 "NEVER USED SEDATIVES"
                       993 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SVTOTFG   98 "BLANK (NO ANSWER)" ;
label define SVFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define SVBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SVDAYPYR  981 "NEVER USED SEDATIVES Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED SEDATIVES"
                       993 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SVDAYPMO  81 "NEVER USED SEDATIVES Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SVDAYPWK  81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IRCIGRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CIGRC  1 "Questionnaire data"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRCGRRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never smoked cigars" ;
label define IICGRRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2CGRRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRPIPLF   1 "Ever used pipes" 9 "Never smoked pipes" ;
label define IIPIPLF   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPIPMN   1 "Within the past 30 days"
                       2 "More than 30 days ago but within lifetime"
                       9 "Never smoked pipes" ;
label define IIPIPMN   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSLTRC   1 "Within the past 30 days"
                       2 "More than 30 days age but within the past 12 mos"
                       3 "More than 12 months age but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Never used smokeless tobacco" ;
label define IISLTRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2SLTRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRCHWRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Never used chewing tobacco" ;
label define IICHWRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CHWRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRSNFRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used snuff" ;
label define IISNFRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2SNFRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRALCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2ALCRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRMJRC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2MJRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRCOCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2COCRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRCRKRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used CRACK" ;
label define IICRKRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2CRKRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRHERRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2HERRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRHALRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2HALRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRLSDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used LSD" ;
label define IILSDRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2LSDRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRPCPRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2PCPRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9" ;
label define IRINHRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2INHRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRANLRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used pain relievers" ;
label define IIANLRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2ANLRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRTRNRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2TRNRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRSTMRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2STMRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRMTHRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used methamphetamines" ;
label define IIMTHRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2MTHRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRSEDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2SEDRC  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9" ;
label define IRALCFY   991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL PAST YEAR" ;
label define IIALCFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2ALCFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRMJFY    991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA PAST YEAR" ;
label define IIMJFY    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2MJFY   1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCOCFY   991 "NEVER USED COCAINE"
                       993 "DID NOT USE COCAINE PAST YEAR" ;
label define IICOCFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2COCFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCRKFY   991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK PAST YEAR" ;
label define IICRKFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CRKFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHERFY   991 "NEVER USED HEROIN"
                       993 "DID NOT USE HEROIN PAST YEAR" ;
label define IIHERFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2HERFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHALFY   991 "NEVER USED HALLUCINOGENS"
                       993 "DID NOT USE HALLUCINOGENS PAST YEAR" ;
label define IIHALFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2HALFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRINHFY   991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST YEAR" ;
label define IIINHFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2INHFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRANLFY   991 "NEVER USED PAIN RELIEVERS"
                       993 "DID NOT USE PAIN RELIEVERS PAST YEAR" ;
label define IIANLFY   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2ANLFY  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRTRNFY   991 "NEVER USED TRANQUILIZERS"
                       993 "DID NOT USE TRANQUILIZERS PAST YEAR" ;
label define IITRNFY   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2TRNFY  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRSTMFY   991 "NEVER USED STIMULANTS"
                       993 "DID NOT USE STIMULANTS PAST YEAR" ;
label define IISTMFY   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2STMFY  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRSEDFY   991 "NEVER USED SEDATIVES"
                       993 "DID NOT USE SEDATIVES PAST YEAR" ;
label define IISEDFY   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2SEDFY  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCIGFM   91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH" ;
label define IICIGFM   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2CIGFM  1 "Questionnaire data" 2 "Logically imputed data"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCGRFM   91.00 "NEVER SMOKED CIGARS"
                       93.00 "DID NOT SMOKE CIGARS PAST MONTH" ;
label define IICGRFM   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2CGRFM  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCHWFM   91 "NEVER USED CHEWING TOBACCO"
                       93 "DID NOT USE CHEWING TOBACCO PAST MONTH" ;
label define IICHWFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CHWFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRSNFFM   91 "NEVER USED SNUFF"
                       93 "DID NOT USE SNUFF PAST MONTH" ;
label define IISNFFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2SNFFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRALCFM   91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL PAST MONTH" ;
label define IIALCFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2ALCFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRALCD5   91 "NEVER USED ALCOHOL"
                       93 "DID NOT HAVE 5+ ALC DRNKS PAST MONTH" ;
label define IIALCD5   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2ALCD5  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRMJFM    91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA PAST MONTH" ;
label define IIMJFM    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2MJFM   1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCOCFM   91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PAST MONTH" ;
label define IICOCFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2COCFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCRKFM   91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK PAST MONTH" ;
label define IICRKFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CRKFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHERFM   91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST MONTH" ;
label define IIHERFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2HERFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHALFM   91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PAST MONTH" ;
label define IIHALFM   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define II2HALFM  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRINHFM   91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PAST MONTH" ;
label define IIINHFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2INHFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCIGAGE  991 "NEVER USED" ;
label define IICIGAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCIGYFU  9999 "NEVER USED" ;
label define IICIGYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCDUAGE  991 "NEVER USED" 993 "NEVER USED CIGARETTES DAILY" ;
label define IICDUAGE  1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "Legitimate skip" ;
label define IRCDUYFU  9993 "NEVER A DAILY USER" 9999 "NEVER USED" ;
label define IICDUYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCGRAGE  991 "NEVER USED" ;
label define IICGRAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCGRYFU  9999 "NEVER USED" ;
label define IICGRYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRSNFAGE  991 "Never Used" ;
label define IISNFAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRSNFYFU  9999 "NEVER USED" ;
label define IISNFYFU  1 "Questionnaire Data" 3 "Statistical Imputation" ;
label define IRCHWAGE  991 "NEVER USED" ;
label define IICHWAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCHWYFU  9999 "Never Used" ;
label define IICHWYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRSLTAGE  991 "Never Used" ;
label define IISLTAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRSLTYFU  9999 "Never Used" ;
label define IISLTYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRALCAGE  991 "Never Used" ;
label define IIALCAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRALCYFU  9999 "NEVER USED" ;
label define IIALCYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRMJAGE   991 "Never Used" ;
label define IIMJAGE   1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRMJYFU   9999 "Never Used" ;
label define IIMJYFU   1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCOCAGE  991 "Never Used" ;
label define IICOCAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCOCYFU  9999 "Never Used" ;
label define IICOCYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRCRKAGE  991 "Never Used" ;
label define IICRKAGE  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRCRKYFU  9999 "Never Used" ;
label define IICRKYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRHERAGE  991 "Never Used" ;
label define IIHERAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRHERYFU  9999 "Never Used" ;
label define IIHERYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRHALAGE  991 "Never Used" ;
label define IIHALAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRHALYFU  9999 "Never Used" ;
label define IIHALYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRINHAGE  991 "Never Used" ;
label define IIINHAGE  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRINHYFU  9999 "Never Used" ;
label define IIINHYFU  1 "Questionnaire Data" 3 "Statistically Imputed Data" ;
label define IRANLAGE  991 "Never Used" ;
label define IIANLAGE  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRANLYFU  9999 "Never Used" ;
label define IIANLYFU  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRTRNAGE  991 "Never Used" ;
label define IITRNAGE  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRTRNYFU  9999 "Never Used" ;
label define IITRNYFU  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRSTMAGE  991 "Never Used" ;
label define IISTMAGE  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRSTMYFU  9999 "Never Used" ;
label define IISTMYFU  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRMTHAGE  991 "Never Used" ;
label define IIMTHAGE  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRMTHYFU  9999 "Never Used" ;
label define IIMTHYFU  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRSEDAGE  991 "Never Used" ;
label define IISEDAGE  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define IRSEDYFU  9999 "Never Used" ;
label define IISEDYFU  1 "Questionnaire Data" 2 "Logical Edited Data"
                       3 "Statistically Imputed Data" ;
label define CIGFLAG   0 "Never used (IRCIGRC = 9)"
                       1 "Ever used (IRCIGRC = 1-4)" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC = 2-4,9)"
                       1 "Used within the past month (IRCIGRC = 1)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC = 3,4,9)"
                       1 "Used within the past year (IRCIGRC = 1,2)" ;
label define CGRFLAG   0 "Never used (IRCGRRC = 9)"
                       1 "Ever used (IRCGRRC = 1-4)" ;
label define CGRYR     0 "Did not use in the past year (IRCGRRC = 3,4,9)"
                       1 "Used within the past year (IRCGRRC = 1,2)" ;
label define CGRMON    0 "Did not use in the past month (IRCGRRC = 2-4,9)"
                       1 "Used within the past month (IRCGRRC = 1)" ;
label define PIPFLAG   0 "Never Used (IRPIPLF=9)" 1 "Ever Used (IRPIPLF=1)" ;
label define PIPMON    0 "Did not use in the past month (IRPIPMN=2,9)"
                       1 "Used within the past month (IRPIPMN=1)" ;
label define SMKFLAG   0 "Never used (IRSLTRC = 9)"
                       1 "Ever used (IRSLTRC = 1-4)" ;
label define SMKYR     0 "Did not use in the past year (IRSLTRC = 3,4,9)"
                       1 "Used within the past year (IRSLTRC = 1,2)" ;
label define SMKMON    0 "Did not use in the past month (IRSLTRC = 2-4,9)"
                       1 "Used within the past month (IRSLTRC = 1)" ;
label define CHWFLAG   0 "Never Used (IRCHWRC=9)" 1 "Ever Used (IRCHWRC=1-4)" ;
label define CHWYR     0 "Did not use in the past year (IRCHWRC=3,4,9)"
                       1 "Used within the past year (IRCHWRC=1,2)" ;
label define CHWMON    0 "Did not use in the past month (IRCHWRC=2-4,9)"
                       1 "Used within the past month (IRCHWRC=1)" ;
label define SNFFLAG   0 "Never used (IRSNFRC = 9)"
                       1 "Ever used (IRSNFRC = 1-4)" ;
label define SNFYR     0 "Did not use in the past year (IRSNFRC = 3,4,9)"
                       1 "Used within the past year (IRSNFRC = 1,2)" ;
label define SNFMON    0 "Did not use in the past month (IRSNFRC = 2-4,9)"
                       1 "Used within the past month (IRSNFRC = 1)" ;
label define TOBFLAG   0 "Never Used (all source vars=9)"
                       1 "Ever Used (any source var=1-4)" ;
label define TOBYR     0 "Never use pst yr(IRPIPMN=2,9 &oth src vars=3,4,9)"
                       1 "Used pst yr(IRPIPMN=1 or any oth src var=1,2)" ;
label define TOBMON    0 "Did not use in pst month (all source vars=2-4,9)"
                       1 "Used in past month (any source var=1)" ;
label define CIGBRAND  -9 "Not Past Month Cigarette User (CIGMON=0)"
                       1 "Marlboro (CIG30BR2=112)" 2 "Newport (CIG30BR2=118)"
                       3 "Camel (CIG30BR2=104)" 4 "Basic (CIG30BR2=101)"
                       5 "Doral (CIG30BR2=107" 6 "Winston (CIG30BR2=126)"
                       7 "GPC (CIG30BR2=109)" 8 "Kool (CIG30BR2=111)"
                       9 "Virginia Slims (CIG30BR2=125)"
                       10 "Benson & Hedges (CIG30BR2=102)"
                       11 "Salem (CIG30BR2=122)" 12 "Merit (CIG30BR2=113)"
                       13 "Pall Mall (CIG30BR2=119)"
                       14 "Misty (CIG30BR2=114)"
                       15 "Parliament (CIG30BR2=120)"
                       16 "Capri (CIG30BR2=105)"
                       17 "Other Brnd (CIG30BR2=other 100-199,1001-1999)"
                       18 "Unknwn Brnd (CIG30BR2=300-799,4999,9985-9998)" ;
label define CGRBRAND  -9 "Not Past Month Cigar Users (CGRMON=0)"
                       1 "Swisher Sweets (CGR30BR2 = 423)"
                       2 "Black and Mild (CGR30BR2 = 404)"
                       3 "Macanudos (CGR30BR2 = 416)"
                       4 "Garcia Y Vega (CGR30BR2 = 411)"
                       5 "Backwoods (CGR30BR2 = 402)"
                       6 "Phillies (CGR30BR2 = 419)"
                       7 "Dutch Masters (CGR30BR2 = 408)"
                       8 "Antoinio Y Cleopatra (CGR30BR2 = 401)"
                       9 "Partagas (CGR30BR2 = 418)"
                       10 "King Edward (CGR30BR2 = 413)"
                       11 "Havatampa (CGR30BR2 = 412)"
                       12 "Cuba, brand unspecified (CGR30BR2 = 448,449)"
                       13 "Arturo Fuentes (CGR30BR2 = 431)"
                       14 "White Owl (CGR30BR2 = 426)"
                       15 "Montecristo (CGR30BR2 = 486)"
                       16 "Other Brnd (CGR30BR2 =other 400-499,4000-4999)"
                       17 "Unknwn Brnd (CGR30BR2=101-175,9000,9985-9998)" ;
label define SMKBRAND  -9 "Not Past Month Smokeless Tobacco User (SMKMON=0)"
                       1 "Skoal (SLT30BR2=308)" 2 "Copenhagen (SLT30BR2=301)"
                       3 "Kodiak (SLT30BR2=305)" 4 "Red Man (SLT30BR2=208)"
                       5 "Levi Garrett (SLT30BR2=206)"
                       6 "Timber Wolf (SLT30BR2=309)"
                       7 "Beech-Nut (SLT30BR2=201)"
                       8 "Day's Work (SLT30BR2=203)"
                       9 "Chatanooga Chew (SLT30BR2=202)"
                       10 "Other Brand (SLT30BR2=other 200-399,2999,3999)"
                       11 "Unknwn Brnd (SLT30BR2=111,118,701,702,9000-9998)" ;
label define CIGCMPNY  1 "Phillip Morris" 2 "R.J. Reynolds" 3 "Lorillard"
                       4 "Brown and Williamson" 5 "Liggett"
                       6 "Commonwealth Brands"
                       7 "Santa Fe Natural Tobacco Company"
                       70 "SOME OTHER BRAND/COMPANY"
                       80 "CIG BRAND/COMPANY NOT SPECIFIED"
                       85 "BAD DATA Log assn (CIG30BR2=9985)"
                       90 "NOT A CIGARETTE BRAND" 91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW (CIG30BR2=9994)"
                       97 "REFUSED (CIG30BR2=9997)"
                       98 "BLANK (CIG30BR2=9998)" ;
label define ALCFLAG   0 "Never used (IRALCRC = 9)"
                       1 "Ever used (IRALCRC = 1-3)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC = 3,9)"
                       1 "Used within the past year (IRALCRC = 1,2)" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC = 2-3,9)"
                       1 "Used within the past month (IRALCRC = 1)" ;
label define MRJFLAG   0 "Never used (IRMJRC = 9)"
                       1 "Ever used (IRMJRC = 1-3)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC = 3,9)"
                       1 "Used within the past year (IRMJRC = 1,2)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC = 2-3,9)"
                       1 "Used within the past month (IRMJRC = 1)" ;
label define COCFLAG   0 "Never used (IRCOCRC = 9)"
                       1 "Ever used (IRCOCRC = 1-3)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC = 3,9)"
                       1 "Used within the past year (IRCOCRC = 1,2)" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC = 2-3,9)"
                       1 "Used within the past month (IRCOCRC = 1)" ;
label define CRKFLAG   0 "Never used (IRCRKRC = 9)"
                       1 "Ever used (IRCRKRC = 1-3)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKRC = 3,9)"
                       1 "Used within the past year (IRCRKRC = 1,2)" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC = 2-3,9)"
                       1 "Used within the past month (IRCRKRC = 1)" ;
label define HERFLAG   0 "Never used (IRHERRC = 9)"
                       1 "Ever used (IRHERRC = 1-3)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC = 3,9)"
                       1 "Used within the past year (IRHERRC = 1,2)" ;
label define HERMON    0 "Did not use in the past month (IRHERRC = 2-3,9)"
                       1 "Used within the past month (IRHERRC = 1)" ;
label define HALFLAG   0 "Never used (IRHALRC = 9)"
                       1 "Ever used (IRHALRC = 1-3)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC = 3,9)"
                       1 "Used within the past year (IRHALRC = 1,2)" ;
label define HALMON    0 "Did not use in the past month (IRHALRC = 2-3,9)"
                       1 "Used within the past month (IRHALRC = 1)" ;
label define LSDFLAG   0 "Never used (IRLSDRC = 9)"
                       1 "Ever used (IRLSDRC = 1-3)" ;
label define LSDYR     0 "Did not use in the past year (IRLSDRC = 3,9)"
                       1 "Used within the past year (IRLSDRC = 1,2)" ;
label define LSDMON    0 "Did not use in the past month (IRLSDRC = 2-3,9)"
                       1 "Used within the past month (IRLSDRC = 1)" ;
label define PCPFLAG   0 "Never used (IRPCPRC = 9)"
                       1 "Ever used (IRPCPRC = 1-3)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC = 3,9)"
                       1 "Used within the past year (IRPCPRC = 1,2)" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC = 2-3,9)"
                       1 "Used within the past month (IRPCPRC = 1)" ;
label define INHFLAG   0 "Never used (IRINHRC = 9)"
                       1 "Ever used (IRINHRC = 1-3)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC = 3,9)"
                       1 "Used within the past year (IRINHRC = 1,2)" ;
label define INHMON    0 "Did not use in the past month (IRINHRC = 2-3,9)"
                       1 "Used within the past month (IRINHRC = 1)" ;
label define ANLFLAG   0 "Never used (IRANLRC = 9)"
                       1 "Ever used (IRANLRC = 1-3)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC = 3,9)"
                       1 "Used within the past year (IRANLRC = 1,2)" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC = 2-3,9)"
                       1 "Used within the past month (IRANLRC = 1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC = 9)"
                       1 "Ever used (IRTRNRC = 1-3)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC = 3,9)"
                       1 "Used within the past year (IRTRNRC = 1,2)" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC = 2-3,9)"
                       1 "Used within the past month (IRTRNRC = 1)" ;
label define STMFLAG   0 "Never used (IRSTMRC = 9)"
                       1 "Ever used (IRSTMRC = 1-3)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC = 3,9)"
                       1 "Used within the past year (IRSTMRC = 1,2)" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC = 2-3,9)"
                       1 "Used within the past month (IRSTMRC = 1)" ;
label define MTHFLAG   0 "Never Used (IRMTHRC=9)" 1 "Ever Used (IRMTHRC=1-3)" ;
label define MTHYR     0 "Did not use in the past year (IRMTHRC=3,9)"
                       1 "Used within the past year (IRMTHRC=1,2)" ;
label define MTHMON    0 "Did not use in the past month (IRMTHRC=2-3,9)"
                       1 "Used within the past month (IRMTHRC=1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC = 9)"
                       1 "Ever used (IRSEDRC = 1-3)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC = 3,9)"
                       1 "Used within the past year (IRSEDRC = 1,2)" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC = 2-3,9)"
                       1 "Used within the past month (IRSEDRC = 1)" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES = 9)"
                       1 "Ever used (ANY SOURCE VARIABLE < 9)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE VARS > 2)"
                       1 "Used in past year (ANY SOURCE VARIABLE < 3)" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VARS > 1)"
                       1 "Used in past month (ANY SOURCE VARIABLE = 1)" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES = 0)"
                       1 "Ever used (ANY SOURCE VARIABLE = 1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VARS =0)"
                       1 "Used in past year (ANY SOURCE VARIABLE = 1)" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VARS = 0)"
                       1 "Used in past month (ANY SOURCE VARIABLE = 1)" ;
label define MJOFLAG   0 "Never used MJ/has used both MJ & anothr illct drug"
                       1 "Marijuana is only (illicit) drug ever used" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr drug past yr"
                       1 "Marijuana is only (illicit) drug in past year" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr drug past mo"
                       1 "Marijuana only (illicit) drug in past month" ;
label define IEMFLAG   0 "Never used drug/used only marijuana"
                       1 "Illicit drug except for marijuana are ever used" ;
label define IEMYR     0 "Never used drug/used only marijuana past year"
                       1 "Illicit drug except for marijuana used past year" ;
label define IEMMON    0 "Never used drug/used only marijuana past month"
                       1 "Illicit drug except for marijuana used past month" ;
label define BINGEDRK  0 "Never/No 'Binge' alcohol use (IRALCD5 = 0)"
                       1 "'Binge' alcohol use (IRALCD5 = 1-30)" ;
label define HVYDRK2   0 "Never/No heavy alcohol use (IRALCD5 = 0-4)"
                       1 "Heavy alcohol use (IRALCD5 = 5-30)" ;
label define BINGEHVY  1 "Heavy Alcohol Use (HVYDRK2=1)"
                       2 "'Binge' But Not Heavy Use (BINGEDRK=1 & HVYDRK2=0)"
                       3 "Pst Month But Not 'Binge' (ALCMON=1 & BINGEDRK=0)"
                       4 "Did Not Use Alcohol in Pst Month (All source=0)" ;
label define PEYOTE2   0 "No/Unknown (PEYOTE=2,91,94,97)" 1 "Yes (PEYOTE=1)" ;
label define MESC2     0 "No/Unknown (MESC=2,91,94,97)" 1 "Yes (MESC=1,3)" ;
label define PSILCY2   0 "No/Unknown (PSILCY=2,91,94,97)"
                       1 "Yes (PSILCY=1,3)" ;
label define ECSTASY2  0 "No/Unknown (ECSTASY=2,91,94,97)"
                       1 "Yes (ECSTASY=1)" ;
label define AMYLNIT2  0 "No/Unknown (AMYLNIT=2,91,94,97)"
                       1 "Yes (AMYLNIT=1,3)" ;
label define CLEFLU2   0 "No/Unknown (CLEFLU=2,91,94,97)"
                       1 "Yes (CLEFLU=1,3)" ;
label define GAS2      0 "No/Unknown (GAS=2,91,94,97,98)" 1 "Yes (GAS=1,3)" ;
label define GLUE2     0 "No/Unknown (GLUE=2,91,94,97,98)" 1 "Yes (GLUE=1,3)" ;
label define ETHER2    0 "No/Unknown (ETHER=2,91,94,97,98)"
                       1 "Yes (ETHER=1,3)" ;
label define SOLVENT2  0 "No/Unknown (SOLVENT=2,91,94,97,98)"
                       1 "Yes (SOLVENT=1,3)" ;
label define LGAS2     0 "No/Unknown (LGAS=2,91,94,97,98)" 1 "Yes (LGAS=1,3)" ;
label define NITOXID2  0 "No/Unknown (NITOXID=2,91,94,97,98)"
                       1 "Yes (NITOXID=1,3)" ;
label define SPPAINT2  0 "No/Unknown (SPPAINT=2,91,94,97,98)"
                       1 "Yes (SPPAINT=1)" ;
label define AEROS2    0 "No/Unknown (AEROS=2,91,94,97,98)"
                       1 "Yes (AEROS=1,3)" ;
label define DIETPIL2  0 "No/Unknown (DIETPILS=2,81,91,94,97,98)"
                       1 "Yes (DIETPILS=1,3)" ;
label define RITMPHE2  0 "No/Unknown (RITMPHEN=2,81,91,94,97,98)"
                       1 "Yes (RITMPHEN=1,3)" ;
label define OTHSTM    0 "No/Unknwn (STMCARD or STMNOLST=2,4,81,91,94,97,98)"
                       1 "Yes (STMCARD or STMNOLST = 1,3)" ;
label define METHAQ2   0 "No/Unknown (METHAQ=2,81,91,94,97,98)"
                       1 "Yes (METHAQ=1)" ;
label define NEMBBAR2  0 "No/Unknown (NEMBBARB=2,81,91,94,97,98)"
                       1 "Yes (NEMBBARB=1)" ;
label define RESTTMA2  0 "No/Unknown (RESTTMAZ=2,81,91,94,97,98)"
                       1 "Yes (RESTTMAZ=1)" ;
label define OTHSED    0 "No/Unknwn (SEDCARD or SEDNOLST=2,4,81,91,94,97,98)"
                       1 "Yes (SEDCARD or SEDNOLST = 1,3)" ;
label define KLONOPI2  0 "No/Unknown (KLONOPIN=2,81,91,94,97,98)"
                       1 "Yes (KLONOPIN=1)" ;
label define XNAXATV2  0 "No/Unknown (XNAXATVN=2,81,91,94,97,98)"
                       1 "Yes (XNAXATVN=1,3)" ;
label define VALMDIA2  0 "No/Unknown (VALMDIAZ=2,81,91,94,97,98)"
                       1 "Yes (VALMDIAZ=1,3)" ;
label define OTHTRN    0 "No/Unknwn (TRNCARD or TRNNOLST=2,4,81,91,94,97,98)"
                       1 "Yes (TRNCARD or TRNNOLST = 1,3)" ;
label define DARVTYL2  0 "No/Unknown (DARVTYLC=2,81,91,94,97,98)"
                       1 "Yes (DARVTYLC=1,3)" ;
label define PERCTYL2  0 "No/Unknown (PERCTYLX=2,91,94,97)"
                       1 "Yes (PERCTYLX=1,3)" ;
label define VICOLOR2  0 "No/Unknown (VICOLOR=2,91,94,97)"
                       1 "Yes (VICOLOR=1,3)" ;
label define OTHANL    0 "No/Unknwn (ANLCARD or ANLNOLST=2,4,81,91,94,97,98)"
                       1 "Yes (ANLCARD or ANLNOLST = 1,3)" ;
label define AMYTAL2   0 "No/Unknown (AMYTAL=6,81,91,94,97,98,99)"
                       1 "Yes (AMYTAL= 1)" ;
label define BUTISOL2  0 "No/Unknown (BUTISOL=6,81,91,94,97,98,99)"
                       1 "Yes (BUTISOL= 1)" ;
label define CHHYD2    0 "No/ Unknown (CHHYD = 6,81,91,94,97,98,99)"
                       1 "Yes (CHHYD= 1)" ;
label define DALMANE2  0 "No/Unknown (DALMANE=6,81,91,94,97,98,99)"
                       1 "Yes (DALMANE=1,3)" ;
label define HALCION2  0 "No/Unknown (HALCION=6,81,91,94,97,98,99)"
                       1 "Yes (HALCION=1)" ;
label define PHENOBR2  0 "No/Unknown (PHENOBAR=6,81,91,94,97,98,99)"
                       1 "Yes (PHENOBAR=1,3)" ;
label define PLACIDY2  0 "No/ Unknown (PLACIDYL = 6,81,91,94,97,98,99)"
                       1 "Yes (PLACIDYL= 1,3)" ;
label define TUINAL2   0 "No/Unknown (TUINAL=6,81,91,94,97,98,99)"
                       1 "Yes (TUINAL=1,3)" ;
label define CODEINE2  0 "No/Unknown (CODEINE=6,81,91,94,97,98,99)"
                       1 "Yes (CODEINE=1,3)" ;
label define DEMEROL2  0 "No/Unknown (DEMEROL=6,81,91,94,97,98,99)"
                       1 "Yes (DEMEROL=1,3)" ;
label define DILAUD2   0 "No/ Unknown (DILAUD = 6,81,91,94,97,98,99)"
                       1 "Yes (DILAUD = 1,3)" ;
label define FIORICT2  0 "No/Unknown (FIORICET=6,81,91,94,97,98,99)"
                       1 "Yes (FIORICET=1,3)" ;
label define FIORINL2  0 "No/Unknown (FIORINAL= 6,81,91,94,97,98,99)"
                       1 "Yes (FIORINAL=1,3)" ;
label define HYDROCD2  0 "No/Unknown (HYDROCOD= 6,81,91,94,97,98,99)"
                       1 "Yes (HYDROCOD=1,3)" ;
label define METHDON2  0 "No/ Unknown (METHDON =6,81,91,94,97,98,99)"
                       1 "Yes (METHDON = 1,3)" ;
label define MORPHIN2  0 "No/ Unknown (MORPHINE =6,81,91,94,97,98,99)"
                       1 "Yes (MORPHINE = 1,3)" ;
label define OXYCONT2  0 "No/ Unknown (OXYCONTN =6,81,91,94,97,98,99)"
                       1 "Yes (OXYCONTN = 1,3)" ;
label define PHENCOD2  0 "No/ Unknown (PHENCOD =6,81,91,94,97,98,99)"
                       1 "Yes (PHENCOD = 1)" ;
label define PROPOXY2  0 "No/ Unknown (PROPOXY =6,81,91,94,97,98,99)"
                       1 "Yes (PROPOXY = 1,3)" ;
label define SK65A2    0 "No/ Unknown (SK65A =6,81,91,94,97,98,99)"
                       1 "Yes (SK65A = 1,3)" ;
label define STADOL2   0 "No/ Unknown (STADOL =6,81,91,94,97,98,99)"
                       1 "Yes (STADOL = 1)" ;
label define TALACEN2  0 "No/ Unknown (TALACEN =6,81,91,94,97,98,99)"
                       1 "Yes (TALACEN = 1)" ;
label define TALWIN2   0 "No/ Unknown (TALWIN =6,81,91,94,97,98,99)"
                       1 "Yes (TALWIN = 1,3)" ;
label define TALWINX2  0 "No/ Unknown (TALWINNX =6,81,91,94,97,98,99)"
                       1 "Yes (TALWINNX = 1)" ;
label define TRAMADL2  0 "No/ Unknown (TRAMADOL =6,81,91,94,97,98,99)"
                       1 "Yes (TRAMADOL = 1)" ;
label define ULTRAM2   0 "No/ Unknown (ULTRAM =6,81,91,94,97,98,99)"
                       1 "Yes (ULTRAM = 1,3)" ;
label define ATARAX2   0 "No/ Unknown (ATARAX =6,81,91,94,97,98,99)"
                       1 "Yes (ATARAX = 1)" ;
label define BUSPAR2   0 "No/ Unknown (BUSPAR =6,81,91,94,97,98,99)"
                       1 "Yes (BUSPAR = 1,3)" ;
label define EQUANIL2  0 "No/ Unknown (EQUANIL =6,81,91,94,97,98,99)"
                       1 "Yes (EQUANIL = 1)" ;
label define FLEXERL2  0 "No/ Unknown (FLEXERIL =6,81,91,94,97,98,99)"
                       1 "Yes (FLEXERIL = 1,3)" ;
label define LIBRIUM2  0 "No/ Unknown (LIBRIUM =6,81,91,94,97,98,99)"
                       1 "Yes (LIBRIUM = 1,3)" ;
label define LIMBTRL2  0 "No/ Unknown (LIMBTROL =6,81,91,94,97,98,99)"
                       1 "Yes (LIMBTROL = 1)" ;
label define MEPROB2   0 "No/ Unknown (MEPROB =6,81,91,94,97,98,99)"
                       1 "Yes (MEPROB = 1)" ;
label define MILTOWN2  0 "No/ Unknown (MILTOWN =6,81,91,94,97,98,99)"
                       1 "Yes (MILTOWN = 1)" ;
label define ROHYPNL2  0 "No/Unknown (ROHYPNOL =6,81,91.94,97,98,99)"
                       1 "Yes (ROHYPNOL = 1,3)" ;
label define SERAX2    0 "No/ Unknown (SERAX =6,81,91,94,97,98,99)"
                       1 "Yes (SERAX = 1)" ;
label define SOMA2     0 "No/ Unknown (SOMA =6,81,91,94,97,98,99)"
                       1 "Yes (SOMA = 1,3)" ;
label define TRANXEN2  0 "No/ Unknown (TRANXENE =6,81,91,94,97,98,99)"
                       1 "Yes (TRANXENE = 1)" ;
label define VISTAR2   0 "No/ Unknown (VISTAR =6,81,91,94,97,98,99)"
                       1 "Yes (VISTAR = 1,3)" ;
label define CYLERT2   0 "No/ Unknown (CYLERT =6,81,91,94,97,98,99)"
                       1 "Yes (CYLERT = 1)" ;
label define DEXED2    0 "No/ Unknown (DEXED =6,81,91,94,97,98,99)"
                       1 "Yes (DEXED = 1,3)" ;
label define DETAMP2   0 "No/ Unknown (DETAMP =6,81,91,94,97,98,99)"
                       1 "Yes (DETAMP = 1,3)" ;
label define DIDREX2   0 "No/ Unknown (DIDREX =6,81,91,94,97,98,99)"
                       1 "Yes (DIDREX = 1)" ;
label define ESKAT2    0 "No/ Unknown (ESKAT =6,81,91,94,97,98,99)"
                       1 "Yes (ESKAT = 1)" ;
label define IONAMIN2  0 "No/ Unknown (IONAMIN =6,81,91,94,97,98,99)"
                       1 "Yes (IONAMIN = 1,3)" ;
label define MAZANOR2  0 "No/ Unknown (MAZANOR =6,81,91,94,97,98,99)"
                       1 "Yes (MAZANOR = 1,3)" ;
label define OBLA2     0 "No/ Unknown (OBLA =6,81,91,94,97,98,99)"
                       1 "Yes (OBLA = 1)" ;
label define PLEGINE2  0 "No/ Unknown (PLEGINE =6,81,91,94,97,98,99)"
                       1 "Yes (PLEGINE = 1)" ;
label define PRELUDN2  0 "No/ Unknown (PRELUDIN =6,81,91,94,97,98,99)"
                       1 "Yes (PRELUDIN = 1)" ;
label define SANOREX2  0 "No/ Unknown (SANOREX =6,81,91,94,97,98,99)"
                       1 "Yes (SANOREX = 1)" ;
label define TENUATE2  0 "No/ Unknown (TENUATE =6,81,91,94,97,98,99)"
                       1 "Yes (TENUATE = 1)" ;
label define ALCAFU    1 "14 Years or Younger (IRALCAGE=1-14)"
                       2 "15-17 Years Old (IRALCAGE=15-17)"
                       3 "18 Years or Older (IRALCAGE=18+)"
                       4 "Non Alcohol Users (IRALAGE = 991)" ;
label define MJAFU     1 "14 Years or Younger (IRMJAGE=1-14)"
                       2 "15-17 Years Old (IRMJAGE=15-17)"
                       3 "18 Years or Older (IRMJAGE=18+)"
                       4 "Non Marijuana Users (IRMJGE = 991)" ;
label define COCAFU    1 "14 Years or Younger (IRCOCAGE=1-14)"
                       2 "15-17 Years Old (IRCOCAGE=15-17)"
                       3 "18 Years or Older (IRCOCAGE=18+)"
                       4 "Non Cocaine Users (IRCOCAGE = 991)" ;
label define HERAFU    1 "14 Years or Younger (IRHERAGE=1-14)"
                       2 "15-17 Years Old (IRHERAGE=15-17)"
                       3 "18 Years or Older (IRHERAGE=18+)"
                       4 "Non Heroin Users (IRHERAGE = 991)" ;
label define HALAFU    1 "14 Years or Younger (IRHALAGE=1-14)"
                       2 "15-17 Years Old (IRHALAGE=15-17)"
                       3 "18 Years or Older (IRHALAGE=18+)"
                       4 "Non Hallucinogen Users (IRHALAGE = 991)" ;
label define INHAFU    1 "14 Years or Younger (IRINHAGE=1-14)"
                       2 "15-17 Years Old (IRINHAGE=15-17)"
                       3 "18 Years or Older (IRINHAGE=18+)"
                       4 "Non Inhalant Users (IRINHAGE = 991)" ;
label define ANLAFU    1 "14 Years or Younger (IRANLAGE=1-14)"
                       2 "15-17 Years Old (IRANLAGE=15-17)"
                       3 "18 Years or Older (IRANLAGE=18+)"
                       4 "Non Pain Reliever Users (IRANLAGE = 991)" ;
label define TRNAFU    1 "14 Years or Younger (IRTRNAGE=1-14)"
                       2 "15-17 Years Old (IRTRNAGE=15-17)"
                       3 "18 Years or Older (IRTRNAGE=18+)"
                       4 "Non Tranquilizer Users (IRTRNAGE = 991)" ;
label define STMAFU    1 "14 Years or Younger (IRSTMAGE=1-14)"
                       2 "15-17 Years Old (IRSTMAGE=15-17)"
                       3 "18 Years or Older (IRSTMAGE=18+)"
                       4 "Non Stimulant Users (IRSTMAGE = 991)" ;
label define SEDAFU    1 "14 Years or Younger (IRSEDAGE=1-14)"
                       2 "15-17 Years Old (IRSEDAGE=15-17)"
                       3 "18 Years or Older (IRSEDAGE=18+)"
                       4 "Non Sedative Users (IRSEDAGE = 991)" ;
label define CIGAFU    1 "14 Years or Younger (IRCIGAGE=1-14)"
                       2 "15-17 Years Old (IRCIGAGE=15-17)"
                       3 "18 Years or Older (IRCIGAGE=18+)"
                       4 "Non Cigarette Users (IRCIGAGE = 991)" ;
label define CGRAFU    1 "14 Years or Younger (IRCGRAGE=1-14)"
                       2 "15-17 Years Old (IRCGRAGE=15-17)"
                       3 "18 Years or Older (IRCGRAGE=18+)"
                       4 "Non Cigar Users (IRCGRAGE = 991)" ;
label define SLTAFU    1 "14 Years or Younger (IRSLTAGE=1-14)"
                       2 "15-17 Years Old (IRSLTAGE=15-17)"
                       3 "18 Years or Older (IRSLTAGE=18+)"
                       4 "Non Smokeless Tobacco Users (IRSLTAGE = 991)" ;
label define CG05      1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG06      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG19      1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG20      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG27      1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG28      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG36      1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG37      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG43      1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALLAST3   1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTDRINK  985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALYRAVE   985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALMONAVE  85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALWKAVE   85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJLAST3   1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTMJ     985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJYRAVE   985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJMONAVE  85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJWKAVE   85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCLAST3   1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTCOKE   985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CCFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCYRAVE   985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CCMONAVE  85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CKLAST3   1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTCRACK  985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CKFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CKYRAVE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CKMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CKWKAVE   85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HELAST3   1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTHERO   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HEFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEYRAVE   997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HEMONAVE  97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSLAST    1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTHALL   985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define LSFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSYRAVE   985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define LSMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS07      1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS08      1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INLAST    1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTINHAL  985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INYRAVE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INWKAVE   85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR09      1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR11      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define PR12      85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR09      1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR11      985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TR12      85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST09      1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST11      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ST12      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST15      1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SV09      1 "Within the past 30 days -- since 30 day ref date"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SV10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SV11      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SV12      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SV13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERSMOKE  1 "Yes" 2 "No" 91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRSMKREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER SMOKED IT" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERSNIFF  1 "Yes" 2 "No" 91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRSNFREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER SNIFFED IT" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLLIF  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCNEEDL  1 "Yes" 2 "No" 91 "NEVER USED COCAINE" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define CONDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define HERNEEDL  1 "Yes" 2 "No" 91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define HRNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define STNEEDLE  1 "Yes" 2 "No" 91 "NEVER USED STIMULANTS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define STNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED STIMULANTS"
                       93 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDREUS  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF = 4)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDLSH1  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF = 4)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDCLEN  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF = 4)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDLSH2  1 "Yes" 2 "No"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF = 4)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF = 2)" ;
label define GNNDGET2  1 "Bought the needle from a pharmacy"
                       2 "Got the needle from a needle exchange"
                       3 "Bought the needle on the street"
                       4 "Got the needle in a shooting gallery"
                       5 "Got the needle some other way"
                       41 "Given by, stolen from a friend/acquaint of friend"
                       42 "Given by, stolen from a relative"
                       43 "Given by, stolen from someone, relation unspecifd"
                       44 "From drug dealer/came with drugs"
                       46 "Given by, stolen from medical facility/professionl"
                       49 "Bought, given, stolen from place/location unspecd"
                       89 "LEGITIMATE SKIP Logically assigned (GNNDLLIF=4)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (GNNDLLIF=2)" ;
label define NEDLRECC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED COC/HER/STM WITH A NEEDLE" 97 "REFUSED"
                       98 "MISSING (BUT NOT REFUSED)" ;
label define NEDFLAG4  0 "Never used (GNNDLLIF=2,4,94,97,98)"
                       1 "Ever Used (GNNDLLIF=1)" ;
label define HERSMOK2  0 "No/Unknown (HERSMOKE=2,91,97,98)"
                       1 "Yes (HERSMOKE=1)" ;
label define HERSNIF2  0 "No/Unknown (HERSNIFF=2,91,97,98)"
                       1 "Yes (HERSNIFF=1)" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYLSD  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKLSDREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYHER  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKHERREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RK5ALDLY  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RK5ALWK   1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKDIFMJ  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFLSD  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFCOC  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFCRK  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFHER  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKSELL   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQDNGR  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQRSKY  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQPBLT  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQDBLT  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       5 "I don't drive" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GRSKPKCG  -9 "Unknown (RSKPKCIG = 94,97,98)"
                       0 "Otherwise (RSKPKCIG = 1,2,3)"
                       1 "Great Risk (RSKPKCIG = 4)" ;
label define GRSKCREG  -9 "Unknown (RKCOCREG = 94,97,98)"
                       0 "Otherwise (RKCOCREG = 1,2,3)"
                       1 "Great Risk (RKCOCREG = 4)" ;
label define GRSKCOCC  -9 "Unknown (RKCOCOCC = 94,97,98)"
                       0 "Otherwise (RKCOCOCC = 1,2,3)"
                       1 "Great Risk (RKCOCOCC = 4)" ;
label define GRSKMREG  -9 "Unknown (RSKMJREG = 94,97,98)"
                       0 "Otherwise (RSKMJREG = 1,2,3)"
                       1 "Great Risk (RSKMJREG = 4)" ;
label define GRSKMOCC  -9 "Unknown (RSKMJOCC = 94,97,98)"
                       0 "Otherwise (RSKMJOCC = 1,2,3)"
                       1 "Great Risk (RSKMJOCC = 4)" ;
label define GRSKHTRY  -9 "Unknown (RKTRYHER = 94,97,98)"
                       0 "Otherwise (RKTRYHER = 1,2,3)"
                       1 "Great Risk (RKTRYHER = 4)" ;
label define GRSKHREG  -9 "Unknown (RKHERREG = 94,97,98)"
                       0 "Otherwise (RKHERREG = 1,2,3)"
                       1 "Great Risk (RKHERREG = 4)" ;
label define GRSKLTRY  -9 "Unknown (RKTRYLSD = 94,97,98)"
                       0 "Otherwise (RKTRYLSD = 1,2,3)"
                       1 "Great Risk (RKTRYLSD=4)" ;
label define GRSKLREG  -9 "Unknown (RKLSDREG = 94,97,98)"
                       0 "Otherwise (RKLSDREG = 1,2,3)"
                       1 "Great Risk (RKLSDREG = 4)" ;
label define GRSKD4_5  -9 "Unknown (RK5ALDLY = 94,97,98)"
                       0 "Otherwise (RK5ALDLY = 1,2,3)"
                       1 "Great Risk (RK5ALDLY = 4)" ;
label define GRSKD5WK  -9 "Unknown (RK5ALWK = 94,97,98)"
                       0 "Otherwise (RK5ALWK = 1,2,3)"
                       1 "Great Risk (RK5ALWK = 4)" ;
label define RDIFMJ    -9 "Unknown (RSKDIFMJ = 94,97,98)"
                       0 "Otherwise (RSKDIFMJ = 1,2,3)"
                       1 "Fairly or very easy (RSKDIFMJ = 4,5)" ;
label define RDIFCOC   -9 "Unknown (RKDIFCOC = 94,97,98)"
                       0 "Otherwise (RKDIFCOC = 1,2,3)"
                       1 "Fairly or very easy (RKDIFCOC = 4,5)" ;
label define RDIFHER   -9 "Unknown (RKDIFHER = 94,97,98)"
                       0 "Otherwise (RKDIFHER = 1,2,3)"
                       1 "Fairly or very easy (RKDIFHER = 4,5)" ;
label define RDIFLSD   -9 "Unknown (RKDIFLSD = 94,97,98)"
                       0 "Otherwise (RKDIFLSD = 1,2,3)"
                       1 "Fairly or very easy (RKDIFLSD = 4,5)" ;
label define RDIFCRK   -9 "Unknown (RKDIFCRK = 94,97,98)"
                       0 "Otherwise (RKDIFCRK = 1,2,3)"
                       1 "Fairly or very easy (RKDIFCRK = 4,5)" ;
label define APPSELDG  -9 "Unknown (RSKSELL = 85,94,97,98)"
                       0 "No (RSKSELL = 2)" 1 "Yes (RSKSELL = 1)" ;
label define GRTMCIG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTCIG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLCIG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDCIG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBCIG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRCIG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCIG    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WDRWCIG   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DPRSCIG   1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRSLPCIG  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IRRITCIG  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANXCIG    1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CONCCIG   1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HUNGRCIG  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define RSTLSCIG  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLHRTCIG  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GRTMALC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTALC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLALC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDALC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBALC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRALC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDALC    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WDRWALC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SWETALC   1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HSHAKALC  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRSLPALC  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VOMITALC  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HALUCALC  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SITSTALC  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANXALC    1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SEIZALC   1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AVDWDALC  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMMRJ   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTMRJ   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLMRJ   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDMRJ   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBMRJ   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRMRJ   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDMRJ    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCOC    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DPRSCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WDRWCOC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TIREDCOC  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BDDRMCOC  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLPRBCOC  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HUNGRCOC  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLODNCOC  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AVDWDCOC  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMHER   1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LAMTHER   1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BTOLHER   1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ACRDHER   1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define EMPBHER   1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRHER   1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHER    1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define WDRWHER   1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DPRSHER   1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define VOMITHER  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CRAMPHER  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EYNOSHER  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DILATHER  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DIARHER   1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YAWNHER   1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FEVERHER  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRSLPHER  1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AVDWDHER  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMHAL   1 "Yes" 2 "No"
                       83 "DID NOT USE HALLUCINOGENS IN PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTHAL   1 "Yes" 2 "No"
                       83 "DID NOT USE HALLUCINOGENS IN PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLHAL   1 "Yes" 2 "No"
                       83 "DID NOT USE HALLUCINOGENS IN PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDHAL   1 "Yes" 2 "No"
                       83 "DID NOT USE HALLUCINOGENS IN PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBHAL   1 "Yes" 2 "No"
                       83 "DID NOT USE HALLUCINOGENS IN PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRHAL   1 "Yes" 2 "No"
                       83 "DID NOT USE HALLUCINOGENS IN PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHAL    1 "Yes" 2 "No"
                       83 "DID NOT USE HALLUCINOGENS IN PST 12 MOS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMINH   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTINH   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLINH   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDINH   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBINH   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRINH   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDINH    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMANL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTANL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLANL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDANL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBANL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRANL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDANL    1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WDRWANL   1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DPRSANL   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VOMITANL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRAMPANL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EYNOSANL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DILATANL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DIARANL   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YAWNANL   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FEVERANL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRSLPANL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AVDWDANL  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMTRN   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTTRN   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLTRN   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDTRN   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBTRN   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRTRN   1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDTRN    1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSTM    1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DPRSSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WDRWSTM   1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TIREDSTM  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BDDRMSTM  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLPRBSTM  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HUNGRSTM  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLODNSTM  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AVDWDSTM  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRTMSED   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LAMTSED   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BTOLSED   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ACRDSED   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EMPBSED   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLPRSED   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSED    1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WDRWSED   1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SWETSED   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HSHAKSED  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLPRBSED  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VOMITSED  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HALUCSED  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SITSTSED  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANXSED    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SEIZSED   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AVDWDSED  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPALC    0 "No" 1 "Yes" ;
label define DEPANL    0 "No" 1 "Yes" ;
label define DEPCIG    0 "No" 1 "Yes" ;
label define DEPCOC    0 "No" 1 "Yes" ;
label define DEPHAL    0 "No" 1 "Yes" ;
label define DEPHER    0 "No" 1 "Yes" ;
label define DEPINH    0 "No" 1 "Yes" ;
label define DEPMRJ    0 "No" 1 "Yes" ;
label define DEPSED    0 "No" 1 "Yes" ;
label define DEPSTM    0 "No" 1 "Yes" ;
label define DEPTRN    0 "No" 1 "Yes" ;
label define DEPILL    0 "No" 1 "Yes (Any source variable listed above =1)" ;
label define DILORALC  0 "No" 1 "Yes (DEPILL=1 or DEPALC=1)" ;
label define DILANALC  0 "No" 1 "Yes (DEPILL=1 or DEPALC=1)" ;
label define DEPPSYCH  0 "No"
                       1 "Yes (DEPTRN or DEPANL or DEPSTM or DEPSED=1)" ;
label define BOOKED    1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (PROBATON OR PAROLE=1)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOBOOKY2  0 "None" 1 "One time" 2 "Two times"
                       3 "Three or more times"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (BOOKED=2)" ;
label define BKLARCNY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKBURGL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKAGASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKSMASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKMVTHFT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKROB     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKRAPE    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKMURDER  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKARSON   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKDRVINF  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKDRUNK   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKDRUG    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKPROS    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKVANDAL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKOTH     1 "Yes" 2 "No" 5 "Offense unknown"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKOTHOF2  1 "Larceny or theft"
                       2 "Burglary or breaking and entering"
                       3 "Aggravated assault"
                       4 "Other assault, such as simple assault or battery"
                       5 "Motor vehicle theft" 6 "Robbery"
                       11 "Drunkenness or other liquor law violation"
                       12 "Possession or sale of drugs"
                       14 "Oth proprty offns: fraud, poss stln goods, vndlsm"
                       15 "Other offense, not categorized elsewhere"
                       16 "Weapons law violations"
                       17 "Counterfeiting/Forgery"
                       18 "Violation of court order, parole, probation"
                       19 "Disorderly conduct" 20 "Juvenile status offenses"
                       21 "All oth offns: crimes agnst persons/prprty/society"
                       22 "Traffic violations" 23 "Bad checks"
                       24 "Curfew/loitering/vagrancy violations"
                       25 "Trespass of real property" 26 "Runaway"
                       27 "Family offenses, nonviolent" 28 "Intimidation"
                       31 "Tobacco law/code violation"
                       36 "Possession of drug paraphernalia"
                       38 "Evading/hindering/obstructing police"
                       39 "False report/statement/alarm"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PROBATON  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PAROLE    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DRVALDR   1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRIVEAL   1 "Yes" 2 "No" 12 "No (DRVALDR = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRIVEDR   1 "Yes" 2 "No" 12 "No (DRVALDR = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXEVER    1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXYREVER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXYRADG   1 "Alcohol use only" 2 "Drug use only"
                       3 "Both alcohol and drug use"
                       4 "Alcohol (drug trmt unknown) LOGICALLY ASSIGNED"
                       5 "Drugs (alcohol trmt unknown) LOGICALLY ASSIGNED"
                       6 "Both alcohol and drug use LOGICALLY ASSIGNED"
                       11 "Alcohol only (but last tmt for drugs reported)"
                       12 "Drugs only (but last tmt for alc reported)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRHOSP  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRRFIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRRFOP  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRMHC   1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRTXER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRDOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRJAIL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRSHG   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRSOP   1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTMAI2)"
                       7 "Treatment location unknown, LOG ASSN"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYROTS2  9 "Some other place, not categorized elsewhere"
                       22 "Residential drug or alc rehab facility overnight"
                       26 "Private doctor's office" 27 "Prison or jail"
                       28 "Self-help group" 40 "Home, family, friends"
                       41 "School, college"
                       42 "Church/religious/spiritual influence"
                       44 "Halfway house/group home"
                       45 "Rehab/intervention fac/prgrm, ptnt status unspcfd"
                       48 "Counselor, therapist, psychologist"
                       49 "Court-mandated/sponsored program"
                       51 "Alcohol/drug class, location unspecified"
                       59 "Foster Care, Child & Family Services, DSS"
                       64 "Methadone clinic/program"
                       65 "Name of facility/program given"
                       981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL OR DRUGS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TXYRVSER  1 "Yes" 2 "No" 6 "NEVER USED RELEVANT DRUGS"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRNME2  981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL OR DRUGS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NDTXNEED  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXALC   1 "Yes" 2 "No" 11 "Yes (TXYRADG=12)"
                       12 "No (TXYRADG=12)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXMJ    1 "Yes" 2 "No" 11 "Yes (TXYRADG=11)"
                       12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXCOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       11 "Yes (TXYRADG=11)" 12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXHER   1 "Yes" 2 "No" 11 "Yes (TXYRADG=11)"
                       12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXHAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       11 "Yes (TXYRADG=11)" 12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXINH   1 "Yes" 2 "No" 11 "Yes (TXYRADG=11)"
                       12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXANL   1 "Yes" 2 "No" 11 "Yes (TXYRADG=11)"
                       12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXTRAN  1 "Yes" 2 "No" 11 "Yes (TXYRADG=11)"
                       12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXSTIM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       11 "Yes (TXYRADG=11)" 12 "No (TXYRADG=11)"
                       13 "Yes LOGICALLY ASSIGNED (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Log assn"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXSED   1 "Yes" 2 "No" 11 "Yes (TXYRADG=11)"
                       12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXSOD   1 "Yes" 2 "No" 5 "Drug Unknown LOGICALLY ASSIGNED"
                       11 "Yes (TXYRADG=11)" 12 "No (TXYRADG=11)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXDRG1  355 "Crystal meth"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       658 "Special K, Ketamine"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       805 "Cocaine, coca, cocana, coke" 806 "Crack, rock"
                       824 "Steroids" 3052 "Speed, otherwise unspecified"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXDRG2  9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXDRG3  9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXDRG4  9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXDRG5  9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXEFRT  1 "Yes" 2 "No" 11 "Yes (TXYRADG=11,12)"
                       12 "No (TXYRADG=11,12)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXADGREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Treatment in past year LOGICALLY ASSIGNED"
                       9 "Treatment in lifetime LOGICALLY ASSIGNED"
                       13 "Treatment > 12 mos ago LOG ASSN (TXYREVER=2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTMAI2  1 "Hospital inpatient overnight"
                       2 "Residential drug or alc rehab facility overnight"
                       3 "Drug or alcohol rehab facility as outpatient"
                       4 "Mental health center or facility as outpatient"
                       5 "Emergency room" 6 "Private doctor's office"
                       7 "Prison or jail" 8 "Self-help group"
                       9 "In some other place" 40 "Home, family, friends"
                       41 "School, college"
                       42 "Church/religious/spiritual influence"
                       44 "Halfway house/group home"
                       45 "Rehab/intervention fac/prgrm, ptnt status unspcfd"
                       46 "Mental health center or facility, inpatient"
                       47 "Community/city/county/state program, unspecified"
                       48 "Counselor, therapist, psychologist"
                       49 "Court-mandated/sponsored program"
                       50 "Within myself (self-treatment)"
                       51 "Alcohol/drug class, location unspecified"
                       52 "Military/VA Hospital"
                       53 "Hospital, patient status unspecified"
                       54 "On the job, Job Corp, EAP"
                       55 "Youth-oriented facility/organization/program"
                       65 "Name of facility/program given"
                       66 "Church-run formal program/facility"
                       981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL OR DRUGS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TXLTALC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOG ASSN (TXYRADG = 1)"
                       6 "NEVER USED ALCOHOL (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTMJ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED MARIJUANA (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTCOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED COCAINE (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHER   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED HEROIN (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTHAL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED HALLUCINOGENS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTINH   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED INHALANTS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTANL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED PAIN RELIEVERS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTTRAN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED TRANQUILIZERS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSTIM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED STIMULANTS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSED   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED SEDATIVES (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTSOD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Treatment drug unknown, LOGICALLY ASSIGNED"
                       7 "Treatment drug/alc unknown LOG ASSN"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTA     209 "Xanax, Alprazolam" 246 "Clonazepam, Klonopin"
                       268 "Rohypnol, Roche, roofies"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       336 "Diet pills" 339 "Amphetamines" 348 "Crystal"
                       355 "Crystal meth" 401 "Darvon"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       426 "Fiorinal"
                       434 "Anexsia, Co-Gesic, Lortab, Tussionex, Vicodin"
                       442 "Ibuprofen"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       531 "Candy, powdered candy" 601 "LSD ('acid')"
                       602 "Peyote" 604 "Psilocybin (mushrooms), shrooms"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       658 "Special K, Ketamine"
                       701 "OTHER Opiates, NOT OTHERWISE SPECIFIED"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed"
                       805 "Cocaine, coca, cocana, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       808 "All of the ones I've tried" 818 "Nicotine"
                       857 "Wicki stick" 3050 "Mini Thins"
                       3052 "Speed, otherwise unspecified"
                       8006 "Laxative <OTC>" 8007 "Gabapentin, Neurontin"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXLTB     322 "Methamphetamine ('ice' or 'crank'), Meth"
                       335 "Dexatrim <OTC>" 339 "Amphetamines"
                       355 "Crystal meth" 601 "LSD ('acid')"
                       658 "Special K, Ketamine"
                       805 "Cocaine, coca, cocana, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       900 "Not a drug, Non-drug reason given for a drug"
                       2001 "Soma" 2002 "Muscle Relaxers"
                       3052 "Speed, otherwise unspecified"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXLTC     322 "Methamphetamine ('ice' or 'crank'), Meth"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TXLTD     326 "White cross" 336 "Diet pills"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXLTE     3052 "Speed, otherwise unspecified"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TXLTPRIM  1 "Alcohol" 2 "Marijuana or hashish"
                       3 "Cocaine or Crack" 4 "Heroin" 5 "Hallucinogens"
                       6 "Inhalants" 7 "Prescription pain relievers"
                       8 "Prescription tranquilizers"
                       9 "Prescription stimulants"
                       10 "Prescription sedatives" 11 "Some other drug"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXOUTC2   1 "You are still in treatment"
                       2 "You successfully completed treatment"
                       3 "You left because you had a problem with program"
                       4 "You left because you couldn't afford to continue"
                       5 "You left because your family needed you"
                       6 "You left because you began using drugs again"
                       7 "Your last treatment had some other outcome"
                       41 "You left because you didn't need/want treatment"
                       42 "You consider that treatment is for lifetime"
                       43 "You were successful b/c of own efforts, not trmt"
                       44 "You relapsed/program did not work for you"
                       45 "You were kicked out of program"
                       46 "You moved away from the treatment location"
                       48 "Discontinued treatment, success unknown"
                       49 "Completed treatment, outcome unknown"
                       50 "You had other problems to deal with"
                       51 "You still use drugs, but to a lesser extent"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXLTDUR2  730 "730 or more days"
                       99981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       99985 "BAD DATA Logically assigned"
                       99991 "NEVER USED ALCOHOL OR DRUGS" 99994 "DON'T KNOW"
                       99997 "REFUSED" 99998 "BLANK (NO ANSWER)"
                       99999 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDINS   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDCARE  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDCAID  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDPUBP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSAVE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDFMLY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDCORT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDMILC  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDEMPL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSOS   1 "Yes" 2 "No" 4 "No LOG ASSN (free trmt specified)"
                       5 "Yes, payment source not specified LOG ASSN"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXPDSP2   1 "Private health insurance" 3 "Medicaid"
                       4 "Public assistance program other than Medicaid"
                       5 "Own savings or earnings" 6 "Family members"
                       7 "Courts"
                       8 "CHAMPUS, TRICARE, CHAMPVA, VA, othr military hlth"
                       9 "Employer" 10 "Free" 11 "Some other source"
                       12 "Friend/sponsor" 14 "School" 15 "Treatment program"
                       16 "Indian Health Service/BIA"
                       19 "Public assistance, unspecified"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPDFRE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXENROLL  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TRMTNEED  0 "No" 1 "Yes (See comment above)" ;
label define TRTNEED2  0 "No" 1 "Yes (TRMTNEED=1) OR (DEPALC=1)" ;
label define TRMTSPEC  0 "No (Otherwise)"
                       1 "Yes (TXYRADG=2,3,5,6,11,12) & (ANY ABOVE SOURCE)" ;
label define LEVEL2    0 "No" 1 "Yes (See comment above)" ;
label define DRNKHELP  0 "No (Otherwise)"
                       1 "Yes (TXYREVER=1,3 & TXYRADG=1,3,4,6,11,12)" ;
label define DRUGHELP  0 "No (Otherwise)"
                       1 "Yes (TXYREVER=1,3 & TXYRADG=2,3,5,6,11,12)" ;
label define SUBSHELP  0 "No (DRNKHELP=0 and DRUGHELP=0)"
                       1 "Yes (DRNKHELP=1 or DRUGHELP=1)" ;
label define SNLIVNBR  1 "Less than one year"
                       2 "At least 1 year but less than 3 years"
                       3 "At least 3 years but less than 5 years"
                       4 "At least 5 years but less than 10 years"
                       5 "10 or more years" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SNCRIME   1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSELLDG  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNPPVAL   1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSTFGT   1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNEMTBLD  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNPPHLP   1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNGRAFTI  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNPPVSIT  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNPPMOVE  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNAPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNAMJEVR  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNAALDLY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNAALDRV  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNMOV5Y2  0 "None" 1 "One time" 2 "Two times" 3 "Three times"
                       4 "Four times" 5 "Five times" 6 "Six or more times"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SNPPHHLD  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SNINSULT  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSRARGU  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSMARGU  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPOUSE  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SNSPACTV  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPANGR  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPHITU  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYHITSP  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPCRIT  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPCONC  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFRCONC  1 "None" 2 "One" 3 "2 or 3" 4 "4 to 5" 5 "More than 5"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFRACTV  1 "None" 2 "One" 3 "2 or 3" 4 "4 to 5" 5 "More than 5"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFRCARE  1 "None" 2 "One" 3 "2 or 3" 4 "4 to 5" 5 "More than 5"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYSELL   1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYSTOLE  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYATTAK  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFACIG   1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFAMJEV  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFAALDY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFAALDV  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFDCIG   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SNFDMJ    1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SNFDALC   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SNFDDRNK  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YELIVNBR  1 "Less than one year"
                       2 "At least 1 year but less than 3 years"
                       3 "At least 3 years but less than 5 years"
                       4 "At least 5 years but less than 10 years"
                       5 "10 or more years"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECRIME   1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESELLDG  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPPHLP   1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTFGT   1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEEMTBLD  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPPVSIT  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGRAFTI  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPPMOVE  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEAPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEAMJEVR  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEAALDLY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEMOV5Y2  0 "None" 1 "One time" 2 "Two times" 3 "Three times"
                       4 "Four times" 5 "Five times" 6 "Six or more times"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define YEADOCIG  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEADOMRJ  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEADOALC  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEADODNK  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEENRLYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHFLT  1 "I liked going to school a lot"
                       2 "I kind of liked going to school"
                       3 "I didn't like going to school very much"
                       4 "I hated going to school"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHWRK  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHIMP  1 "Very important" 2 "Somewhat important"
                       3 "Somewhat unimportant" 4 "Very unimportant"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHINT  1 "Very interesting" 2 "Somewhat interesting"
                       3 "Somewhat boring" 4 "Very boring"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETCGJOB  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YELSTGRD  1 "An 'A+', 'A' or 'A-minus' average"
                       2 "A 'B+', 'B' or 'B-minus' average"
                       3 "A 'C+', 'C' or 'C-minus' average"
                       4 "A 'D' or less than a 'D' average"
                       5 "My school does not give these grades"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSCIG  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSMJ   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSALC  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSDNK  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETRSCIG  1 "A lot of trouble" 2 "A little trouble"
                       3 "No trouble at all" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETRPDAL  1 "A lot of trouble" 2 "A little trouble"
                       3 "No trouble at all" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETRPUDG  1 "A lot of trouble" 2 "A little trouble"
                       3 "No trouble at all" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPCHKHW  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPHLPHW  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPCHORE  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPLMTTV  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPLMTSN  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPGDJOB  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPPROUD  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYARGUP  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYFGTSW  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYFGTGP  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYHGUN   1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYSELL   1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYSTOLE  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYATTAK  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPMJEVR  1 "Neither Approve or Disapprove"
                       2 "Somewhat Disapprove" 3 "Strongly Disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPALDLY  1 "Neither Approve or Disapprove"
                       2 "Somewhat Disapprove" 3 "Strongly Disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGMJEVR  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGALDLY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFMJEVR  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFALDLY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFDCIG   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFDMJ    1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFDALC   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFDDNK   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKNON  1 "Response entered" 6 "Response not entered"
                       11 "Response entered (& other responses entered)"
                       13 "Resp entered LOG ASSN (& other responses entered)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKMOM  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       13 "Response entered LOG ASSN (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKDAD  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       13 "Response entered LOG ASSN (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKGPR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKBGF  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKSIB  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKSOR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKFRN  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKNBR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKTCH  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKPSY  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       13 "Response entered LOG ASSN (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKCLG  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       13 "Response entered LOG ASSN (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKSOP  1 "Response entered" 6 "Response not entered"
                       11 "Response entered (YETLKNON=11,13)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKSP   8 "Respondent" 20 "Parent/Guardian"
                       21 "Step/Adopted/Foster Parent/Future Step Parent"
                       40 "Sibling" 61 "Friend/Roommate/Companion"
                       71 "Cousin/Cousin's Spouse"
                       90 "Other Relative, Gender not specified"
                       92 "Other, Relation and Gender Unspecified"
                       110 "Husband" 120 "Father/Male Guardian"
                       121 "Step/Adopted/Foster Father/Future Step Father"
                       140 "Brother/Half Brother"
                       141 "Step/Adopted/Foster Brother/Future Step Brother"
                       142 "Brother In-Law"
                       150 "Grandfather/Great+ Grandfather"
                       161 "Male Fiance/Boyfriend/Roommate/Companion"
                       170 "Uncle/Step Uncle/Aunt's Husband"
                       181 "Other Male God Relative"
                       192 "Other Male, Relation Unspecified"
                       220 "Mother/Female Guardian"
                       221 "Step/Adopted/Foster Mother/Future Step Mother"
                       222 "Mother/Step Mother/Future Mother In-Law"
                       240 "Sister/Half Sister"
                       241 "Step/Adopted/Foster Sister/Future Step Sister"
                       250 "Grandmother/Great+ Grandmother"
                       251 "Step/Adopted/Foster/Great+ Grandmother"
                       261 "Female Fiancee/Girlfriend/Roommate/Companion"
                       270 "Aunt" 281 "Other Female God Relative"
                       291 "Other Female Non-Relative"
                       292 "Other Female, Relation Unspecified"
                       320 "Parents/Guardians"
                       321 "Step/Adopted/Foster Parents/Future Step Parents"
                       340 "Siblings" 350 "Grandparents/Great+ Grandparents"
                       361 "Friends/Roommates/Companions"
                       371 "Cousins/Cousins' Spouses"
                       390 "Other Relatives, Gender not specified"
                       391 "Other Non-Relatives, Gender not specified"
                       492 "Other Males, Relation Unspecified"
                       540 "Sisters/Half Sisters" 570 "Aunts"
                       600 "Teacher(s)" 601 "Coach(es)"
                       602 "School counselor(s)/principal(s)" 603 "Pastor(s)"
                       604 "Clergy" 605 "Police/law enforcement"
                       606 "Counselor(s), type unspecified"
                       607 "Other church worker(s)/member(s)"
                       608 "Teacher(s), non-school"
                       609 "Psychologist(s)/psychiatrist(s)/therapist(s)"
                       610 "Doctor(s)/nurse(s)/health care professional(s)"
                       612 "Internet/Chat room friends"
                       614 "Boy/girlfriend of parent"
                       615 "Other friend(s) of parent"
                       616 "Boy/girlfriend of sibling(s)"
                       618 "Friend(s) of family"
                       620 "Parent of boy/girlfriend"
                       621 "Parent(s) of friend(s)"
                       622 "Other relative(s) of friend(s)"
                       630 "Manager/boss/employer"
                       632 "Co-worker(s), relationship unspecified"
                       633 "Neighbor(s)" 634 "In the military"
                       635 "Babysitter"
                       636 "Casual acquaintance(s)/stranger(s)"
                       638 "Scout leader/master or similar"
                       639 "Youth worker, church not specified"
                       640 "Mentor/person being mentored"
                       641 "Another adult/older person(s)"
                       642 "Someone known to R, relationship unspecified"
                       644 "Anybody/everybody" 645 "Sponsor(s)"
                       650 "Specific name(s) mentioned"
                       651 "Person w/desired characteristics/experience"
                       900 "NOT A PERSON"
                       901 "God/Heavenly Father/Jesus/Higher Power/Mary"
                       950 "Qualities listed: may apply to previous answer"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define YEPARDNG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEBIGBRO  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPRBSLV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEVIOPRV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYMCA    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCOUTS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPRVLES  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDGPRGP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETEMSPT  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YE4HCLUB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESLFHLP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEBAND    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHCLB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEVOLUNT  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTGOVT  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPRGSTD  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEJBSKIL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECHOIR   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDECLAS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDERGLR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDESPCL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPVNTYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ACTALL    1 "No activities were marked"
                       2 "One activity was marked"
                       3 "Two activities were marked"
                       4 "Three or more activities were marked" ;
label define ACTSEL    1 "No selected activities were marked"
                       2 "One selected activity was marked"
                       3 "Two selected activities were marked"
                       4 "Three or more selected activities were marked" ;
label define ADFLALDY  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEAALDLY = 1)"
                       2 "Somewhat Disapprove (YEAALDLY = 2)"
                       3 "Strongly Disapprove (YEAALDLY = 3)" ;
label define ADFLPKCG  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEAPKCIG = 1)"
                       2 "Somewhat Disapprove (YEAPKCIG = 2)"
                       3 "Strongly Disapprove (YEAPKCIG = 3)" ;
label define ADFLTMRJ  -9 "Otherwise"
                       1 "Neither Approve or Disapprove (YEAMJEVR = 1)"
                       2 "Somewhat Disapprove (YEAMJEVR = 2)"
                       3 "Strongly Disapprove (YEAMJEVR = 3)" ;
label define ADULTALC  -9 "Otherwise" 1 "None of Them (YEADOALC = 1)"
                       2 "A few of Them (YEADOALC = 2)"
                       3 "Most of Them (YEADOALC = 3)"
                       4 "All of Them (YEADOALC = 4)" ;
label define ADULTCIG  -9 "Otherwise" 1 "None of Them (YEADOCIG = 1)"
                       2 "A few of Them (YEADOCIG = 2)"
                       3 "Most of Them (YEADOCIG = 3)"
                       4 "All of Them (YEADOCIG = 4)" ;
label define ADULTDRK  -9 "Otherwise" 1 "None of Them (YEADODNK = 1)"
                       2 "A few of Them (YEADODNK = 2)"
                       3 "Most of Them (YEADODNK = 3)"
                       4 "All of Them (YEADODNK = 4)" ;
label define ADULTMRJ  -9 "Otherwise" 1 "None of Them (YEADOMRJ = 1)"
                       2 "A few of Them (YEADOMRJ = 2)"
                       3 "Most of Them (YEADOMRJ = 3)"
                       4 "All of Them (YEADOMRJ = 4)" ;
label define ANYEDUC2  1 "Yes (DRGSPCLS = 1 or DRGRGCLS = 1 or DRUGLECT = 1)"
                       2 "No (DRGSPCLS = 0 & DRGRGCLS = 0 & DRUGLECT = 0)" ;
label define DRGRGCLS  0 "Otherwise" 1 "Yes (YEDERGLR = 1)" ;
label define DRGSPCLS  0 "Otherwise" 1 "Yes (YEDECLAS = 1)" ;
label define DRPRVME2  1 "Yes (YEPVNTYR = 1)"
                       2 "No (YEPVNTRY = 2,85,89,94,97,98,99)" ;
label define DRUGLECT  0 "Otherwise" 1 "Yes (YEDESPCL = 1)" ;
label define FRDALDLY  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEFALDLY = 1)"
                       2 "Somewhat Disapprove (YEFALDLY = 2)"
                       3 "Strongly Disapprove (YEFALDLY = 3)" ;
label define FRDMJEVR  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEFMJEVR = 1)"
                       2 "Somewhat Disapprove (YEFMJEVR = 2)"
                       3 "Strongly Disapprove (YEFMJEVR = 3)" ;
label define FRDPKCIG  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEFPKCIG = 1)"
                       2 "Somewhat Disapprove (YEFPKCIG = 2)"
                       3 "Strongly Disapprove (YEFPKCIG = 3)" ;
label define FRNDALC   -9 "Otherwise" 1 "None of Them (YEFDALC = 1)"
                       2 "A few of Them (YEFDALC = 2)"
                       3 "Most of Them (YEFDALC = 3)"
                       4 "All of Them (YEFDALC = 4)" ;
label define FRNDCIG   -9 "Otherwise" 1 "None of Them (YEFDCIG = 1)"
                       2 "A few of Them (YEFDCIG = 2)"
                       3 "Most of Them (YEFDCIG = 3)"
                       4 "All of Them (YEFDCIG = 4)" ;
label define FRNDDNK   -9 "Otherwise" 1 "None of Them (YEFDDNK = 1)"
                       2 "A few of Them (YEFDDNK = 2)"
                       3 "Most of Them (YEFDDNK = 3)"
                       4 "All of Them (YEFDDNK = 4)" ;
label define FRNDMJ    -9 "Otherwise" 1 "None of Them (YEFDMJ = 1)"
                       2 "A few of Them (YEFDMJ = 2)"
                       3 "Most of Them (YEFDMJ = 3)"
                       4 "All of Them (YEFDMJ = 4)" ;
label define GRPCNSL   1 "Yes (YESLFHLP = 1)"
                       2 "Otherwise (YESLFHLP = 2,85,89,94,97,98,99)" ;
label define LIVNBRHD  -9 "Otherwise" 1 "Less Than One Year (YELIVNBR = 1)"
                       2 "At least 1 yr but Less than 3 yrs (YELIVNBR = 2)"
                       3 "At least 3 yrs but Less than 5 yrs (YELIVNBR = 3)"
                       4 "At least 5 yrs but Less than 10 yrs (YELIVNBR = 4)"
                       5 "10 or More Years (YELIVNBR = 5)" ;
label define MOVIN5YR  -9 "Otherwise" 1 "None (YEMOV5Y2 = 0)"
                       2 "One Time (YEMOV5Y2 = 1)"
                       3 "Two Times (YEMOV5Y2 = 2)"
                       4 "Three Times (YEMOV5Y2 = 3)"
                       5 "Four Times (YEMOV5Y2 = 4)"
                       6 "5 or more times (YEMOV5Y2 = 5-6)" ;
label define NGHDBLDG  -9 "Otherwise" 1 "Strongly Agree (YEEMTBLD = 1)"
                       2 "Somewhat Agree (YEEMTBLD = 2)"
                       3 "Somewhat Disagree (YEEMTBLD = 3)"
                       4 "Strongly Disagree (YEEMTBLD = 4)" ;
label define NGHDCRIM  -9 "Otherwise" 1 "Strongly Agree (YECRIME = 1)"
                       2 "Somewhat Agree (YECRIME = 2)"
                       3 "Somewhat Disagree (YECRIME = 3)"
                       4 "Strongly Disagree (YECRIME = 4)" ;
label define NGHDFGHT  -9 "Otherwise" 1 "Strongly Agree (YESTFGT = 1)"
                       2 "Somewhat Agree (YESTFGT = 2)"
                       3 "Somewhat Disagree (YESTFGT = 3)"
                       4 "Strongly Disagree (YESTFGT = 4)" ;
label define NGHDGRAF  -9 "Otherwise" 1 "Strongly Agree (YEGRAFTI = 1)"
                       2 "Somewhat Agree (YEGRAFTI = 2)"
                       3 "Somewhat Disagree (YEGRAFTI = 3)"
                       4 "Strongly Disagree (YEGRAFTI = 4)" ;
label define NGHDHELP  -9 "Otherwise" 1 "Strongly Agree (YEPPHLP = 1)"
                       2 "Somewhat Agree (YEPPHLP = 2)"
                       3 "Somewhat Disagree (YEPPHLP = 3)"
                       4 "Strongly Disagree (YEPPHLP = 4)" ;
label define NGHDMOVE  -9 "Otherwise" 1 "Strongly Agree (YEPPMOVE = 1)"
                       2 "Somewhat Agree (YEPPMOVE = 2)"
                       3 "Somewhat Disagree (YEPPMOVE = 3)"
                       4 "Strongly Disagree (YEPPMOVE = 4)" ;
label define NGHDSELL  -9 "Otherwise" 1 "Strongly Agree (YESLLDG = 1)"
                       2 "Somewhat Agree (YESLLDG = 2)"
                       3 "Somewhat Disagree (YESLLDG = 3)"
                       4 "Strongly Disagree (YESLLDG = 4)" ;
label define NGHDVSIT  -9 "Otherwise" 1 "Strongly Agree (YEPPVSIT = 1)"
                       2 "Somewhat Agree (YEPPVSIT = 2)"
                       3 "Somewhat Disagree (YEPPVSIT = 3)"
                       4 "Strongly Disagree (YEPPVSIT = 4)" ;
label define PARALDLY  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEPALDLY = 1)"
                       2 "Somewhat Disapprove (YEPALDLY = 2)"
                       3 "Strongly Disapprove (YEPALDLY = 3)" ;
label define PARCHORE  -9 "Otherwise" 1 "Always (YEPCHORE = 1)"
                       2 "Sometimes (YEPCHORE = 2)" 3 "Seldom (YEPCHORE = 3)"
                       4 "Never (YEPCHORE = 4)" ;
label define PARGDJOB  -9 "Otherwise" 1 "Always (YEPGDJOB = 1)"
                       2 "Sometimes (YEPGDJOB = 2)" 3 "Seldom (YEPGDJOB = 3)"
                       4 "Never (YEPGDJOB = 4)" ;
label define PARLMTTV  -9 "Otherwise" 1 "Always (YEPLMTTV = 1)"
                       2 "Sometimes (YEPLMTTV = 2)" 3 "Seldom (YEPLMTTV = 3)"
                       4 "Never (YEPLMTTV = 4)" ;
label define PARMJEVR  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEPMJEVR = 1)"
                       2 "Somewhat Disapprove (YEPMJEVR = 2)"
                       3 "Strongly Disapprove (YEPMJEVR = 3)" ;
label define PARPKCIG  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEPPKCIG = 1)"
                       2 "Somewhat Disapprove (YEPPKCIG = 2)"
                       3 "Strongly Disapprove (YEPPKCIG = 3)" ;
label define PARPROUD  -9 "Otherwise" 1 "Always (YEPPROUD = 1)"
                       2 "Sometimes (YEPPROUD = 2)" 3 "Seldom (YEPPROUD = 3)"
                       4 "Never (YEPPROUD = 4)" ;
label define PRBSOLV   1 "Yes (YEPRBSLV = 1)"
                       2 "Otherwise (YEPRBSLV = 2,85,89,94,97,98,99)" ;
label define PREGPGM   1 "Yes (YEPRGSTD = 1)"
                       2 "Otherwise (YEPRGSTD = 2,85,89,94,97,98,99)" ;
label define PREVIOL   1 "Yes (YEVIOPRV = 1)"
                       2 "Otherwise (YEVIOPRV = 2,85,89,94,97,98,99)" ;
label define PRTALK2   1 "Yes (YEPARDNG = 1)"
                       2 "No (YEPARDNG = 2,85,89,94,97,98,99)" ;
label define PRVDRGO   1 "Yes (YEDGPRGP = 1)"
                       2 "Otherwise (YEDGPRGP = 2,85,89,94,97,98,99)" ;
label define TLKADULT  1 "Response Marked (Any Source = 1,3,11,13)"
                       2 "Response Not Marked (All Source = 6)"
                       3 "Unknown (All Source = 85,94,97,98)"
                       4 "Respondents Aged 18 + (All Source = 99)" ;
label define TLKBGF    1 "Response Marked (YETLKBGF = 1,3,11)"
                       2 "Response Not Marked (YETLKBGF = 6)"
                       3 "Unknown (YETLKBGF = 85,94,97,98)"
                       4 "Respondents Aged 18 + (YETLKBGF = 99)" ;
label define TLKDAD    1 "Response Marked (YETLKDAD = 1,3,11,13)"
                       2 "Response Not Marked (YETLKDAD = 6)"
                       3 "Unknown (YETLKDAD = 85,94,97,98)"
                       4 "Respondents Aged 18 + (YETLKDAD = 99)" ;
label define TLKMOM    1 "Response Marked (YETLKMOM = 1,3,11,13)"
                       2 "Response Not Marked (YETLKMOM = 6)"
                       3 "Unknown (YETLKMOM = 85,94,97,98)"
                       4 "Respondents Aged 18 + (YETLKMOM = 99)" ;
label define TLKNON    1 "Response Marked (YETLKNON = 1,11,13)"
                       2 "Response Not Marked (YETLKNON = 6)"
                       3 "Unknown (YETLKNON = 85,94,97,98)"
                       4 "Respondents Aged 18 + (YETLKNON = 99)" ;
label define TLKNONAD  1 "Response Marked (Any Source = 1,3,11,13)"
                       2 "Response Not marked (All Source = 6)"
                       3 "Unknown (All Source = 85,94,97,98)"
                       4 "Respondents Aged 18 + (All Source = 99)" ;
label define TLKOTHER  1 "Response Marked (Any Source = 1,3,11,13)"
                       2 "Response Not Marked (All Source = 6)"
                       3 "Unknown (All Source = 85,94,97,98)"
                       4 "Respondents Aged 18 + (All Source = 99)" ;
label define YTFLADLY  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEGALDLY = 1)"
                       2 "Somewhat Disapprove (YEGALDLY = 2)"
                       3 "Strongly Disapprove (YEGALDLY = 3)" ;
label define YTFLPKCG  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEGPKCIG = 1)"
                       2 "Somewhat Disapprove (YEGPKCIG = 2)"
                       3 "Strongly Disapprove (YEGPKCIG = 3)" ;
label define YTFLTMRJ  -9 "Otherwise"
                       1 "Neither Approve Nor Disapprove (YEGMJEVR = 1)"
                       2 "Somewhat Disapprove (YEGMJEVR = 2)"
                       3 "Strongly Disapprove (YEGMJEVR = 3)" ;
label define YTHARGUE  -9 "Otherwise" 1 "None (YEYARGUP = 1)"
                       2 "1 or 2 Times (YEYARGUP = 2)"
                       3 "3 to 5 Times (YEYARGUP = 3)"
                       4 "6 to 9 Times (YEYARGUP = 4)"
                       5 "10 or More Times (YEYARGUP = 5)" ;
label define YTHATTAK  -9 "Otherwise" 1 "None (YEYATTAK = 1)"
                       2 "1 or 2 Times (YEYATTAK = 2)"
                       3 "3 to 5 Times (YEYATTAK = 3)"
                       4 "6 to 9 Times (YEYATTAK = 4)"
                       5 "10 or More Times (YEYATTAK = 5)" ;
label define YTHFIGHT  -9 "Otherwise" 1 "None (YEYFGTSW = 1)"
                       2 "1 or 2 Times (YEYFGTSW = 2)"
                       3 "3 to 5 Times (YEYFGTSW = 3)"
                       4 "6 to 9 Times (YEYFGTSW = 4)"
                       5 "10 or More Times (YEYFGTSW = 5)" ;
label define YTHGRPFT  -9 "Otherwise" 1 "None (YEYFGTGP = 1)"
                       2 "1 or 2 Times (YEYFGTGP = 2)"
                       3 "3 to 5 Times (YEYFGTGP = 3)"
                       4 "6 to 9 Times (YEYFGTGP = 4)"
                       5 "10 or More Times (YEYFGTGP = 5)" ;
label define YTHHGUN   -9 "Otherwise" 1 "None (YEYHGUN = 1)"
                       2 "1 or 2 Times (YEYHGUN = 2)"
                       3 "3 to 5 Times (YEYHGUN = 3)"
                       4 "6 to 9 Times (YEYHGUN = 4)"
                       5 "10 or More Times (YEYHGUN = 5)" ;
label define YTHSELL   -9 "Otherwise" 1 "None (YEYSELL = 1)"
                       2 "1 or 2 Times (YEYSELL = 2)"
                       3 "3 to 5 Times (YEYSELL = 3)"
                       4 "6 to 9 Times (YEYSELL = 4)"
                       5 "10 or More Times (YEYSELL = 5)" ;
label define YTHSTOLE  -9 "Otherwise" 1 "None (YEYSTOLE = 1)"
                       2 "1 or 2 Times (YEYSTOLE = 2)"
                       3 "3 to 5 Times (YEYSTOLE = 3)"
                       4 "6 to 9 Times (YEYSTOLE = 4)"
                       5 "10 or More Times (YEYSTOLE = 5)" ;
label define IMOTHER   1 "R is 12-17, mother in hh"
                       2 "R is 12-17, no mother in hh"
                       3 "R is 12-17, don't know whether mother is in hh"
                       4 "R is 18 or older" ;
label define IFATHER   1 "R is 12-17, father in hh"
                       2 "R is 12-17, no father in hh"
                       3 "R is 12-17, don't know whether father is in hh"
                       4 "R is 18 or older" ;
label define IRHHSIZ2  1 "One person in household"
                       2 "Two people in household"
                       3 "Three people in household"
                       4 "Four people in household"
                       5 "Five people in household"
                       6 "6 to 25 people in household" ;
label define IIHHSIZ2  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHH65_2  1 "No people 65 or older in household"
                       2 "One person 65 or older in household"
                       3 "Two or more people 65 or older in household" ;
label define IIHH65_2  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRKI17_2  1 "No children under 18" 2 "One child under 18"
                       3 "Two children under 18"
                       4 "Three or more children under 18" ;
label define IIKI17_2  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define PREGNANT  1 "Yes" 2 "No" 11 "Yes (but potentially inconsistent)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NMERTMT2  31 "31 or more" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NMHSPOV2  31 "31 or more" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NMHSPPE2  31 "31 or more" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define OUTPEYR   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PROXANS2  1 "Yes" 2 "No" 7 "Unclear LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (Respondent answering)" ;
label define PREG      0 "Otherwise"
                       1 "Pregnant Females Aged 12-44 (PREGNANT=1,11)" ;
label define PREG2     -9 "Unknown (PREGNANT = 94,97,98)"
                       1 "Pregnant (PREGNANT=1,11)"
                       2 "Not Pregnant (PREGNANT=2)"
                       3 "Males/Females not age 12-44 (PREGNANT=99)" ;
label define TRIMEST   -9 "Unknown" 1 "1st 3 months of pregnancy"
                       2 "2nd 3 months of pregnancy"
                       3 "Last 3 months of pregnancy"
                       4 "Males/Not Pregnant Females" ;
label define IRPSOC    1 "Yes" 2 "No" ;
label define IIPSOC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMSOC  1 "Yes" 2 "No" ;
label define IIFAMSOC  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPSSI    1 "Yes" 2 "No" ;
label define IIPSSI    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMSSI  1 "Yes" 2 "No" ;
label define IIFAMSSI  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFSTAMP  1 "Yes" 2 "No" ;
label define IIFSTAMP  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPPMT    1 "Yes" 2 "No" ;
label define IIPPMT    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMPMT  1 "Yes" 2 "No" ;
label define IIFAMPMT  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPSVC    1 "Yes" 2 "No" ;
label define IIPSVC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMSVC  1 "Yes" 2 "No" ;
label define IIFAMSVC  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRWELMOS  99 "LEGITIMATE SKIP" ;
label define IIWELMOS  1 "Questionnaire data" 2 "Logically Assigned data"
                       3 "Statistically imputed data" 9 "Legitimate skip" ;
label define IRPINT    1 "Yes" 2 "No" ;
label define IIPINT    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMINT  1 "Yes" 2 "No" ;
label define IIFAMINT  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPCHD    1 "Yes" 2 "No" ;
label define IIPCHD    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMCHD  1 "Yes" 2 "No" ;
label define IIFAMCHD  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPWAG    1 "Yes" 2 "No" ;
label define IIPWAG    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMWAG  1 "Yes" 2 "No" ;
label define IIFAMWAG  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPOTH    1 "Yes" 2 "No" ;
label define IIPOTH    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMOTH  1 "Yes" 2 "No" ;
label define IIFAMOTH  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPINC3   1 "$0 - $9,999 (Including Loss)" 2 "$10,000 - $19,999"
                       3 "$20,000 - $29,999" 4 "$30,000 - $39,999"
                       5 "$40,000 - $49,999" 6 "$50,000 - $74,999"
                       7 "$75,000 or more" ;
label define IIPINC3   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMIN3  1 "$0 - $9,999 (Including Loss)" 2 "$10,000 - $19,999"
                       3 "$20,000 - $29,999" 4 "$30,000 - $39,999"
                       5 "$40,000 - $49,999" 6 "$50,000 - $74,999"
                       7 "$75,000 or more" ;
label define IIFAMIN3  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define HLCALLFG  1 "Answered yes to all current health insurance Qs"
                       98 "BLANK (NO ANSWER)" ;
label define MEDICARE  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MEDICAID  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CHAMPUS   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PRVHLTIN  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GRPHLTIN  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLTINALC  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLTINDRG  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLTINMNT  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLCNOTYR  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLCNOTMO  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCLAST   1 "Within the past 6 months"
                       2 "More than 6 months ago, but within the past year"
                       3 "More than 1 year ago, but within the past 3 years"
                       4 "More than 3 years ago" 5 "Never had coverage"
                       11 "Within the past 6 months (HLLSORS2=90)"
                       13 "More than 1 yr ago but w/in pst 3 yr (HLLSORS2=90)"
                       14 "More than 3 years ago (HLLSORS2=90)"
                       15 "Never had coverage (HLNVSP2=90,92)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCPRIVT  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLCMCAID  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCMILT   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCMCARE  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCOGOVT  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLCOTHER  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCOTHS2  1 "Private health insurance"
                       2 "Medicaid or medical assistance"
                       5 "Some other government program"
                       6 "Some other kind of coverage"
                       7 "Public health service/indian hlth hospital or clnc"
                       8 "Health care coverage outside of usa"
                       9 "School/sport-related health care coverage"
                       61 "Does not have medical insurance"
                       85 "BAD DATA Logically assigned"
                       90 "NEVER HAD HEALTH CARE COVERAGE" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLLLOSJB  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLLMAJOB  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (potl incons w/last coverage)"
                       13 "Response entered LOG ASSN (potl incons)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLLMASOR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       11 "Response entered (potl incons w/last coverage)"
                       13 "Response entered LOG ASSN (potl incons)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLLCOST   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLLINELG  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLLNOFFR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLLDIVOR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLLDEATH  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLLREFUS  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLLNONED  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLLSOR    1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLLSORS2  1 "Person in family w/ ins lost job/chngd employers"
                       2 "Lost medicaid or med assist cov b/c new job/income"
                       3 "Lost medicaid or med assist cov for other reason"
                       4 "Cost is too high/can't afford premiums"
                       5 "Became ineligible b/c of age or leaving school"
                       6 "Employer doesn't offer cov/not eligible for cov"
                       7 "Got divorced or separated from person w/ ins"
                       9 "Insurance company refused coverage"
                       10 "Don't need it" 11 "Some other reason"
                       12 "Have not applied or reapplied for ins coverage"
                       13 "Applied ins/medicaid,waiting for activation/eligib"
                       14 "Ineligible b/c moved out of parents home/got marri"
                       16 "Non-us citizen"
                       19 "Self-employed/parents self-employed"
                       20 "Dissatisfied with previous/available coverage"
                       21 "Don't believe in/trust medical profession/ins co"
                       22 "Had ins in another country before moving to US"
                       23 "Moved/don't have same coverage"
                       25 "Don't qualify, no reason specified"
                       26 "Dropped coverage, no reason specified"
                       39 "Employer/respondent is changing insurance plans"
                       41 "Parent/guardian doesn't/won't provide coverage"
                       42 "Ins co didn't receive payment/paperwork in time"
                       44 "Student/becoming stdnt(elg for oth cov unk)"
                       85 "BAD DATA LOGICALLY ASSIGNED"
                       90 "CURRENTLY COVERED BY HEALTH INSURANCE"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLNVCOST  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLNVOFFR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLNVREF   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLNVNEED  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLNVSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLNVSP2   1 "Cost is too high/can't afford premiums"
                       2 "Employer doesn't offer cov/not eligible for cov"
                       3 "Insurance company refused coverage"
                       4 "Don't need it" 5 "Some other reason"
                       7 "Have never applied for/thought about ins covrg"
                       8 "Religious beliefs/don't trust medical prof/ins co"
                       11 "No one has ever offered" 12 "Non-US citizen"
                       13 "Don't want insurance" 14 "Prefer to pay cash"
                       15 "Never had insurance, no reason specified"
                       16 "Parent/guardian don't/won't provide coverage"
                       17 "Ineligible, other reasons"
                       85 "BAD DATA Logically assigned"
                       90 "CURRENTLY COVERED BY HEALTH INSURANCE"
                       91 "ASSISTANCE PROVIDED BY CHURCH/COMMUNITY"
                       92 "HAVE BEEN COVERED BY HEALTH INSURANCE IN PAST"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IRPINSUR  1 "Yes, respondent does have private health insurance"
                       2 "No, respondent does not have private health insur" ;
label define IIPINSUR  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRINSUR   1 "Yes, respondent does have health insurance"
                       2 "No, respondent does not have health insurance" ;
label define IIINSUR   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define LANGVER   1 "English" 2 "Spanish" 98 "BLANK (NO ANSWER)" ;
label define QUARTER   1 "Quarter 1" 2 "Quarter 2" 3 "Quarter 3"
                       4 "Quarter 4" ;
label define QTRFIELD  1 "Quarter 1" 2 "Quarter 2" 3 "Quarter 3"
                       4 "Quarter 4" ;
label define GQTYPE    -9 "Not a Group Quarter" 1 "Halfway House"
                       2 "Boarding House" 3 "College Dorm" 4 "Shelter"
                       5 "Other" ;
label define AGE2      1 "Respondent is 12 years old"
                       2 "Respondent is 13 years old"
                       3 "Respondent is 14 years old"
                       4 "Respondent is 15 years old"
                       5 "Respondent is 16 years old"
                       6 "Respondent is 17 years old"
                       7 "Respondent is 18 years old"
                       8 "Respondent is 19 years old"
                       9 "Respondent is 20 years old"
                       10 "Respondent is 21 years old"
                       11 "Respondent is 22 or 23 years old"
                       12 "Respondent is 24 or 25 years old"
                       13 "Respondent is between 26 and 29 years old"
                       14 "Respondent is between 30 and 34 years old"
                       15 "Respondent is between 35 and 49 years old"
                       16 "Respondent is between 50 and 64 years old"
                       17 "Respondent is 65 years old or older" ;
label define NOMARR2   1 "One time" 2 "Two or more times" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SERVICE   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MILSTAT   2 "In a reserves component"
                       3 "Now separated/retired from reserves/active duty"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HEALTH    1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex from questionnaire" 2 "Sex from screener" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Been Married" 99 "LEGITIMATE SKIP" ;
label define IIMARIT   1 "Marital status from questionnaire"
                       3 "Marital status statistically imputed"
                       9 "LEGITIMATE SKIP Respondent is <= 14 years old" ;
label define IREDUC2   1 "Fifth grade or less" 2 "Sixth grade"
                       3 "Seventh grade" 4 "Eighth grade" 5 "Ninth grade"
                       6 "Tenth grade" 7 "Eleventh grade" 8 "Twelfth grade"
                       9 "Freshman/13th year"
                       10 "Sophomore/14th year or Junior/15th year"
                       11 "Senior/16th year or Graduate/Prof School (or highe" ;
label define IIEDUC2   1 "Education from questionnaire"
                       3 "Education statistically imputed" ;
label define EMPSTAT3  1 "Employed full time" 2 "Employed part time"
                       3 "Unemployed" 4 "Other" 5 "12-17 year olds" ;
label define IIEMPST3  1 "Employment status from questionnaire"
                       3 "Employment statistically imputed"
                       4 "12-17 years old" ;
label define EMPSTAT4  1 "Employed full time" 2 "Employed part time"
                       3 "Unemployed" 4 "Other (incl. not in labor force)"
                       5 "12-17 year olds" ;
label define IIEMPST4  1 "Employment status from questionnaire"
                       3 "Employment statistically imputed"
                       4 "12-17 years old" ;
label define EMPSTATY  1 "Employed full time" 2 "Employed part time"
                       3 "Unemployed" 4 "Other" 5 "12-17 year olds" ;
label define IIEMPSTY  1 "Employment status from questionnaire"
                       3 "Employment statistically imputed"
                       4 "12-17 years old" ;
label define NRCH17_2  -9 "Missing" 0 "No children" 1 "One child"
                       2 "Two children" 3 "Three or more children" ;
label define MOVESPY2  0 "None" 1 "One time" 2 "Two times"
                       3 "Three or more times" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define ENROLED   1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (LFSCHRS2=777,778)"
                       5 "Yes LOGICALLY ASSIGNED (LFSCHRS2=601)"
                       11 "Yes (SCHDSKIP = 30)"
                       52 "Summer interview (not enrolled & HSDIPLMA=4)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EDUCNOW2  1 "2nd Grade through 5th Grade" 2 "6th Grade"
                       3 "7th Grade" 4 "8th Grade" 5 "9th Grade"
                       6 "10th Grade" 7 "11th Grade" 8 "12th Grade"
                       9 "College or university/1st year"
                       10 "College or university/2nd Year, 3rd year"
                       11 "College or university/4th Year, 5th or higher year"
                       12 "Missing" 13 "LEGITIMATE SKIP" ;
label define STUDNT    1 "FULL-TIME" 2 "PART-TIME" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SCHDSICK  0 "None" 85 "BAD DATA Logically assigned"
                       90 "SCHOOL NOT IN SESSION" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SCHDSKIP  0 "None" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HSDIPLMA  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HSGED     1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LFSCHRS2  1 "School was boring" 2 "I got pregnant"
                       3 "I got expelled for selling drugs"
                       4 "I got expelled for using drugs"
                       5 "I got expelled for some other reason"
                       6 "I had to get a job (or work more hours)"
                       7 "I was getting bad grades"
                       8 "I wasn't learning anything"
                       9 "I got married (or moved in with boy/girlfriend)"
                       10 "I moved here from another country"
                       11 "I was treated badly at school"
                       12 "I became ill (or injured)"
                       13 "I went to jail/prison" 14 "Other reason"
                       41 "Family member became ill/sick/died"
                       42 "Responsibilities at home/family/personal problems"
                       43 "Parents/guardian/partner wouldn't allow me to"
                       44 "Ran away from/put out of/placed out of home"
                       45 "Too stressful/couldn't adjust"
                       48 "Running with the wrong crowd/getting in trouble"
                       49 "Afraid of gangs/fear of violence/crime"
                       50 "Moved away/didn't re-enroll"
                       51 "Skipping school/excessive absenteeism"
                       52 "Too expensive/couldn't afford"
                       53 "Didn't like it/didn't want to go/not interested"
                       56 "Grade,credit discrepancies/lacked credits/document"
                       57 "Involved with too many activities to go to school"
                       58 "All the schooling/preferred that was available"
                       59 "Wasn't required/didn't have to/not needed/customs"
                       60 "Against my religion/beliefs"
                       63 "I was stupid/foolish" 66 "Too old"
                       67 "Wanted to work/do apprenticeship instead"
                       69 "Just quit; reason unspecified"
                       70 "Did not have a permanent address"
                       71 "Didn't pass/take end of grade/school test"
                       72 "Went to group home/foster home/special home"
                       75 "Was abusing drugs/alcohol" 601 "Home schooled"
                       605 "Completed HS/certificate, general"
                       607 "Pursuing GED/proficiency exam/re-enrolling"
                       777 "Summer/school not in session"
                       778 "I am still in school"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LFTSCHA2  10 "Left at age 10 or younger"
                       19 "Left at age 19 or older"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define JOBSTAT2  1 "Worked at full-time job, past week"
                       2 "Worked at part time job, past week"
                       3 "Has job or volunteer worker, did not work past wee"
                       4 "Unemployed/on layoff, looking for work"
                       5 "Disabled" 6 "Keeping house full-time"
                       7 "In school/training" 8 "Retired"
                       9 "Does not have a job, some other reason"
                       10 "MISSING" 11 "LEGITIMATE SKIP" ;
label define JBSTATR2  1 "Worked at full-time job, past week"
                       2 "Worked at part time job, past week"
                       3 "Has job but out: vacation/sick/temp absence"
                       4 "Has job but out: layoff, looking for work"
                       5 "Has job but out: layoff, not looking for work"
                       6 "Has job but out: waiting to report to new job"
                       7 "Has job but out: self-employed, no business"
                       8 "Has job but out: in school/training"
                       9 "No job: unemp/layoff, looking for work"
                       10 "No job: layoff, not looking for work"
                       11 "No job: keeping house full time" ;
label define WRKHAVJB  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WRKHRSWK  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WRKEFFRT  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WRKEDYR   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WRKSLFEM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKJOBS2  1 "One" 2 "Two" 3 "Three" 4 "Four or more"
                       975 "At least one LOGICALLY ASSIGNED" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WRKUNEMP  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKUNWKS  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKLASY2  1960 "1960 or earlier"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER WORKED FOR PAY" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define WORKDAYS  0 "None" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKBLAH  0 "None" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LOCSIZE   1 "Less than 10 people" 2 "10-24 people"
                       3 "25-99 people" 4 "100-499 people"
                       5 "500 people or more" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DRGPLCY   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PLCYCOV   1 "Only alcohol" 2 "Only drugs"
                       3 "Both alcohol and drugs" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WKDRGED   1 "Yes" 2 "No" 3 "Don't remember" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRGPRGM   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define USALCTST  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define USDRGTST  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TSTHIRE   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TSTRAND   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FIRSTPOS  1 "Handled on indiv basis/policy does not spec what"
                       2 "Employee is fired"
                       3 "Employee is referred for treatment or counseling"
                       4 "Nothing happens" 5 "Something else happens"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKHIRE   1 "More likely" 2 "Less likely"
                       3 "Would it make no difference to you" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKRAND  1 "More likely" 2 "Less likely"
                       3 "Would make no difference" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define RLGSVCYR  1 "0 times" 2 "1 to 2 times" 3 "3 to 5 times"
                       4 "6 to 24 times" 5 "25 to 52 times"
                       6 "More than 52 times" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RLGIMPRT  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RLGDECSN  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RLGFRNDS  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TELNO2    0 "None" 1 "One" 2 "Two or more" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COLLEGE2  -9 "Unknwn Enrollment, Aged 18-22"
                       1 "Full-Time College Student Aged 18-22"
                       2 "Part-Time College Student Aged 18-22"
                       3 "Not Enrolled" 4 "Others Persons Aged 18-22"
                       5 "Persons Aged 12-17, or 23 or Older" ;
label define CATAGE    1 "12-17 Years Old" 2 "18-25 Years Old"
                       3 "26-34 Years Old" 4 "35 or Older" ;
label define CATAG2    1 "12-17 Years Old" 2 "18-25 Years Old"
                       3 "26 or Older" ;
label define CATAG3    1 "12-17 Years Old" 2 "18-25 Years Old"
                       3 "26-34 Years Old" 4 "35-49 Years Old"
                       5 "50 or Older" ;
label define NEWRACE2  1 "NonHisp White" 2 "NonHisp Black/Afr Am"
                       3 "NonHisp Native Am/AK Native"
                       4 "NonHisp Native HI/Other Pac Isl" 5 "NonHisp Asian"
                       6 "NonHisp More than one race" 7 "Hispanic" ;
label define EDUCCAT2  1 "Less than high school" 2 "High school graduate"
                       3 "Some college" 4 "College graduate"
                       5 "12 to 17 year olds (1<=AGE2<=6)" ;
label define PDEN      1 "Segment in a MSA with 1 million or more persons"
                       2 "Segment in a MSA with fewer than 1 million persons"
                       3 "Segment not in a MSA" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CIGOFRSM = . if (CIGOFRSM >= 81 )
replace CIGWILYR = . if (CIGWILYR >= 81 )
replace CIGTRY = . if (CIGTRY >= 981 )
replace CIGYFU = . if (CIGYFU >= 9981 )
replace CIGMFU = . if (CIGMFU >= 81 )
replace CIGREC = . if (CIGREC >= 81 )
replace CIG30USE = . if (CIG30USE >= 81 )
replace CG30EST = . if (CG30EST >= 81 )
replace CIG30AV = . if (CIG30AV >= 81 )
replace CIG30BR2 = . if (CIG30BR2 >= 9981 )
replace CIG30RO2 = . if (CIG30RO2 >= 81 )
replace CIGDLYMO = . if (CIGDLYMO >= 81 )
replace CIGAGE = . if (CIGAGE >= 981 )
replace CIG100LF = . if (CIG100LF >= 81 )
replace CHEWEVER = . if (CHEWEVER >= 81 )
replace CHEWTRY = . if (CHEWTRY >= 981 )
replace CHEWYFU = . if (CHEWYFU >= 9981 )
replace CHEWMFU = . if (CHEWMFU >= 81 )
replace CHEWREC = . if (CHEWREC >= 81 )
replace CHW30USE = . if (CHW30USE >= 81 )
replace CHW30BR2 = . if (CHW30BR2 >= 9981 )
replace SNFEVER = . if (SNFEVER >= 81 )
replace SNUFTRY = . if (SNUFTRY >= 981 )
replace SNUFYFU = . if (SNUFYFU >= 9981 )
replace SNUFMFU = . if (SNUFMFU >= 81 )
replace SNFREC = . if (SNFREC >= 81 )
replace SNF30USE = . if (SNF30USE >= 81 )
replace SNF30BR2 = . if (SNF30BR2 >= 9981 )
replace SLTTRY = . if (SLTTRY >= 981 )
replace SLTYFU = . if (SLTYFU >= 9981 )
replace SLTMFU = . if (SLTMFU >= 81 )
replace SLTREC = . if (SLTREC >= 81 )
replace SLT30BR2 = . if (SLT30BR2 >= 9981 )
replace SLT30FAV = . if (SLT30FAV >= 81 )
replace CIGAREVR = . if (CIGAREVR >= 81 )
replace CIGARTRY = . if (CIGARTRY >= 981 )
replace CIGARYFU = . if (CIGARYFU >= 9981 )
replace CIGARMFU = . if (CIGARMFU >= 81 )
replace CIGARREC = . if (CIGARREC >= 81 )
replace CGR30USE = . if (CGR30USE >= 81 )
replace CI30EST = . if (CI30EST >= 81 )
replace CGR30BR2 = . if (CGR30BR2 >= 9981 )
replace PIPEVER = . if (PIPEVER >= 81 )
replace PIPE30DY = . if (PIPE30DY >= 81 )
replace ALCEVER = . if (ALCEVER >= 81 )
replace ALCTRY = . if (ALCTRY >= 981 )
replace ALCYFU = . if (ALCYFU >= 9981 )
replace ALCMFU = . if (ALCMFU >= 81 )
replace ALCREC = . if (ALCREC >= 81 )
replace ALCYRTOT = . if (ALCYRTOT >= 981 )
replace ALTOTFG = . if (ALTOTFG >= 81 )
replace ALFQFLG = . if (ALFQFLG >= 81 )
replace ALBSTWAY = . if (ALBSTWAY >= 81 )
replace ALDAYPYR = . if (ALDAYPYR >= 981 )
replace ALDAYPMO = . if (ALDAYPMO >= 81 )
replace ALDAYPWK = . if (ALDAYPWK >= 81 )
replace ALCDAYS = . if (ALCDAYS >= 81 )
replace ALDYSFG = . if (ALDYSFG >= 81 )
replace NODR30A = . if (NODR30A >= 975 )
replace DR5DAY = . if (DR5DAY >= 80 )
replace MJEVER = . if (MJEVER >= 81 )
replace MJAGE = . if (MJAGE >= 981 )
replace MJYFU = . if (MJYFU >= 9981 )
replace MJMFU = . if (MJMFU >= 81 )
replace MJREC = . if (MJREC >= 81 )
replace MJYRTOT = . if (MJYRTOT >= 981 )
replace MRTOTFG = . if (MRTOTFG >= 81 )
replace MJFQFLG = . if (MJFQFLG >= 81 )
replace MRBSTWAY = . if (MRBSTWAY >= 81 )
replace MRDAYPYR = . if (MRDAYPYR >= 981 )
replace MRDAYPMO = . if (MRDAYPMO >= 81 )
replace MRDAYPWK = . if (MRDAYPWK >= 81 )
replace MJDAY30A = . if (MJDAY30A >= 81 )
replace COCEVER = . if (COCEVER >= 81 )
replace COCAGE = . if (COCAGE >= 981 )
replace COCYFU = . if (COCYFU >= 9981 )
replace COCMFU = . if (COCMFU >= 81 )
replace COCREC = . if (COCREC >= 81 )
replace COCYRTOT = . if (COCYRTOT >= 981 )
replace CCTOTFG = . if (CCTOTFG >= 81 )
replace CCFQFLG = . if (CCFQFLG >= 81 )
replace CCBSTWAY = . if (CCBSTWAY >= 81 )
replace CCDAYPYR = . if (CCDAYPYR >= 981 )
replace CCDAYPMO = . if (CCDAYPMO >= 81 )
replace CCDAYPWK = . if (CCDAYPWK >= 81 )
replace COCUS30A = . if (COCUS30A >= 81 )
replace CRKEVER = . if (CRKEVER >= 81 )
replace CRKAGE = . if (CRKAGE >= 981 )
replace CRKYFU = . if (CRKYFU >= 9981 )
replace CRKMFU = . if (CRKMFU >= 81 )
replace CRAKREC = . if (CRAKREC >= 81 )
replace CRKYRTOT = . if (CRKYRTOT >= 981 )
replace CRTOTFG = . if (CRTOTFG >= 81 )
replace CRFQFLG = . if (CRFQFLG >= 81 )
replace CRBSTWAY = . if (CRBSTWAY >= 81 )
replace CRDAYPYR = . if (CRDAYPYR >= 981 )
replace CRDAYPMO = . if (CRDAYPMO >= 81 )
replace CRDAYPWK = . if (CRDAYPWK >= 81 )
replace CRKUS30A = . if (CRKUS30A >= 81 )
replace HEREVER = . if (HEREVER >= 81 )
replace HERAGE = . if (HERAGE >= 981 )
replace HERYFU = . if (HERYFU >= 9981 )
replace HERMFU = . if (HERMFU >= 81 )
replace HERREC = . if (HERREC >= 81 )
replace HERYRTOT = . if (HERYRTOT >= 981 )
replace HRTOTFG = . if (HRTOTFG >= 81 )
replace HRFQFLG = . if (HRFQFLG >= 81 )
replace HRBSTWAY = . if (HRBSTWAY >= 81 )
replace HRDAYPYR = . if (HRDAYPYR >= 981 )
replace HRDAYPMO = . if (HRDAYPMO >= 81 )
replace HRDAYPWK = . if (HRDAYPWK >= 81 )
replace HER30USE = . if (HER30USE >= 81 )
replace LSD = . if (LSD >= 81 )
replace PCP = . if (PCP >= 81 )
replace PEYOTE = . if (PEYOTE >= 81 )
replace MESC = . if (MESC >= 81 )
replace PSILCY = . if (PSILCY >= 81 )
replace ECSTASY = . if (ECSTASY >= 81 )
replace HALNOLST = . if (HALNOLST >= 81 )
replace HALNEWA = . if (HALNEWA >= 9981 )
replace HALNEWB = . if (HALNEWB >= 9981 )
replace HALNEWC = . if (HALNEWC >= 9981 )
replace HALNEWD = . if (HALNEWD >= 9981 )
replace HALNEWE = . if (HALNEWE >= 9981 )
replace HALLAGE = . if (HALLAGE >= 981 )
replace HALYFU = . if (HALYFU >= 9981 )
replace HALMFU = . if (HALMFU >= 81 )
replace HALLREC = . if (HALLREC >= 81 )
replace HALYRTOT = . if (HALYRTOT >= 981 )
replace HLTOTFG = . if (HLTOTFG >= 81 )
replace HLFQFLG = . if (HLFQFLG >= 81 )
replace HLBSTWAY = . if (HLBSTWAY >= 81 )
replace HLDAYPYR = . if (HLDAYPYR >= 981 )
replace HLDAYPMO = . if (HLDAYPMO >= 81 )
replace HLDAYPWK = . if (HLDAYPWK >= 81 )
replace HAL30USE = . if (HAL30USE >= 81 )
replace LSDREC = . if (LSDREC >= 81 )
replace PCPREC = . if (PCPREC >= 81 )
replace AMYLNIT = . if (AMYLNIT >= 81 )
replace CLEFLU = . if (CLEFLU >= 81 )
replace GAS = . if (GAS >= 81 )
replace GLUE = . if (GLUE >= 81 )
replace ETHER = . if (ETHER >= 81 )
replace SOLVENT = . if (SOLVENT >= 81 )
replace LGAS = . if (LGAS >= 81 )
replace NITOXID = . if (NITOXID >= 81 )
replace SPPAINT = . if (SPPAINT >= 81 )
replace AEROS = . if (AEROS >= 81 )
replace INHNOLST = . if (INHNOLST >= 81 )
replace INHNEWA = . if (INHNEWA >= 9981 )
replace INHNEWB = . if (INHNEWB >= 9981 )
replace INHNEWC = . if (INHNEWC >= 9981 )
replace INHNEWD = . if (INHNEWD >= 9981 )
replace INHNEWE = . if (INHNEWE >= 9981 )
replace INHAGE = . if (INHAGE >= 981 )
replace INHYFU = . if (INHYFU >= 9981 )
replace INHMFU = . if (INHMFU >= 81 )
replace INHREC = . if (INHREC >= 81 )
replace INHYRTOT = . if (INHYRTOT >= 981 )
replace INTOTFG = . if (INTOTFG >= 81 )
replace INFQFLG = . if (INFQFLG >= 81 )
replace INBSTWAY = . if (INBSTWAY >= 81 )
replace INDAYPYR = . if (INDAYPYR >= 981 )
replace INDAYPMO = . if (INDAYPMO >= 81 )
replace INDAYPWK = . if (INDAYPWK >= 81 )
replace INHDY30A = . if (INHDY30A >= 81 )
replace DARVTYLC = . if (DARVTYLC >= 81 )
replace PERCTYLX = . if (PERCTYLX >= 81 )
replace VICOLOR = . if (VICOLOR >= 81 )
replace ANLCARD = . if (ANLCARD >= 81 )
replace CODEINE = . if (CODEINE >= 81 )
replace DEMEROL = . if (DEMEROL >= 81 )
replace DILAUD = . if (DILAUD >= 81 )
replace FIORICET = . if (FIORICET >= 81 )
replace FIORINAL = . if (FIORINAL >= 81 )
replace HYDROCOD = . if (HYDROCOD >= 81 )
replace METHDON = . if (METHDON >= 81 )
replace MORPHINE = . if (MORPHINE >= 81 )
replace OXYCONTN = . if (OXYCONTN >= 81 )
replace PHENCOD = . if (PHENCOD >= 81 )
replace PROPOXY = . if (PROPOXY >= 81 )
replace SK65A = . if (SK65A >= 81 )
replace STADOL = . if (STADOL >= 81 )
replace TALACEN = . if (TALACEN >= 81 )
replace TALWIN = . if (TALWIN >= 81 )
replace TALWINNX = . if (TALWINNX >= 81 )
replace TRAMADOL = . if (TRAMADOL >= 81 )
replace ULTRAM = . if (ULTRAM >= 81 )
replace ANLNOLST = . if (ANLNOLST >= 81 )
replace ANALNEWA = . if (ANALNEWA >= 9981 )
replace ANALNEWB = . if (ANALNEWB >= 9981 )
replace ANALNEWC = . if (ANALNEWC >= 9981 )
replace ANALNEWD = . if (ANALNEWD >= 9981 )
replace ANALNEWE = . if (ANALNEWE >= 9981 )
replace ANALAGE = . if (ANALAGE >= 981 )
replace ANALYFU = . if (ANALYFU >= 9981 )
replace ANALMFU = . if (ANALMFU >= 81 )
replace ANALREC = . if (ANALREC >= 81 )
replace ANLYRTOT = . if (ANLYRTOT >= 981 )
replace PRTOTFG = . if (PRTOTFG >= 81 )
replace PRFQFLG = . if (PRFQFLG >= 81 )
replace PRBSTWAY = . if (PRBSTWAY >= 81 )
replace PRDAYPYR = . if (PRDAYPYR >= 981 )
replace PRDAYPMO = . if (PRDAYPMO >= 81 )
replace PRDAYPWK = . if (PRDAYPWK >= 81 )
replace KLONOPIN = . if (KLONOPIN >= 81 )
replace XNAXATVN = . if (XNAXATVN >= 81 )
replace VALMDIAZ = . if (VALMDIAZ >= 81 )
replace TRNCARD = . if (TRNCARD >= 81 )
replace ATARAX = . if (ATARAX >= 81 )
replace BUSPAR = . if (BUSPAR >= 81 )
replace EQUANIL = . if (EQUANIL >= 81 )
replace FLEXERIL = . if (FLEXERIL >= 81 )
replace LIBRIUM = . if (LIBRIUM >= 81 )
replace LIMBTROL = . if (LIMBTROL >= 81 )
replace MEPROB = . if (MEPROB >= 81 )
replace MILTOWN = . if (MILTOWN >= 81 )
replace ROHYPNOL = . if (ROHYPNOL >= 81 )
replace SERAX = . if (SERAX >= 81 )
replace SOMA = . if (SOMA >= 81 )
replace TRANXENE = . if (TRANXENE >= 81 )
replace VISTAR = . if (VISTAR >= 81 )
replace TRNOLST = . if (TRNOLST >= 81 )
replace TRNEWA = . if (TRNEWA >= 9981 )
replace TRNEWB = . if (TRNEWB >= 9981 )
replace TRNEWC = . if (TRNEWC >= 9981 )
replace TRNEWD = . if (TRNEWD >= 9981 )
replace TRNEWE = . if (TRNEWE >= 9981 )
replace TRANAGE = . if (TRANAGE >= 981 )
replace TRANYFU = . if (TRANYFU >= 9981 )
replace TRANMFU = . if (TRANMFU >= 81 )
replace TRANREC = . if (TRANREC >= 81 )
replace TRNYRTOT = . if (TRNYRTOT >= 981 )
replace TRTOTFG = . if (TRTOTFG >= 81 )
replace TRFQFLG = . if (TRFQFLG >= 81 )
replace TRBSTWAY = . if (TRBSTWAY >= 81 )
replace TRDAYPYR = . if (TRDAYPYR >= 981 )
replace TRDAYPMO = . if (TRDAYPMO >= 81 )
replace TRDAYPWK = . if (TRDAYPWK >= 81 )
replace METHDES = . if (METHDES >= 81 )
replace DIETPILS = . if (DIETPILS >= 81 )
replace RITMPHEN = . if (RITMPHEN >= 81 )
replace STMCARD = . if (STMCARD >= 81 )
replace CYLERT = . if (CYLERT >= 81 )
replace DEXED = . if (DEXED >= 81 )
replace DETAMP = . if (DETAMP >= 81 )
replace DIDREX = . if (DIDREX >= 81 )
replace ESKAT = . if (ESKAT >= 81 )
replace IONAMIN = . if (IONAMIN >= 81 )
replace MAZANOR = . if (MAZANOR >= 81 )
replace OBLA = . if (OBLA >= 81 )
replace PLEGINE = . if (PLEGINE >= 81 )
replace PRELUDIN = . if (PRELUDIN >= 81 )
replace SANOREX = . if (SANOREX >= 81 )
replace TENUATE = . if (TENUATE >= 81 )
replace STMNOLST = . if (STMNOLST >= 81 )
replace STIMNEWA = . if (STIMNEWA >= 9981 )
replace STIMNEWB = . if (STIMNEWB >= 9981 )
replace STIMNEWC = . if (STIMNEWC >= 9981 )
replace STIMNEWD = . if (STIMNEWD >= 9981 )
replace STIMNEWE = . if (STIMNEWE >= 9981 )
replace STIMAGE = . if (STIMAGE >= 981 )
replace STIMYFU = . if (STIMYFU >= 9981 )
replace STIMMFU = . if (STIMMFU >= 81 )
replace STIMREC = . if (STIMREC >= 81 )
replace STMYRTOT = . if (STMYRTOT >= 981 )
replace STTOTFG = . if (STTOTFG >= 81 )
replace STFQFLG = . if (STFQFLG >= 81 )
replace STBSTWAY = . if (STBSTWAY >= 81 )
replace STDAYPYR = . if (STDAYPYR >= 981 )
replace STDAYPMO = . if (STDAYPMO >= 81 )
replace STDAYPWK = . if (STDAYPWK >= 81 )
replace METHAGE = . if (METHAGE >= 981 )
replace METHYFU = . if (METHYFU >= 9981 )
replace METHMFU = . if (METHMFU >= 81 )
replace METHREC = . if (METHREC >= 81 )
replace METHAQ = . if (METHAQ >= 81 )
replace NEMBBARB = . if (NEMBBARB >= 81 )
replace RESTTMAZ = . if (RESTTMAZ >= 81 )
replace SEDCARD = . if (SEDCARD >= 81 )
replace AMYTAL = . if (AMYTAL >= 81 )
replace BUTISOL = . if (BUTISOL >= 81 )
replace CHHYD = . if (CHHYD >= 81 )
replace DALMANE = . if (DALMANE >= 81 )
replace HALCION = . if (HALCION >= 81 )
replace PHENOBAR = . if (PHENOBAR >= 81 )
replace PLACIDYL = . if (PLACIDYL >= 81 )
replace TUINAL = . if (TUINAL >= 81 )
replace SEDNOLST = . if (SEDNOLST >= 81 )
replace SEDNEWA = . if (SEDNEWA >= 9981 )
replace SEDNEWB = . if (SEDNEWB >= 9981 )
replace SEDNEWC = . if (SEDNEWC >= 9981 )
replace SEDNEWD = . if (SEDNEWD >= 9981 )
replace SEDNEWE = . if (SEDNEWE >= 9981 )
replace SEDAGE = . if (SEDAGE >= 981 )
replace SEDYFU = . if (SEDYFU >= 9981 )
replace SEDMFU = . if (SEDMFU >= 81 )
replace SEDREC = . if (SEDREC >= 81 )
replace SEDYRTOT = . if (SEDYRTOT >= 981 )
replace SVTOTFG = . if (SVTOTFG >= 81 )
replace SVFQFLG = . if (SVFQFLG >= 81 )
replace SVBSTWAY = . if (SVBSTWAY >= 81 )
replace SVDAYPYR = . if (SVDAYPYR >= 981 )
replace SVDAYPMO = . if (SVDAYPMO >= 81 )
replace SVDAYPWK = . if (SVDAYPWK >= 81 )
replace IRCIGRC = . if (IRCIGRC == 9)
replace IRCGRRC = . if (IRCGRRC == 9)
replace IRPIPLF = . if (IRPIPLF == 9)
replace IRPIPMN = . if (IRPIPMN == 9)
replace IRSLTRC = . if (IRSLTRC == 9)
replace IRCHWRC = . if (IRCHWRC == 9)
replace IRSNFRC = . if (IRSNFRC == 9)
replace IRALCRC = . if (IRALCRC == 9)
replace IRMJRC = . if (IRMJRC == 9)
replace IRCOCRC = . if (IRCOCRC == 9)
replace IRCRKRC = . if (IRCRKRC == 9)
replace IRHERRC = . if (IRHERRC == 9)
replace IRHALRC = . if (IRHALRC == 9)
replace IRLSDRC = . if (IRLSDRC == 9)
replace IRPCPRC = . if (IRPCPRC == 9)
replace IRINHRC = . if (IRINHRC == 9)
replace IRANLRC = . if (IRANLRC == 9)
replace IRTRNRC = . if (IRTRNRC == 9)
replace IRSTMRC = . if (IRSTMRC == 9)
replace IRMTHRC = . if (IRMTHRC == 9)
replace IRSEDRC = . if (IRSEDRC == 9)
replace IRALCFY = . if (IRALCFY >= 981 )
replace IRMJFY = . if (IRMJFY >= 981 )
replace IRCOCFY = . if (IRCOCFY >= 981 )
replace IRCRKFY = . if (IRCRKFY >= 981 )
replace IRHERFY = . if (IRHERFY >= 981 )
replace IRHALFY = . if (IRHALFY >= 981 )
replace IRINHFY = . if (IRINHFY >= 981 )
replace IRANLFY = . if (IRANLFY >= 981 )
replace IRTRNFY = . if (IRTRNFY >= 981 )
replace IRSTMFY = . if (IRSTMFY >= 981 )
replace IRSEDFY = . if (IRSEDFY >= 981 )
replace IRCIGFM = . if (IRCIGFM >= 91.00 )
replace IRCGRFM = . if (IRCGRFM >= 91.00 )
replace IRCHWFM = . if (IRCHWFM >= 81 )
replace IRSNFFM = . if (IRSNFFM >= 81 )
replace IRALCFM = . if (IRALCFM >= 81 )
replace IRALCD5 = . if (IRALCD5 >= 81 )
replace IRMJFM = . if (IRMJFM >= 81 )
replace IRCOCFM = . if (IRCOCFM >= 81 )
replace IRCRKFM = . if (IRCRKFM >= 81 )
replace IRHERFM = . if (IRHERFM >= 81 )
replace IRHALFM = . if (IRHALFM >= 81 )
replace IRINHFM = . if (IRINHFM >= 81 )
replace IRCIGAGE = . if (IRCIGAGE >= 981 )
replace IRCIGYFU = . if (IRCIGYFU >= 9981 )
replace IRCDUAGE = . if (IRCDUAGE >= 981 )
replace IICDUAGE = . if (IICDUAGE == 9)
replace IRCDUYFU = . if (IRCDUYFU >= 9981 )
replace IRCGRAGE = . if (IRCGRAGE >= 981 )
replace IRCGRYFU = . if (IRCGRYFU >= 9981 )
replace IRSNFAGE = . if (IRSNFAGE >= 981 )
replace IRSNFYFU = . if (IRSNFYFU >= 9981 )
replace IRCHWAGE = . if (IRCHWAGE >= 981 )
replace IRCHWYFU = . if (IRCHWYFU >= 9981 )
replace IRSLTAGE = . if (IRSLTAGE >= 981 )
replace IRSLTYFU = . if (IRSLTYFU >= 9981 )
replace IRALCAGE = . if (IRALCAGE >= 981 )
replace IRALCYFU = . if (IRALCYFU >= 9981 )
replace IRMJAGE = . if (IRMJAGE >= 981 )
replace IRMJYFU = . if (IRMJYFU >= 9981 )
replace IRCOCAGE = . if (IRCOCAGE >= 981 )
replace IRCOCYFU = . if (IRCOCYFU >= 9981 )
replace IRCRKAGE = . if (IRCRKAGE >= 981 )
replace IRCRKYFU = . if (IRCRKYFU >= 9981 )
replace IRHERAGE = . if (IRHERAGE >= 981 )
replace IRHERYFU = . if (IRHERYFU >= 9981 )
replace IRHALAGE = . if (IRHALAGE >= 981 )
replace IRHALYFU = . if (IRHALYFU >= 9981 )
replace IRINHAGE = . if (IRINHAGE >= 981 )
replace IRINHYFU = . if (IRINHYFU >= 9981 )
replace IRANLAGE = . if (IRANLAGE >= 981 )
replace IRANLYFU = . if (IRANLYFU >= 9981 )
replace IRTRNAGE = . if (IRTRNAGE >= 981 )
replace IRTRNYFU = . if (IRTRNYFU >= 9981 )
replace IRSTMAGE = . if (IRSTMAGE >= 981 )
replace IRSTMYFU = . if (IRSTMYFU >= 9981 )
replace IRMTHAGE = . if (IRMTHAGE >= 981 )
replace IRMTHYFU = . if (IRMTHYFU >= 9981 )
replace IRSEDAGE = . if (IRSEDAGE >= 981 )
replace IRSEDYFU = . if (IRSEDYFU >= 9981 )
replace CIGBRAND = . if (CIGBRAND == -9)
replace CGRBRAND = . if (CGRBRAND == -9)
replace SMKBRAND = . if (SMKBRAND == -9)
replace CIGCMPNY = . if (CIGCMPNY >= 81 )
replace ALCAFU = . if (ALCAFU == 4)
replace MJAFU = . if (MJAFU == 4)
replace COCAFU = . if (COCAFU == 4)
replace HERAFU = . if (HERAFU == 4)
replace HALAFU = . if (HALAFU == 4)
replace INHAFU = . if (INHAFU == 4)
replace ANLAFU = . if (ANLAFU == 4)
replace TRNAFU = . if (TRNAFU == 4)
replace STMAFU = . if (STMAFU == 4)
replace SEDAFU = . if (SEDAFU == 4)
replace CIGAFU = . if (CIGAFU == 4)
replace CGRAFU = . if (CGRAFU == 4)
replace SLTAFU = . if (SLTAFU == 4)
replace CG05 = . if (CG05 >= 81 )
replace CG06 = . if (CG06 >= 81 )
replace CG19 = . if (CG19 >= 81 )
replace CG20 = . if (CG20 >= 81 )
replace CG27 = . if (CG27 >= 81 )
replace CG28 = . if (CG28 >= 81 )
replace CG36 = . if (CG36 >= 81 )
replace CG37 = . if (CG37 >= 81 )
replace CG43 = . if (CG43 >= 81 )
replace ALLAST3 = . if (ALLAST3 >= 81 )
replace TOTDRINK = . if (TOTDRINK >= 981 )
replace ALFRAME3 = . if (ALFRAME3 >= 81 )
replace ALYRAVE = . if (ALYRAVE >= 981 )
replace ALMONAVE = . if (ALMONAVE >= 81 )
replace ALWKAVE = . if (ALWKAVE >= 81 )
replace MJLAST3 = . if (MJLAST3 >= 81 )
replace TOTMJ = . if (TOTMJ >= 981 )
replace MJFRAME3 = . if (MJFRAME3 >= 81 )
replace MJYRAVE = . if (MJYRAVE >= 981 )
replace MJMONAVE = . if (MJMONAVE >= 81 )
replace MJWKAVE = . if (MJWKAVE >= 81 )
replace CCLAST3 = . if (CCLAST3 >= 81 )
replace TOTCOKE = . if (TOTCOKE >= 981 )
replace CCFRAME3 = . if (CCFRAME3 >= 81 )
replace CCYRAVE = . if (CCYRAVE >= 981 )
replace CCMONAVE = . if (CCMONAVE >= 81 )
replace CCWKAVE = . if (CCWKAVE >= 81 )
replace CKLAST3 = . if (CKLAST3 >= 81 )
replace TOTCRACK = . if (TOTCRACK >= 981 )
replace CKFRAME3 = . if (CKFRAME3 >= 81 )
replace CKYRAVE = . if (CKYRAVE >= 981 )
replace CKMONAVE = . if (CKMONAVE >= 81 )
replace CKWKAVE = . if (CKWKAVE >= 81 )
replace HELAST3 = . if (HELAST3 >= 81 )
replace TOTHERO = . if (TOTHERO >= 981 )
replace HEFRAME3 = . if (HEFRAME3 >= 81 )
replace HEYRAVE = . if (HEYRAVE >= 981 )
replace HEMONAVE = . if (HEMONAVE >= 81 )
replace HEWKAVE = . if (HEWKAVE >= 81 )
replace LSLAST = . if (LSLAST >= 81 )
replace TOTHALL = . if (TOTHALL >= 981 )
replace LSFRAME3 = . if (LSFRAME3 >= 81 )
replace LSYRAVE = . if (LSYRAVE >= 981 )
replace LSMONAVE = . if (LSMONAVE >= 81 )
replace LSWKAVE = . if (LSWKAVE >= 81 )
replace LS07 = . if (LS07 >= 81 )
replace LS08 = . if (LS08 >= 81 )
replace INLAST = . if (INLAST >= 81 )
replace TOTINHAL = . if (TOTINHAL >= 981 )
replace INFRAME3 = . if (INFRAME3 >= 81 )
replace INYRAVE = . if (INYRAVE >= 981 )
replace INMONAVE = . if (INMONAVE >= 81 )
replace INWKAVE = . if (INWKAVE >= 81 )
replace PR09 = . if (PR09 >= 81 )
replace PR10 = . if (PR10 >= 81 )
replace PR11 = . if (PR11 >= 981 )
replace PR12 = . if (PR12 >= 81 )
replace PR13 = . if (PR13 >= 81 )
replace TR09 = . if (TR09 >= 81 )
replace TR10 = . if (TR10 >= 81 )
replace TR11 = . if (TR11 >= 981 )
replace TR12 = . if (TR12 >= 81 )
replace TR13 = . if (TR13 >= 81 )
replace ST09 = . if (ST09 >= 81 )
replace ST10 = . if (ST10 >= 81 )
replace ST11 = . if (ST11 >= 981 )
replace ST12 = . if (ST12 >= 81 )
replace ST13 = . if (ST13 >= 81 )
replace ST15 = . if (ST15 >= 81 )
replace SV09 = . if (SV09 >= 81 )
replace SV10 = . if (SV10 >= 81 )
replace SV11 = . if (SV11 >= 981 )
replace SV12 = . if (SV12 >= 81 )
replace SV13 = . if (SV13 >= 81 )
replace HERSMOKE = . if (HERSMOKE >= 81 )
replace HRSMKREC = . if (HRSMKREC >= 81 )
replace HERSNIFF = . if (HERSNIFF >= 81 )
replace HRSNFREC = . if (HRSNFREC >= 81 )
replace GNNDLLIF = . if (GNNDLLIF >= 81 )
replace COCNEEDL = . if (COCNEEDL >= 81 )
replace CONDLREC = . if (CONDLREC >= 81 )
replace HERNEEDL = . if (HERNEEDL >= 81 )
replace HRNDLREC = . if (HRNDLREC >= 81 )
replace STNEEDLE = . if (STNEEDLE >= 81 )
replace STNDLREC = . if (STNDLREC >= 81 )
replace GNNDREUS = . if (GNNDREUS >= 81 )
replace GNNDLSH1 = . if (GNNDLSH1 >= 81 )
replace GNNDCLEN = . if (GNNDCLEN >= 81 )
replace GNNDLSH2 = . if (GNNDLSH2 >= 81 )
replace GNNDGET2 = . if (GNNDGET2 >= 81 )
replace NEDLRECC = . if (NEDLRECC >= 81 )
replace RSKPKCIG = . if (RSKPKCIG >= 81 )
replace RSKMJOCC = . if (RSKMJOCC >= 81 )
replace RSKMJREG = . if (RSKMJREG >= 81 )
replace RKTRYLSD = . if (RKTRYLSD >= 81 )
replace RKLSDREG = . if (RKLSDREG >= 81 )
replace RKTRYHER = . if (RKTRYHER >= 81 )
replace RKHERREG = . if (RKHERREG >= 81 )
replace RKCOCOCC = . if (RKCOCOCC >= 81 )
replace RKCOCREG = . if (RKCOCREG >= 81 )
replace RK5ALDLY = . if (RK5ALDLY >= 81 )
replace RK5ALWK = . if (RK5ALWK >= 81 )
replace RSKDIFMJ = . if (RSKDIFMJ >= 81 )
replace RKDIFLSD = . if (RKDIFLSD >= 81 )
replace RKDIFCOC = . if (RKDIFCOC >= 81 )
replace RKDIFCRK = . if (RKDIFCRK >= 81 )
replace RKDIFHER = . if (RKDIFHER >= 81 )
replace RSKSELL = . if (RSKSELL >= 81 )
replace RKFQDNGR = . if (RKFQDNGR >= 81 )
replace RKFQRSKY = . if (RKFQRSKY >= 81 )
replace RKFQPBLT = . if (RKFQPBLT >= 81 )
replace RKFQDBLT = . if (RKFQDBLT >= 81 )
replace GRSKPKCG = . if (GRSKPKCG == -9)
replace GRSKCREG = . if (GRSKCREG == -9)
replace GRSKCOCC = . if (GRSKCOCC == -9)
replace GRSKMREG = . if (GRSKMREG == -9)
replace GRSKMOCC = . if (GRSKMOCC == -9)
replace GRSKHTRY = . if (GRSKHTRY == -9)
replace GRSKHREG = . if (GRSKHREG == -9)
replace GRSKLTRY = . if (GRSKLTRY == -9)
replace GRSKLREG = . if (GRSKLREG == -9)
replace GRSKD4_5 = . if (GRSKD4_5 == -9)
replace GRSKD5WK = . if (GRSKD5WK == -9)
replace RDIFMJ = . if (RDIFMJ == -9)
replace RDIFCOC = . if (RDIFCOC == -9)
replace RDIFHER = . if (RDIFHER == -9)
replace RDIFLSD = . if (RDIFLSD == -9)
replace RDIFCRK = . if (RDIFCRK == -9)
replace APPSELDG = . if (APPSELDG == -9)
replace GRTMCIG = . if (GRTMCIG >= 81 )
replace LAMTCIG = . if (LAMTCIG >= 81 )
replace BTOLCIG = . if (BTOLCIG >= 81 )
replace ACRDCIG = . if (ACRDCIG >= 81 )
replace EMPBCIG = . if (EMPBCIG >= 81 )
replace HLPRCIG = . if (HLPRCIG >= 81 )
replace UCDCIG = . if (UCDCIG >= 81 )
replace WDRWCIG = . if (WDRWCIG >= 81 )
replace DPRSCIG = . if (DPRSCIG >= 81 )
replace TRSLPCIG = . if (TRSLPCIG >= 81 )
replace IRRITCIG = . if (IRRITCIG >= 81 )
replace ANXCIG = . if (ANXCIG >= 81 )
replace CONCCIG = . if (CONCCIG >= 81 )
replace HUNGRCIG = . if (HUNGRCIG >= 81 )
replace RSTLSCIG = . if (RSTLSCIG >= 81 )
replace SLHRTCIG = . if (SLHRTCIG >= 81 )
replace GRTMALC = . if (GRTMALC >= 81 )
replace LAMTALC = . if (LAMTALC >= 81 )
replace BTOLALC = . if (BTOLALC >= 81 )
replace ACRDALC = . if (ACRDALC >= 81 )
replace EMPBALC = . if (EMPBALC >= 81 )
replace HLPRALC = . if (HLPRALC >= 81 )
replace UCDALC = . if (UCDALC >= 81 )
replace WDRWALC = . if (WDRWALC >= 81 )
replace SWETALC = . if (SWETALC >= 81 )
replace HSHAKALC = . if (HSHAKALC >= 81 )
replace TRSLPALC = . if (TRSLPALC >= 81 )
replace VOMITALC = . if (VOMITALC >= 81 )
replace HALUCALC = . if (HALUCALC >= 81 )
replace SITSTALC = . if (SITSTALC >= 81 )
replace ANXALC = . if (ANXALC >= 81 )
replace SEIZALC = . if (SEIZALC >= 81 )
replace AVDWDALC = . if (AVDWDALC >= 81 )
replace GRTMMRJ = . if (GRTMMRJ >= 81 )
replace LAMTMRJ = . if (LAMTMRJ >= 81 )
replace BTOLMRJ = . if (BTOLMRJ >= 81 )
replace ACRDMRJ = . if (ACRDMRJ >= 81 )
replace EMPBMRJ = . if (EMPBMRJ >= 81 )
replace HLPRMRJ = . if (HLPRMRJ >= 81 )
replace UCDMRJ = . if (UCDMRJ >= 81 )
replace GRTMCOC = . if (GRTMCOC >= 81 )
replace LAMTCOC = . if (LAMTCOC >= 81 )
replace BTOLCOC = . if (BTOLCOC >= 81 )
replace ACRDCOC = . if (ACRDCOC >= 81 )
replace EMPBCOC = . if (EMPBCOC >= 81 )
replace HLPRCOC = . if (HLPRCOC >= 81 )
replace UCDCOC = . if (UCDCOC >= 81 )
replace DPRSCOC = . if (DPRSCOC >= 81 )
replace WDRWCOC = . if (WDRWCOC >= 81 )
replace TIREDCOC = . if (TIREDCOC >= 81 )
replace BDDRMCOC = . if (BDDRMCOC >= 81 )
replace SLPRBCOC = . if (SLPRBCOC >= 81 )
replace HUNGRCOC = . if (HUNGRCOC >= 81 )
replace SLODNCOC = . if (SLODNCOC >= 81 )
replace AVDWDCOC = . if (AVDWDCOC >= 81 )
replace GRTMHER = . if (GRTMHER >= 81 )
replace LAMTHER = . if (LAMTHER >= 81 )
replace BTOLHER = . if (BTOLHER >= 81 )
replace ACRDHER = . if (ACRDHER >= 81 )
replace EMPBHER = . if (EMPBHER >= 81 )
replace HLPRHER = . if (HLPRHER >= 81 )
replace UCDHER = . if (UCDHER >= 81 )
replace WDRWHER = . if (WDRWHER >= 81 )
replace DPRSHER = . if (DPRSHER >= 81 )
replace VOMITHER = . if (VOMITHER >= 81 )
replace CRAMPHER = . if (CRAMPHER >= 81 )
replace EYNOSHER = . if (EYNOSHER >= 81 )
replace DILATHER = . if (DILATHER >= 81 )
replace DIARHER = . if (DIARHER >= 81 )
replace YAWNHER = . if (YAWNHER >= 81 )
replace FEVERHER = . if (FEVERHER >= 81 )
replace TRSLPHER = . if (TRSLPHER >= 81 )
replace AVDWDHER = . if (AVDWDHER >= 81 )
replace GRTMHAL = . if (GRTMHAL >= 81 )
replace LAMTHAL = . if (LAMTHAL >= 81 )
replace BTOLHAL = . if (BTOLHAL >= 81 )
replace ACRDHAL = . if (ACRDHAL >= 81 )
replace EMPBHAL = . if (EMPBHAL >= 81 )
replace HLPRHAL = . if (HLPRHAL >= 81 )
replace UCDHAL = . if (UCDHAL >= 81 )
replace GRTMINH = . if (GRTMINH >= 81 )
replace LAMTINH = . if (LAMTINH >= 81 )
replace BTOLINH = . if (BTOLINH >= 81 )
replace ACRDINH = . if (ACRDINH >= 81 )
replace EMPBINH = . if (EMPBINH >= 81 )
replace HLPRINH = . if (HLPRINH >= 81 )
replace UCDINH = . if (UCDINH >= 81 )
replace GRTMANL = . if (GRTMANL >= 81 )
replace LAMTANL = . if (LAMTANL >= 81 )
replace BTOLANL = . if (BTOLANL >= 81 )
replace ACRDANL = . if (ACRDANL >= 81 )
replace EMPBANL = . if (EMPBANL >= 81 )
replace HLPRANL = . if (HLPRANL >= 81 )
replace UCDANL = . if (UCDANL >= 81 )
replace WDRWANL = . if (WDRWANL >= 81 )
replace DPRSANL = . if (DPRSANL >= 81 )
replace VOMITANL = . if (VOMITANL >= 81 )
replace CRAMPANL = . if (CRAMPANL >= 81 )
replace EYNOSANL = . if (EYNOSANL >= 81 )
replace DILATANL = . if (DILATANL >= 81 )
replace DIARANL = . if (DIARANL >= 81 )
replace YAWNANL = . if (YAWNANL >= 81 )
replace FEVERANL = . if (FEVERANL >= 81 )
replace TRSLPANL = . if (TRSLPANL >= 81 )
replace AVDWDANL = . if (AVDWDANL >= 81 )
replace GRTMTRN = . if (GRTMTRN >= 81 )
replace LAMTTRN = . if (LAMTTRN >= 81 )
replace BTOLTRN = . if (BTOLTRN >= 81 )
replace ACRDTRN = . if (ACRDTRN >= 81 )
replace EMPBTRN = . if (EMPBTRN >= 81 )
replace HLPRTRN = . if (HLPRTRN >= 81 )
replace UCDTRN = . if (UCDTRN >= 81 )
replace GRTMSTM = . if (GRTMSTM >= 81 )
replace LAMTSTM = . if (LAMTSTM >= 81 )
replace BTOLSTM = . if (BTOLSTM >= 81 )
replace ACRDSTM = . if (ACRDSTM >= 81 )
replace EMPBSTM = . if (EMPBSTM >= 81 )
replace HLPRSTM = . if (HLPRSTM >= 81 )
replace UCDSTM = . if (UCDSTM >= 81 )
replace DPRSSTM = . if (DPRSSTM >= 81 )
replace WDRWSTM = . if (WDRWSTM >= 81 )
replace TIREDSTM = . if (TIREDSTM >= 81 )
replace BDDRMSTM = . if (BDDRMSTM >= 81 )
replace SLPRBSTM = . if (SLPRBSTM >= 81 )
replace HUNGRSTM = . if (HUNGRSTM >= 81 )
replace SLODNSTM = . if (SLODNSTM >= 81 )
replace AVDWDSTM = . if (AVDWDSTM >= 81 )
replace GRTMSED = . if (GRTMSED >= 81 )
replace LAMTSED = . if (LAMTSED >= 81 )
replace BTOLSED = . if (BTOLSED >= 81 )
replace ACRDSED = . if (ACRDSED >= 81 )
replace EMPBSED = . if (EMPBSED >= 81 )
replace HLPRSED = . if (HLPRSED >= 81 )
replace UCDSED = . if (UCDSED >= 81 )
replace WDRWSED = . if (WDRWSED >= 81 )
replace SWETSED = . if (SWETSED >= 81 )
replace HSHAKSED = . if (HSHAKSED >= 81 )
replace SLPRBSED = . if (SLPRBSED >= 81 )
replace VOMITSED = . if (VOMITSED >= 81 )
replace HALUCSED = . if (HALUCSED >= 81 )
replace SITSTSED = . if (SITSTSED >= 81 )
replace ANXSED = . if (ANXSED >= 81 )
replace SEIZSED = . if (SEIZSED >= 81 )
replace AVDWDSED = . if (AVDWDSED >= 81 )
replace BOOKED = . if (BOOKED >= 81 )
replace NOBOOKY2 = . if (NOBOOKY2 >= 981 )
replace BKLARCNY = . if (BKLARCNY >= 81 )
replace BKBURGL = . if (BKBURGL >= 81 )
replace BKAGASLT = . if (BKAGASLT >= 81 )
replace BKSMASLT = . if (BKSMASLT >= 81 )
replace BKMVTHFT = . if (BKMVTHFT >= 81 )
replace BKROB = . if (BKROB >= 81 )
replace BKRAPE = . if (BKRAPE >= 81 )
replace BKMURDER = . if (BKMURDER >= 81 )
replace BKARSON = . if (BKARSON >= 81 )
replace BKDRVINF = . if (BKDRVINF >= 81 )
replace BKDRUNK = . if (BKDRUNK >= 81 )
replace BKDRUG = . if (BKDRUG >= 81 )
replace BKPROS = . if (BKPROS >= 81 )
replace BKVANDAL = . if (BKVANDAL >= 81 )
replace BKOTH = . if (BKOTH >= 81 )
replace BKOTHOF2 = . if (BKOTHOF2 >= 81 )
replace PROBATON = . if (PROBATON >= 81 )
replace PAROLE = . if (PAROLE >= 81 )
replace DRVALDR = . if (DRVALDR >= 81 )
replace DRIVEAL = . if (DRIVEAL >= 81 )
replace DRIVEDR = . if (DRIVEDR >= 81 )
replace TXEVER = . if (TXEVER >= 81 )
replace TXYREVER = . if (TXYREVER >= 81 )
replace TXYRADG = . if (TXYRADG >= 81 )
replace TXYRHOSP = . if (TXYRHOSP >= 81 )
replace TXYRRFIN = . if (TXYRRFIN >= 81 )
replace TXYRRFOP = . if (TXYRRFOP >= 81 )
replace TXYRMHC = . if (TXYRMHC >= 81 )
replace TXYRTXER = . if (TXYRTXER >= 81 )
replace TXYRDOC = . if (TXYRDOC >= 81 )
replace TXYRJAIL = . if (TXYRJAIL >= 81 )
replace TXYRSHG = . if (TXYRSHG >= 81 )
replace TXYRSOP = . if (TXYRSOP >= 81 )
replace TXYROTS2 = . if (TXYROTS2 >= 981 )
replace TXYRVSER = . if (TXYRVSER >= 81 )
replace TXYRNME2 = . if (TXYRNME2 >= 981 )
replace NDTXNEED = . if (NDTXNEED >= 81 )
replace NDTXALC = . if (NDTXALC >= 81 )
replace NDTXMJ = . if (NDTXMJ >= 81 )
replace NDTXCOC = . if (NDTXCOC >= 81 )
replace NDTXHER = . if (NDTXHER >= 81 )
replace NDTXHAL = . if (NDTXHAL >= 81 )
replace NDTXINH = . if (NDTXINH >= 81 )
replace NDTXANL = . if (NDTXANL >= 81 )
replace NDTXTRAN = . if (NDTXTRAN >= 81 )
replace NDTXSTIM = . if (NDTXSTIM >= 81 )
replace NDTXSED = . if (NDTXSED >= 81 )
replace NDTXSOD = . if (NDTXSOD >= 81 )
replace NDTXDRG1 = . if (NDTXDRG1 >= 9981 )
replace NDTXDRG2 = . if (NDTXDRG2 >= 9981 )
replace NDTXDRG3 = . if (NDTXDRG3 >= 9981 )
replace NDTXDRG4 = . if (NDTXDRG4 >= 9981 )
replace NDTXDRG5 = . if (NDTXDRG5 >= 9981 )
replace NDTXEFRT = . if (NDTXEFRT >= 81 )
replace TXADGREC = . if (TXADGREC >= 81 )
replace TXLTMAI2 = . if (TXLTMAI2 >= 981 )
replace TXLTALC = . if (TXLTALC >= 81 )
replace TXLTMJ = . if (TXLTMJ >= 81 )
replace TXLTCOC = . if (TXLTCOC >= 81 )
replace TXLTHER = . if (TXLTHER >= 81 )
replace TXLTHAL = . if (TXLTHAL >= 81 )
replace TXLTINH = . if (TXLTINH >= 81 )
replace TXLTANL = . if (TXLTANL >= 81 )
replace TXLTTRAN = . if (TXLTTRAN >= 81 )
replace TXLTSTIM = . if (TXLTSTIM >= 81 )
replace TXLTSED = . if (TXLTSED >= 81 )
replace TXLTSOD = . if (TXLTSOD >= 81 )
replace TXLTA = . if (TXLTA >= 9981 )
replace TXLTB = . if (TXLTB >= 9981 )
replace TXLTC = . if (TXLTC >= 9981 )
replace TXLTD = . if (TXLTD >= 9981 )
replace TXLTE = . if (TXLTE >= 9981 )
replace TXLTPRIM = . if (TXLTPRIM >= 81 )
replace TXOUTC2 = . if (TXOUTC2 >= 81 )
replace TXLTDUR2 = . if (TXLTDUR2 >= 99981 )
replace TXPDINS = . if (TXPDINS >= 81 )
replace TXPDCARE = . if (TXPDCARE >= 81 )
replace TXPDCAID = . if (TXPDCAID >= 81 )
replace TXPDPUBP = . if (TXPDPUBP >= 81 )
replace TXPDSAVE = . if (TXPDSAVE >= 81 )
replace TXPDFMLY = . if (TXPDFMLY >= 81 )
replace TXPDCORT = . if (TXPDCORT >= 81 )
replace TXPDMILC = . if (TXPDMILC >= 81 )
replace TXPDEMPL = . if (TXPDEMPL >= 81 )
replace TXPDSOS = . if (TXPDSOS >= 81 )
replace TXPDSP2 = . if (TXPDSP2 >= 81 )
replace TXPDFRE = . if (TXPDFRE >= 81 )
replace TXENROLL = . if (TXENROLL >= 81 )
replace SNLIVNBR = . if (SNLIVNBR >= 81 )
replace SNCRIME = . if (SNCRIME >= 81 )
replace SNSELLDG = . if (SNSELLDG >= 81 )
replace SNPPVAL = . if (SNPPVAL >= 81 )
replace SNSTFGT = . if (SNSTFGT >= 81 )
replace SNEMTBLD = . if (SNEMTBLD >= 81 )
replace SNPPHLP = . if (SNPPHLP >= 81 )
replace SNGRAFTI = . if (SNGRAFTI >= 81 )
replace SNPPVSIT = . if (SNPPVSIT >= 81 )
replace SNPPMOVE = . if (SNPPMOVE >= 81 )
replace SNAPKCIG = . if (SNAPKCIG >= 81 )
replace SNAMJEVR = . if (SNAMJEVR >= 81 )
replace SNAALDLY = . if (SNAALDLY >= 81 )
replace SNAALDRV = . if (SNAALDRV >= 81 )
replace SNMOV5Y2 = . if (SNMOV5Y2 >= 981 )
replace SNPPHHLD = . if (SNPPHHLD >= 81 )
replace SNINSULT = . if (SNINSULT >= 81 )
replace SNSRARGU = . if (SNSRARGU >= 81 )
replace SNSMARGU = . if (SNSMARGU >= 81 )
replace SNSPOUSE = . if (SNSPOUSE >= 81 )
replace SNSPACTV = . if (SNSPACTV >= 81 )
replace SNSPANGR = . if (SNSPANGR >= 81 )
replace SNSPHITU = . if (SNSPHITU >= 81 )
replace SNYHITSP = . if (SNYHITSP >= 81 )
replace SNSPCRIT = . if (SNSPCRIT >= 81 )
replace SNSPCONC = . if (SNSPCONC >= 81 )
replace SNFRCONC = . if (SNFRCONC >= 81 )
replace SNFRACTV = . if (SNFRACTV >= 81 )
replace SNFRCARE = . if (SNFRCARE >= 81 )
replace SNYSELL = . if (SNYSELL >= 81 )
replace SNYSTOLE = . if (SNYSTOLE >= 81 )
replace SNYATTAK = . if (SNYATTAK >= 81 )
replace SNFACIG = . if (SNFACIG >= 81 )
replace SNFAMJEV = . if (SNFAMJEV >= 81 )
replace SNFAALDY = . if (SNFAALDY >= 81 )
replace SNFAALDV = . if (SNFAALDV >= 81 )
replace SNFDCIG = . if (SNFDCIG >= 81 )
replace SNFDMJ = . if (SNFDMJ >= 81 )
replace SNFDALC = . if (SNFDALC >= 81 )
replace SNFDDRNK = . if (SNFDDRNK >= 81 )
replace YELIVNBR = . if (YELIVNBR >= 81 )
replace YECRIME = . if (YECRIME >= 81 )
replace YESELLDG = . if (YESELLDG >= 81 )
replace YEPPHLP = . if (YEPPHLP >= 81 )
replace YESTFGT = . if (YESTFGT >= 81 )
replace YEEMTBLD = . if (YEEMTBLD >= 81 )
replace YEPPVSIT = . if (YEPPVSIT >= 81 )
replace YEGRAFTI = . if (YEGRAFTI >= 81 )
replace YEPPMOVE = . if (YEPPMOVE >= 81 )
replace YEAPKCIG = . if (YEAPKCIG >= 81 )
replace YEAMJEVR = . if (YEAMJEVR >= 81 )
replace YEAALDLY = . if (YEAALDLY >= 81 )
replace YEMOV5Y2 = . if (YEMOV5Y2 >= 981 )
replace YEADOCIG = . if (YEADOCIG >= 81 )
replace YEADOMRJ = . if (YEADOMRJ >= 81 )
replace YEADOALC = . if (YEADOALC >= 81 )
replace YEADODNK = . if (YEADODNK >= 81 )
replace YEENRLYR = . if (YEENRLYR >= 81 )
replace YESCHFLT = . if (YESCHFLT >= 81 )
replace YESCHWRK = . if (YESCHWRK >= 81 )
replace YESCHIMP = . if (YESCHIMP >= 81 )
replace YESCHINT = . if (YESCHINT >= 81 )
replace YETCGJOB = . if (YETCGJOB >= 81 )
replace YELSTGRD = . if (YELSTGRD >= 81 )
replace YESTSCIG = . if (YESTSCIG >= 81 )
replace YESTSMJ = . if (YESTSMJ >= 81 )
replace YESTSALC = . if (YESTSALC >= 81 )
replace YESTSDNK = . if (YESTSDNK >= 81 )
replace YETRSCIG = . if (YETRSCIG >= 81 )
replace YETRPDAL = . if (YETRPDAL >= 81 )
replace YETRPUDG = . if (YETRPUDG >= 81 )
replace YEPCHKHW = . if (YEPCHKHW >= 81 )
replace YEPHLPHW = . if (YEPHLPHW >= 81 )
replace YEPCHORE = . if (YEPCHORE >= 81 )
replace YEPLMTTV = . if (YEPLMTTV >= 81 )
replace YEPLMTSN = . if (YEPLMTSN >= 81 )
replace YEPGDJOB = . if (YEPGDJOB >= 81 )
replace YEPPROUD = . if (YEPPROUD >= 81 )
replace YEYARGUP = . if (YEYARGUP >= 81 )
replace YEYFGTSW = . if (YEYFGTSW >= 81 )
replace YEYFGTGP = . if (YEYFGTGP >= 81 )
replace YEYHGUN = . if (YEYHGUN >= 81 )
replace YEYSELL = . if (YEYSELL >= 81 )
replace YEYSTOLE = . if (YEYSTOLE >= 81 )
replace YEYATTAK = . if (YEYATTAK >= 81 )
replace YEPPKCIG = . if (YEPPKCIG >= 81 )
replace YEPMJEVR = . if (YEPMJEVR >= 81 )
replace YEPALDLY = . if (YEPALDLY >= 81 )
replace YEGPKCIG = . if (YEGPKCIG >= 81 )
replace YEGMJEVR = . if (YEGMJEVR >= 81 )
replace YEGALDLY = . if (YEGALDLY >= 81 )
replace YEFPKCIG = . if (YEFPKCIG >= 81 )
replace YEFMJEVR = . if (YEFMJEVR >= 81 )
replace YEFALDLY = . if (YEFALDLY >= 81 )
replace YEFDCIG = . if (YEFDCIG >= 81 )
replace YEFDMJ = . if (YEFDMJ >= 81 )
replace YEFDALC = . if (YEFDALC >= 81 )
replace YEFDDNK = . if (YEFDDNK >= 81 )
replace YETLKNON = . if (YETLKNON >= 81 )
replace YETLKMOM = . if (YETLKMOM >= 81 )
replace YETLKDAD = . if (YETLKDAD >= 81 )
replace YETLKGPR = . if (YETLKGPR >= 81 )
replace YETLKBGF = . if (YETLKBGF >= 81 )
replace YETLKSIB = . if (YETLKSIB >= 81 )
replace YETLKSOR = . if (YETLKSOR >= 81 )
replace YETLKFRN = . if (YETLKFRN >= 81 )
replace YETLKNBR = . if (YETLKNBR >= 81 )
replace YETLKTCH = . if (YETLKTCH >= 81 )
replace YETLKPSY = . if (YETLKPSY >= 81 )
replace YETLKCLG = . if (YETLKCLG >= 81 )
replace YETLKSOP = . if (YETLKSOP >= 81 )
replace YETLKSP = . if (YETLKSP >= 900 )
replace YEPARDNG = . if (YEPARDNG >= 81 )
replace YEBIGBRO = . if (YEBIGBRO >= 81 )
replace YEPRBSLV = . if (YEPRBSLV >= 81 )
replace YEVIOPRV = . if (YEVIOPRV >= 81 )
replace YEYMCA = . if (YEYMCA >= 81 )
replace YESCOUTS = . if (YESCOUTS >= 81 )
replace YEPRVLES = . if (YEPRVLES >= 81 )
replace YEDGPRGP = . if (YEDGPRGP >= 81 )
replace YETEMSPT = . if (YETEMSPT >= 81 )
replace YE4HCLUB = . if (YE4HCLUB >= 81 )
replace YESLFHLP = . if (YESLFHLP >= 81 )
replace YEBAND = . if (YEBAND >= 81 )
replace YESCHCLB = . if (YESCHCLB >= 81 )
replace YEVOLUNT = . if (YEVOLUNT >= 81 )
replace YESTGOVT = . if (YESTGOVT >= 81 )
replace YEPRGSTD = . if (YEPRGSTD >= 81 )
replace YEJBSKIL = . if (YEJBSKIL >= 81 )
replace YECHOIR = . if (YECHOIR >= 81 )
replace YEDECLAS = . if (YEDECLAS >= 81 )
replace YEDERGLR = . if (YEDERGLR >= 81 )
replace YEDESPCL = . if (YEDESPCL >= 81 )
replace YEPVNTYR = . if (YEPVNTYR >= 81 )
replace ADFLALDY = . if (ADFLALDY == -9)
replace ADFLPKCG = . if (ADFLPKCG == -9)
replace ADFLTMRJ = . if (ADFLTMRJ == -9)
replace ADULTALC = . if (ADULTALC == -9)
replace ADULTCIG = . if (ADULTCIG == -9)
replace ADULTDRK = . if (ADULTDRK == -9)
replace ADULTMRJ = . if (ADULTMRJ == -9)
replace FRDALDLY = . if (FRDALDLY == -9)
replace FRDMJEVR = . if (FRDMJEVR == -9)
replace FRDPKCIG = . if (FRDPKCIG == -9)
replace FRNDALC = . if (FRNDALC == -9)
replace FRNDCIG = . if (FRNDCIG == -9)
replace FRNDDNK = . if (FRNDDNK == -9)
replace FRNDMJ = . if (FRNDMJ == -9)
replace LIVNBRHD = . if (LIVNBRHD == -9)
replace MOVIN5YR = . if (MOVIN5YR == -9)
replace NGHDBLDG = . if (NGHDBLDG == -9)
replace NGHDCRIM = . if (NGHDCRIM == -9)
replace NGHDFGHT = . if (NGHDFGHT == -9)
replace NGHDGRAF = . if (NGHDGRAF == -9)
replace NGHDHELP = . if (NGHDHELP == -9)
replace NGHDMOVE = . if (NGHDMOVE == -9)
replace NGHDSELL = . if (NGHDSELL == -9)
replace NGHDVSIT = . if (NGHDVSIT == -9)
replace PARALDLY = . if (PARALDLY == -9)
replace PARCHORE = . if (PARCHORE == -9)
replace PARGDJOB = . if (PARGDJOB == -9)
replace PARLMTTV = . if (PARLMTTV == -9)
replace PARMJEVR = . if (PARMJEVR == -9)
replace PARPKCIG = . if (PARPKCIG == -9)
replace PARPROUD = . if (PARPROUD == -9)
replace YTFLADLY = . if (YTFLADLY == -9)
replace YTFLPKCG = . if (YTFLPKCG == -9)
replace YTFLTMRJ = . if (YTFLTMRJ == -9)
replace YTHARGUE = . if (YTHARGUE == -9)
replace YTHATTAK = . if (YTHATTAK == -9)
replace YTHFIGHT = . if (YTHFIGHT == -9)
replace YTHGRPFT = . if (YTHGRPFT == -9)
replace YTHHGUN = . if (YTHHGUN == -9)
replace YTHSELL = . if (YTHSELL == -9)
replace YTHSTOLE = . if (YTHSTOLE == -9)
replace PREGNANT = . if (PREGNANT >= 81 )
replace NMERTMT2 = . if (NMERTMT2 >= 81 )
replace NMHSPOV2 = . if (NMHSPOV2 >= 81 )
replace NMHSPPE2 = . if (NMHSPPE2 >= 81 )
replace OUTPEYR = . if (OUTPEYR >= 81 )
replace PROXANS2 = . if (PROXANS2 >= 81 )
replace PREG2 = . if (PREG2 == -9)
replace TRIMEST = . if (TRIMEST == -9)
replace IRWELMOS = . if (IRWELMOS >= 81 )
replace HLCALLFG = . if (HLCALLFG >= 81 )
replace MEDICARE = . if (MEDICARE >= 81 )
replace MEDICAID = . if (MEDICAID >= 81 )
replace CHAMPUS = . if (CHAMPUS >= 81 )
replace PRVHLTIN = . if (PRVHLTIN >= 81 )
replace GRPHLTIN = . if (GRPHLTIN >= 81 )
replace HLTINALC = . if (HLTINALC >= 81 )
replace HLTINDRG = . if (HLTINDRG >= 81 )
replace HLTINMNT = . if (HLTINMNT >= 81 )
replace HLCNOTYR = . if (HLCNOTYR >= 81 )
replace HLCNOTMO = . if (HLCNOTMO >= 81 )
replace HLCLAST = . if (HLCLAST >= 81 )
replace HLCPRIVT = . if (HLCPRIVT >= 81 )
replace HLCMCAID = . if (HLCMCAID >= 81 )
replace HLCMILT = . if (HLCMILT >= 81 )
replace HLCMCARE = . if (HLCMCARE >= 81 )
replace HLCOGOVT = . if (HLCOGOVT >= 81 )
replace HLCOTHER = . if (HLCOTHER >= 81 )
replace HLCOTHS2 = . if (HLCOTHS2 >= 81 )
replace HLLLOSJB = . if (HLLLOSJB >= 81 )
replace HLLMAJOB = . if (HLLMAJOB >= 81 )
replace HLLMASOR = . if (HLLMASOR >= 81 )
replace HLLCOST = . if (HLLCOST >= 81 )
replace HLLINELG = . if (HLLINELG >= 81 )
replace HLLNOFFR = . if (HLLNOFFR >= 81 )
replace HLLDIVOR = . if (HLLDIVOR >= 81 )
replace HLLDEATH = . if (HLLDEATH >= 81 )
replace HLLREFUS = . if (HLLREFUS >= 81 )
replace HLLNONED = . if (HLLNONED >= 81 )
replace HLLSOR = . if (HLLSOR >= 81 )
replace HLLSORS2 = . if (HLLSORS2 >= 81 )
replace HLNVCOST = . if (HLNVCOST >= 81 )
replace HLNVOFFR = . if (HLNVOFFR >= 81 )
replace HLNVREF = . if (HLNVREF >= 81 )
replace HLNVNEED = . if (HLNVNEED >= 81 )
replace HLNVSOR = . if (HLNVSOR >= 81 )
replace HLNVSP2 = . if (HLNVSP2 >= 81 )
replace LANGVER = . if (LANGVER >= 81 )
replace GQTYPE = . if (GQTYPE == -9)
replace AGE2 = . if (AGE2 >= 81 )
replace NOMARR2 = . if (NOMARR2 >= 81 )
replace SERVICE = . if (SERVICE >= 81 )
replace MILSTAT = . if (MILSTAT >= 81 )
replace HEALTH = . if (HEALTH >= 81 )
replace IRMARIT = . if (IRMARIT >= 81 )
replace IIMARIT = . if (IIMARIT == 9)
replace IREDUC2 = . if (IREDUC2 >= 81 )
replace NRCH17_2 = . if (NRCH17_2 == -9)
replace MOVESPY2 = . if (MOVESPY2 >= 81 )
replace ENROLED = . if (ENROLED >= 81 )
replace EDUCNOW2 = . if (EDUCNOW2 >= 81 )
replace STUDNT = . if (STUDNT >= 81 )
replace SCHDSICK = . if (SCHDSICK >= 81 )
replace SCHDSKIP = . if (SCHDSKIP >= 94 )
replace HSDIPLMA = . if (HSDIPLMA >= 81 )
replace HSGED = . if (HSGED >= 81 )
replace LFSCHRS2 = . if (LFSCHRS2 >= 981 )
replace LFTSCHA2 = . if (LFTSCHA2 >= 981 )
replace JOBSTAT2 = . if (JOBSTAT2 >= 10 )
replace WRKHAVJB = . if (WRKHAVJB >= 81 )
replace WRKHRSWK = . if (WRKHRSWK >= 981 )
replace WRKEFFRT = . if (WRKEFFRT >= 81 )
replace WRKEDYR = . if (WRKEDYR >= 81 )
replace WRKSLFEM = . if (WRKSLFEM >= 81 )
replace WRKJOBS2 = . if (WRKJOBS2 >= 981 )
replace WRKUNEMP = . if (WRKUNEMP >= 81 )
replace WRKUNWKS = . if (WRKUNWKS >= 81 )
replace WRKLASY2 = . if (WRKLASY2 >= 9981 )
replace WORKDAYS = . if (WORKDAYS >= 81 )
replace WORKBLAH = . if (WORKBLAH >= 81 )
replace LOCSIZE = . if (LOCSIZE >= 81 )
replace DRGPLCY = . if (DRGPLCY >= 81 )
replace PLCYCOV = . if (PLCYCOV >= 81 )
replace WKDRGED = . if (WKDRGED >= 81 )
replace DRGPRGM = . if (DRGPRGM >= 81 )
replace USALCTST = . if (USALCTST >= 81 )
replace USDRGTST = . if (USDRGTST >= 81 )
replace TSTHIRE = . if (TSTHIRE >= 81 )
replace TSTRAND = . if (TSTRAND >= 81 )
replace FIRSTPOS = . if (FIRSTPOS >= 81 )
replace WRKHIRE = . if (WRKHIRE >= 81 )
replace WORKRAND = . if (WORKRAND >= 81 )
replace RLGSVCYR = . if (RLGSVCYR >= 81 )
replace RLGIMPRT = . if (RLGIMPRT >= 81 )
replace RLGDECSN = . if (RLGDECSN >= 81 )
replace RLGFRNDS = . if (RLGFRNDS >= 81 )
replace TELNO2 = . if (TELNO2 >= 81 )
replace COLLEGE2 = . if (COLLEGE2 == -9)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

